/****************************************************************************
 *
 *  Rohde & Schwarz FPH instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSFPH_HEADER
#define __RSFPH_HEADER

#include "rscore.h"
#include "rsfph_attributes.h"
#include "rsfph_utility.h"

#include <float.h>
#include <math.h>

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define RSFPH_SIMULATION_ID_QUERY      "Rohde&Schwarz,FPH,1321.1111.02/100001,V2.21"  /* Default definition of ID Query Response for simulation */
#define RSFPH_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSFPH_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSFPH_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSFPH_CLASS_DRIVER_DESCRIPTION           ""
#define RSFPH_CLASS_DRIVER_PREFIX                ""
#define RSFPH_CLASS_DRIVER_VENDOR                ""
#define RSFPH_CLASS_DRIVER_REVISION              ""
#define RSFPH_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSFPH_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSFPH_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSFPH_SPECIFIC_DRIVER_PREFIX             "RSFPH"
#define RSFPH_SPECIFIC_DRIVER_LOCATOR            ""
#define RSFPH_SPECIFIC_DRIVER_VENDOR             ""
#define RSFPH_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define RSFPH_MINOR_VERSION                      80L   /* Instrument driver minor version          */
#define RSFPH_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSFPH_SUPPORTED_INSTRUMENT_MODELS        "FPH,FPC"    /* Instrument driver supported model(s)     */
#define RSFPH_GROUP_CAPABILITIES                 ""
#define RSFPH_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSFPH_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSFPH_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSFPH_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSFPH_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSFPH_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSFPH_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSFPH_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSFPH_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSFPH_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSFPH_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSFPH_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSFPH_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSFPH_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSFPH_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSFPH_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSFPH_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSFPH_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSFPH_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSFPH_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSFPH_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSFPH_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSFPH_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSFPH_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSFPH_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSFPH_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSFPH_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSFPH_ATTR_FREQUENCY_DOMAIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6035
#define RSFPH_ATTR_FREQUENCY_INPUT_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6036
#define RSFPH_ATTR_FREQUENCY_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6037
#define RSFPH_ATTR_FREQUENCY_START                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6038
#define RSFPH_ATTR_FREQUENCY_STOP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6039
#define RSFPH_ATTR_FREQUENCY_CENTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6040
#define RSFPH_ATTR_FREQUENCY_CENTER_STEP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6041
#define RSFPH_ATTR_FREQUENCY_CENTER_LINK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6042
#define RSFPH_ATTR_FREQUENCY_SPAN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6043
#define RSFPH_ATTR_FREQUENCY_SPAN_AUTO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6044
#define RSFPH_ATTR_FREQUENCY_SPAN_FULL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6045
#define RSFPH_ATTR_CHANNEL_NUMBER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6256
#define RSFPH_ATTR_CHANNEL_TABLE_DOWNLINK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6257
#define RSFPH_ATTR_CHANNEL_TABLE_UPLINK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6258
#define RSFPH_ATTR_CHANNEL_TABLE_SELECT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6397
#define RSFPH_ATTR_CHANNEL_LINK_DIRECTION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6396
#define RSFPH_ATTR_AMPLITUDE_UNITS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6046
#define RSFPH_ATTR_ATTENUATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6047
#define RSFPH_ATTR_ATTENUATION_AUTO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6048
#define RSFPH_ATTR_ATTENUATION_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6049
#define RSFPH_ATTR_REFERENCE_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6050
#define RSFPH_ATTR_REFERENCE_LEVEL_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6051
#define RSFPH_ATTR_AMPL_PREAMPLIFIER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6052
#define RSFPH_ATTR_INPUT_IMPEDANCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6053
#define RSFPH_ATTR_NUMBER_OF_SWEEPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6054
#define RSFPH_ATTR_VERTICAL_SCALE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6172
#define RSFPH_ATTR_SWEEP_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6055
#define RSFPH_ATTR_TRACKING_GENERATOR_ATTENUATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6398
#define RSFPH_ATTR_TRACKING_GENERATOR_ZERO_SPAN_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6399
#define RSFPH_ATTR_TRACKING_GENERATOR_AUTO_FREQUENCY_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6400
#define RSFPH_ATTR_TRACKING_GENERATOR_FREQUENCY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6401
#define RSFPH_ATTR_TRACKING_GENERATOR_FREQUENCY_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6402
#define RSFPH_ATTR_TRACKING_GENERATOR_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6403
#define RSFPH_ATTR_TRACKING_GENERATOR_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6404
#define RSFPH_ATTR_RESOLUTION_BANDWIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6056
#define RSFPH_ATTR_RESOLUTION_BANDWIDTH_AUTO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6057
#define RSFPH_ATTR_SWEEP_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6058
#define RSFPH_ATTR_SWEEP_TIME_AUTO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6059
#define RSFPH_ATTR_SWEEP_POINTS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6255
#define RSFPH_ATTR_VIDEO_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6060
#define RSFPH_ATTR_VIDEO_BANDWIDTH_AUTO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6061
#define RSFPH_ATTR_TRIGGER_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6062
#define RSFPH_ATTR_TRIGGER_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6063
#define RSFPH_ATTR_TRIGGER_CLOCK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6064
#define RSFPH_ATTR_TRIGGER_SLOPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6065
#define RSFPH_ATTR_VIDEO_TRIGGER_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6066
#define RSFPH_ATTR_IQ_TRIGGER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6405
#define RSFPH_ATTR_EXTERNAL_GATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6067
#define RSFPH_ATTR_EXTERNAL_GATE_HOLD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6068
#define RSFPH_ATTR_EXTERNAL_GATE_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6069
#define RSFPH_ATTR_EXTERNAL_GATE_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6070
#define RSFPH_ATTR_DETECTOR_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6073
#define RSFPH_ATTR_DETECTOR_TYPE_AUTO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6074
#define RSFPH_ATTR_TRACE_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6075
#define RSFPH_ATTR_TRACE_MEMORY_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6076
#define RSFPH_ATTR_TRACE_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6077
#define RSFPH_ATTR_SUBTRACT_TRACES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6407
#define RSFPH_ATTR_TRACE_MATH_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6079
#define RSFPH_ATTR_TRACE_MATH_STORE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6080
#define RSFPH_ATTR_REFERENCE_MARKER_PEAK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6081
#define RSFPH_ATTR_REFERENCE_MARKER_PEAK_NEXT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6082
#define RSFPH_ATTR_REFERENCE_MARKER_MINIMUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6083
#define RSFPH_ATTR_REFERENCE_MARKER_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6084
#define RSFPH_ATTR_REFERENCE_MARKER_AOFF                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6085
#define RSFPH_ATTR_REFERENCE_MARKER_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6086
#define RSFPH_ATTR_REFERENCE_MARKER_REL_POSITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6087
#define RSFPH_ATTR_REFERENCE_MARKER_AMPLITUDE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6088
#define RSFPH_ATTR_MARKER_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6089
#define RSFPH_ATTR_MARKER_AMPLITUDE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6090
#define RSFPH_ATTR_MARKER_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6091
#define RSFPH_ATTR_MARKER_AOFF                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6092
#define RSFPH_ATTR_MARKER_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6408
#define RSFPH_ATTR_MARKER_SEARCH_PEAK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6093
#define RSFPH_ATTR_MARKER_SEARCH_PEAK_NEXT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6094
#define RSFPH_ATTR_MARKER_SEARCH_PEAK_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6095
#define RSFPH_ATTR_MARKER_SEARCH_LIMITS_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6096
#define RSFPH_ATTR_MARKER_SEARCH_LIMITS_LEFT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6097
#define RSFPH_ATTR_MARKER_SEARCH_LIMITS_RIGHT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6098
#define RSFPH_ATTR_MARKER_FREQUENCY_COUNTER_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6099
#define RSFPH_ATTR_MARKER_FREQUENCY_COUNTER_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6100
#define RSFPH_ATTR_MARKER_NOISE_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6101
#define RSFPH_ATTR_MARKER_NOISE_RESULT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6102
#define RSFPH_ATTR_MARKER_DEMOD_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6103
#define RSFPH_ATTR_MARKER_DEMOD_HOLDOFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6104
#define RSFPH_ATTR_MARKER_DEMOD_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6105
#define RSFPH_ATTR_MARKER_NDB_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6106
#define RSFPH_ATTR_MARKER_NDB_VAL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6107
#define RSFPH_ATTR_MARKER_NDB_RESULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6108
#define RSFPH_ATTR_MEAS_POW_SELECT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6260
#define RSFPH_ATTR_MEAS_POW_OFF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6261
#define RSFPH_ATTR_MEAS_POW_STANDARD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6262
#define RSFPH_ATTR_MEAS_POW_STANDARD_CHECK                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6263
#define RSFPH_ATTR_MEAS_POW_ADJUST_REFERENCE_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6264
#define RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6266
#define RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6267
#define RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6268
#define RSFPH_ATTR_ACLR_ABSOLUTE_LIMIT_CHECK_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6269
#define RSFPH_ATTR_ACLR_ABSOLUTE_LIMIT_CHECK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6270
#define RSFPH_ATTR_ACLR_RESULT_UNIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6272
#define RSFPH_ATTR_ACLR_NUMBER_OF_ADJACENT_CHANNELS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6273
#define RSFPH_ATTR_ACLR_CHANNEL_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6274
#define RSFPH_ATTR_ACLR_CHANNEL_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6275
#define RSFPH_ATTR_ACLR_ADJACENT_CHANNEL_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6276
#define RSFPH_ATTR_ACLR_ADJACENT_CHANNEL_SPACING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6277
#define RSFPH_ATTR_ACLR_ADJUST_REFERENCE_LEVEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6278
#define RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6280
#define RSFPH_ATTR_ACLR_REFERENCE_CHANNEL_AUTOMATIC_SELECTION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6281
#define RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_AS_REFERENCE_CHANNEL              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6282
#define RSFPH_ATTR_ACLR_TOTAL_TX_CHANNEL_POWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6283
#define RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_SPACING                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6284
#define RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_BANDWIDTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6285
#define RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_SPACING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6286
#define RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK_STATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6287
#define RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6288
#define RSFPH_ATTR_ACLR_ALTERNATE_ABSOLUTE_LIMIT_CHECK_STATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6289
#define RSFPH_ATTR_ACLR_ALTERNATE_ABSOLUTE_LIMIT_CHECK                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6290
#define RSFPH_ATTR_CHANNEL_POWER_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6292
#define RSFPH_ATTR_CHANNEL_POWER_DISPLAY_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6293
#define RSFPH_ATTR_CHANNEL_POWER_UNIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6294
#define RSFPH_ATTR_CHANNEL_POWER_PER_HERTZ                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6295
#define RSFPH_ATTR_HARMONIC_DISTORTION_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6296
#define RSFPH_ATTR_HARMONIC_DISTORTION_NO_OF_HARMONICS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6297
#define RSFPH_ATTR_HARMONIC_DISTORTION_ADJUST_SETTINGS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6298
#define RSFPH_ATTR_MODULATION_DEPTH_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6301
#define RSFPH_ATTR_MODULATION_DEPTH_RESULT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6302
#define RSFPH_ATTR_SPECTRUM_EMISSION_MASK_PRESET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6432
#define RSFPH_ATTR_SPECTRUM_EMISSION_MASK_STANDARD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6433
#define RSFPH_ATTR_SPECTRUM_EMISSION_MASK_SWEEP_MODE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6434
#define RSFPH_ATTR_OCCUPIED_BANDWIDTH_CHANNEL_BANDWIDTH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6303
#define RSFPH_ATTR_OCCUPIED_BANDWIDTH_POWER_PERCENTAGE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6304
#define RSFPH_ATTR_TDMA_BURST_LENGTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6305
#define RSFPH_ATTR_ISOTROPIC_ANTENNA_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6306
#define RSFPH_ATTR_ISOTROPIC_ANTENNA_DIRECTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6307
#define RSFPH_ATTR_TOI_MEASUREMENT_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6409
#define RSFPH_ATTR_TOI_SEARCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6410
#define RSFPH_ATTR_QUERY_TOI_RESULT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6411
#define RSFPH_ATTR_MARKER_FREQ_DISP_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6110
#define RSFPH_ATTR_MARKER_TO_CENTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6111
#define RSFPH_ATTR_MARKER_TO_REFERENCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6112
#define RSFPH_ATTR_MARKER_TRACKING_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6412
#define RSFPH_ATTR_DLINE_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6113
#define RSFPH_ATTR_DLINE_POSITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6114
#define RSFPH_ATTR_LIMIT_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6115
#define RSFPH_ATTR_LIMIT_HORIZONTAL_UNIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6116
#define RSFPH_ATTR_LIMIT_VERTICAL_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6117
#define RSFPH_ATTR_LIMIT_BEEP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6118
#define RSFPH_ATTR_LIMIT_COMMENT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6119
#define RSFPH_ATTR_LIMIT_DELETE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6120
#define RSFPH_ATTR_LIMIT_CHECK_RESULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6121
#define RSFPH_ATTR_LIMIT_LOWER_SELECT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6124
#define RSFPH_ATTR_LIMIT_LOWER_THRESHOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6125
#define RSFPH_ATTR_LIMIT_UPPER_SELECT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6127
#define RSFPH_ATTR_LIMIT_UPPER_THRESHOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6128
#define RSFPH_ATTR_TFAC_SEL_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6129
#define RSFPH_ATTR_TFAC_UNIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6130
#define RSFPH_ATTR_TFAC_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6131
#define RSFPH_ATTR_TRANSDUCER_FACTOR_ISOTROPIC_ANTENNA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6308
#define RSFPH_ATTR_SYST_POWER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6132
#define RSFPH_ATTR_SYST_BATT_POWER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6133
#define RSFPH_ATTR_SYST_PRESET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6134
#define RSFPH_ATTR_SYSTEM_PRESET_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6135
#define RSFPH_ATTR_SYST_PRESET_USER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6136
#define RSFPH_ATTR_SYST_FACTORY_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6137
#define RSFPH_ATTR_SYST_REBOOT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6138
#define RSFPH_ATTR_SYST_SHUTDOWN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6139
#define RSFPH_ATTR_SYST_VERSION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6140
#define RSFPH_ATTR_SYST_ACCESSORY_AUTO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6141
#define RSFPH_ATTR_SYST_ACCESSORY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6142
#define RSFPH_ATTR_SYST_SPEAKER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6143
#define RSFPH_ATTR_SYST_BEEPER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6144
#define RSFPH_ATTR_SYST_KEYBOARD_CLICK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6145
#define RSFPH_ATTR_BEEPER_ON_POWER_OVERLOAD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6309
#define RSFPH_ATTR_SYST_BNC_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6146
#define RSFPH_ATTR_SYST_CAPTURE_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6147
#define RSFPH_ATTR_SYST_CAPTURE_COUNTER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6148
#define RSFPH_ATTR_SYST_CAPTURE_DATASET_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6149
#define RSFPH_ATTR_SYST_CAPTURE_SCREEN_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6150
#define RSFPH_ATTR_SYST_CAPTURE_GPX_INFORMATION_STATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6310
#define RSFPH_ATTR_INSTRUMENT_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6151
#define RSFPH_ATTR_SYST_PAD_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6152
#define RSFPH_ATTR_SYSTEM_DEVICE_MATERIAL_NUMBER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6311
#define RSFPH_ATTR_SYSTEM_DEVICE_SERIAL_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6312
#define RSFPH_ATTR_SYSTEM_FREE_RAM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6313
#define RSFPH_ATTR_SYSTEM_TOTAL_RAM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6314
#define RSFPH_ATTR_SYSTEM_USED_RAM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6315
#define RSFPH_ATTR_SYSTEM_FREE_STORAGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6316
#define RSFPH_ATTR_SYSTEM_TOTAL_STORAGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6317
#define RSFPH_ATTR_SYSTEM_USED_STORAGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6318
#define RSFPH_ATTR_SYST_SOEVENT_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6156
#define RSFPH_ATTR_SYST_SOEVENT_DISTANCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6157
#define RSFPH_ATTR_SYST_SOEVENT_LIMIT_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6158
#define RSFPH_ATTR_SYST_SOEVENT_STOR_DEV                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6159
#define RSFPH_ATTR_SYST_SOEVENT_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6160
#define RSFPH_ATTR_SYST_SOEVENT_TIME_INTERVAL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6161
#define RSFPH_ATTR_SYST_NETWORK_MAC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6162
#define RSFPH_ATTR_SYST_NETWORK_GATEWAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6163
#define RSFPH_ATTR_SYST_NETWORK_SUBMASK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6164
#define RSFPH_ATTR_SYST_NETWORK_IP_ADDRESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6165
#define RSFPH_ATTR_SYST_NETWORK_DHCP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6166
#define RSFPH_ATTR_SYST_NETWORK_PORT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6167
#define RSFPH_ATTR_GPS_RECEIVER_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6319
#define RSFPH_ATTR_GPS_RECEIVER_CONNECTED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6320
#define RSFPH_ATTR_GPS_RECEIVER_CORRECTION_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6321
#define RSFPH_ATTR_GPS_RECEIVER_SATELLITES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6322
#define RSFPH_ATTR_GPS_RECEIVER_QUALITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6323
#define RSFPH_ATTR_GPS_RECEIVER_LATITUDE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6324
#define RSFPH_ATTR_GPS_RECEIVER_LONGITUDE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6326
#define RSFPH_ATTR_GPS_RECEIVER_ALTITUDE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6328
#define RSFPH_ATTR_GPS_RECEIVER_VALID_POSITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6329
#define RSFPH_ATTR_ROSC_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6168
#define RSFPH_ATTR_DISP_ADJUST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6169
#define RSFPH_ATTR_DISP_REF_POSITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6170
#define RSFPH_ATTR_DISP_LOG_RANGE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6171
#define RSFPH_ATTR_DISPLAY_DEVIATION_PER_DIVISION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6330
#define RSFPH_ATTR_DISP_COL_PRESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6173
#define RSFPH_ATTR_DISP_BRIGHTNESS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6174
#define RSFPH_ATTR_DISP_COLOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6175
#define RSFPH_ATTR_DISP_DATE_FORMAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6176
#define RSFPH_ATTR_DISPLAY_UNIT_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6331
#define RSFPH_ATTR_DISPLAY_REMOTE_OPERATION_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6413
#define RSFPH_ATTR_HCOPY_PRINT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6177
#define RSFPH_ATTR_HCOPY_PRINT_SCREEN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6179
#define RSFPH_ATTR_HCOPY_FILE_NAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6180
#define RSFPH_ATTR_HCOPY_DEVICE_LANG_OUT_FORMAT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6181
#define RSFPH_ATTR_FILE_RECALL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6183
#define RSFPH_ATTR_FILE_SAVE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6185
#define RSFPH_ATTR_FILE_MANAGER_EDIT_PATH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6188
#define RSFPH_ATTR_FILE_MANAGER_DELETE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6190
#define RSFPH_ATTR_FILE_MANAGER_MAKE_DIR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6192
#define RSFPH_ATTR_FILE_MANAGER_CREATE_FILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6194
#define RSFPH_ATTR_FILE_MANAGER_DELETE_DIR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6198
#define RSFPH_ATTR_FILE_MANAGER_CURRENT_DIR_FILE_CATALOG                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6199
#define RSFPH_ATTR_FILE_MANAGER_CURRENT_DIR_CATALOG                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6200
#define RSFPH_ATTR_FILE_MANAGER_LOCK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6202
#define RSFPH_ATTR_FILE_MANAGER_UNLOCK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6204
#define RSFPH_ATTR_MEAS_ABORT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6205
#define RSFPH_ATTR_INIT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6206
#define RSFPH_ATTR_INIT_WITHOUT_OPC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6207
#define RSFPH_ATTR_INIT_SW_TRIGGER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6208
#define RSFPH_ATTR_PWM_ZERO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6209
#define RSFPH_ATTR_PWM_REFERENCE_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6210
#define RSFPH_ATTR_PWM_REFERENCE_VALUE_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6211
#define RSFPH_ATTR_PWM_MEASURE_TO_REFERENCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6212
#define RSFPH_ATTR_PWM_UNIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6213
#define RSFPH_ATTR_PWM_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6214
#define RSFPH_ATTR_PWM_CHANNEL_BW                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6215
#define RSFPH_ATTR_PWM_VIDEO_BANDWIDTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6216
#define RSFPH_ATTR_PWM_MEASUREMENT_TIME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6217
#define RSFPH_ATTR_PWM_STANDARD_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6218
#define RSFPH_ATTR_PWM_STANDARD_SELECT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6219
#define RSFPH_ATTR_PWM_FORWARD_POWER_DISPLAY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6335
#define RSFPH_ATTR_PWM_WAVELENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6416
#define RSFPH_ATTR_PMET_FETCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6220
#define RSFPH_ATTR_PMET_FETCH_REFLECTED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6417
#define RSFPH_ATTR_ANALOG_MODULATION_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6336
#define RSFPH_ATTR_ANALOG_MODULATION_MEASUREMENT_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6337
#define RSFPH_ATTR_ANALOG_MODULATION_DEEMPHASIS_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6338
#define RSFPH_ATTR_ANALOG_MODULATION_DEEMPHASIS_TIME_CONSTANT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6339
#define RSFPH_ATTR_ANALOG_MODULATION_AUDIO_LOWPASS_FILTER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6340
#define RSFPH_ATTR_ANALOG_MODULATION_REFERENCE_DEVIATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6418
#define RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_SELECT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6341
#define RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_DELETE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6342
#define RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_CHECK_RESULT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6343
#define RSFPH_ATTR_ANALOG_MODULATION_RESULT_DISPLAY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6344
#define RSFPH_ATTR_ANALOG_MODULATION_FM_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6345
#define RSFPH_ATTR_ANALOG_MODULATION_CARRIER_POWER_RESULT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6346
#define RSFPH_ATTR_ANALOG_MODULATION_SINAD_RESULT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6347
#define RSFPH_ATTR_ANALOG_MODULATION_THD_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6348
#define RSFPH_ATTR_ANALOG_MODULATION_AUDIO_FREQUENCY_RESULT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6349
#define RSFPH_ATTR_ANALOG_MODULATION_FREQUENCY_ERROR_RESULT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6350
#define RSFPH_ATTR_ANALOG_MODULATION_AM_MODULATION_INDEX_RESULT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6351
#define RSFPH_ATTR_ANALOG_MODULATION_AM_MAX_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6352
#define RSFPH_ATTR_ANALOG_MODULATION_AM_MIN_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6353
#define RSFPH_ATTR_ANALOG_MODULATION_AM_AVERAGE_RESULT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6354
#define RSFPH_ATTR_ANALOG_MODULATION_AM_RMS_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6355
#define RSFPH_ATTR_ANALOG_MODULATION_AM_MODULATION_DEPTH_RESULT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6419
#define RSFPH_ATTR_ANALOG_MODULATION_FM_MAX_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6356
#define RSFPH_ATTR_ANALOG_MODULATION_FM_MIN_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6357
#define RSFPH_ATTR_ANALOG_MODULATION_FM_AVERAGE_RESULT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6358
#define RSFPH_ATTR_ANALOG_MODULATION_FM_RMS_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6359
#define RSFPH_ATTR_ANALOG_MODULATION_FM_MODULATION_RATE_RESULT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6420
#define RSFPH_ATTR_DIGITAL_DEMODULATION_SELECT_MEASUREMENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6360
#define RSFPH_ATTR_DIGITAL_DEMODULATION_SYMBOL_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6361
#define RSFPH_ATTR_DIGITAL_DEMODULATION_NUMBER_OF_SYMBOLS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6362
#define RSFPH_ATTR_DIGITAL_DEMODULATION_MEASUREMENT_FILTER                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6363
#define RSFPH_ATTR_DIGITAL_DEMODULATION_FILTER_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6364
#define RSFPH_ATTR_DIGITAL_DEMODULATION_FILTER_ROLL_OFF_FACTOR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6365
#define RSFPH_ATTR_DIGITAL_DEMODULATION_BURST_STATE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6421
#define RSFPH_ATTR_DIGITAL_DEMODULATION_FSK_FREQUENCY_DEVIATION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6422
#define RSFPH_ATTR_DIGITAL_DEMODULATION_STANDARD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6473
#define RSFPH_ATTR_DIGITAL_DEMODULAITON_FSK_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6366
#define RSFPH_ATTR_DIGITAL_DEMODULATION_RESULT_DISPLAY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6367
#define RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_POWER_RESULT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6368
#define RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_FREQUENCY_DRIFT_RESULT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6369
#define RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_FREQUENCY_ERROR_RESULT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6370
#define RSFPH_ATTR_DIGITAL_DEMODULATION_MODULAITON_DEPTH_RESULT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6371
#define RSFPH_ATTR_DIGITAL_DEMODULATION_FREQUENCY_DEVIATION_RESULT             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6372
#define RSFPH_ATTR_DIGITAL_DEMODULATION_MAGNITUDE_ERROR_RESULT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6373
#define RSFPH_ATTR_DIGITAL_DEMODULATION_MODULATION_INDEX_RESULT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6374
#define RSFPH_ATTR_DIGITAL_DEMODULATION_MODULATION_ERROR_RESULT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6375
#define RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_SIGNAL_POWER_RESULT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6376
#define RSFPH_ATTR_RECEIVER_SCAN_RANGE_START                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6377
#define RSFPH_ATTR_RECEIVER_SCAN_RANGE_STOP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6378
#define RSFPH_ATTR_RECEIVER_SCAN_RANGE_STEP_SIZE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6379
#define RSFPH_ATTR_RECEIVER_FREQUENCY_SCALE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6423
#define RSFPH_ATTR_RECEIVER_RESET_MAXHOLD_INFORMATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6380
#define RSFPH_ATTR_RECEIVER_TRACE_STYLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6382
#define RSFPH_ATTR_RECEIVER_CISPR_BANDWIDTH_AUTO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6383
#define RSFPH_ATTR_RECEIVER_CISPR_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6384
#define RSFPH_ATTR_RECEIVER_SYNCHRONIZE_BARGRAPH_FREQUENCY_TO_MARKER           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6385
#define RSFPH_ATTR_RECEIVER_SYNCHRONIZE_BARGRAPH_FREQUENCY_TO_SPECIFIED_MARKER RS_SPECIFIC_PUBLIC_ATTR_BASE + 6474
#define RSFPH_ATTR_VNA_MEAS_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6435
#define RSFPH_ATTR_VNA_MEAS_FORMAT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6436
#define RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6475
#define RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_AUTO_SIZE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6476
#define RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_SIZE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 6477
#define RSFPH_ATTR_DTF_SETTINGS_COUPLING_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6437
#define RSFPH_ATTR_DTF_CABLE_MODEL_PRESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6438
#define RSFPH_ATTR_DTF_START_DISTANCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6439
#define RSFPH_ATTR_DTF_STOP_DISTANCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6440
#define RSFPH_ATTR_DTF_LIST_THRESHOLD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6444
#define RSFPH_ATTR_DTF_PEAK_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6441
#define RSFPH_ATTR_DTF_DISPLAY_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6443
#define RSFPH_ATTR_VNA_CABLE_LOSS_REFERENCE_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 6445
#define RSFPH_ATTR_VNA_CABLE_LOSS_REFERENCE_POSITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6446
#define RSFPH_ATTR_VNA_CABLE_LOSS_Y_AXIS_RANGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6447
#define RSFPH_ATTR_VNA_RETURN_LOSS_REFERENCE_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6448
#define RSFPH_ATTR_VNA_RETURN_LOSS_REFERENCE_POSITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 6449
#define RSFPH_ATTR_VNA_RETURN_LOSS_Y_AXIS_SCALE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6450
#define RSFPH_ATTR_VNA_RETURN_LOSS_LOG_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6451
#define RSFPH_ATTR_VNA_PHASE_REFERENCE_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6452
#define RSFPH_ATTR_VNA_PHASE_REFERENCE_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6453
#define RSFPH_ATTR_VNA_PHASE_UNWRAPPING_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6454
#define RSFPH_ATTR_VNA_PHASE_Y_AXIS_RANGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6455
#define RSFPH_ATTR_VNA_SWR_Y_AXIS_RANGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6456
#define RSFPH_ATTR_VNA_SWR_Y_AXIS_MINIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6458
#define RSFPH_ATTR_VNA_SWR_Y_AXIS_MAXIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6457
#define RSFPH_ATTR_SMITH_CHART_REFERENCE_IMPEDANCE_MARKER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6459
#define RSFPH_ATTR_START_FULL_S11_CALIBRATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6424
#define RSFPH_ATTR_START_EASY_S11_CALIBRATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 6425
#define RSFPH_ATTR_START_S21_CALIBRATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 6426
#define RSFPH_ATTR_CONTINUE_CALIBRATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6427
#define RSFPH_ATTR_ABORT_CALIBRATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6428
#define RSFPH_ATTR_QUERY_CALIBRATION_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6429
#define RSFPH_ATTR_QUERY_CALIBRATION_STATUS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6430
#define RSFPH_ATTR_SYSTEM_PRESET_CALIBRATION_DISCARD_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 6431
#define RSFPH_ATTR_BINARY_DATA_ORDER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6467
#define RSFPH_ATTR_STATUS_PRESET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6227
#define RSFPH_ATTR_ID_QUERY_RESPONSE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 6221
#define RSFPH_ATTR_SELF_TEST_QUERY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6222
#define RSFPH_ATTR_SYST_ERR                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 6223
#define RSFPH_ATTR_LOGGING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6251
#define RSFPH_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 6230

// rsfph_rngScalingType
#define RSFPH_VAL_TRACE_SPACE_LIN                                           0
#define RSFPH_VAL_TRACE_SPACE_LOG                                           1

// rsfph_rngMeasurementDomain
#define RSFPH_VAL_DOMAIN_TIME                                               0
#define RSFPH_VAL_DOMAIN_FREQUENCY                                          1

// rsfph_rngFreqCentLink
#define RSFPH_VAL_CENT_FREQ_LINK_OFF                                        0
#define RSFPH_VAL_CENT_FREQ_LINK_CENT                                       1
#define RSFPH_VAL_CENT_FREQ_LINK_DIVT                                       2

// rsfph_rngDisplayColor
#define RSFPH_VAL_DISP_COL_COLOR                                            0
#define RSFPH_VAL_DISP_COL_BW                                               1
#define RSFPH_VAL_DISP_COL_PF                                               2

// rsfph_rngDisplayDateFormat
#define RSFPH_VAL_DISP_DATE_FORMAT_DDMM                                     0
#define RSFPH_VAL_DISP_DATE_FORMAT_MMDD                                     1

// rsfph_rngPmetUnit
#define RSFPH_VAL_PMET_UNIT_DBM                                             0
#define RSFPH_VAL_PMET_UNIT_DB                                              1
#define RSFPH_VAL_PMET_UNIT_WATT                                            2
#define RSFPH_VAL_PMET_UNIT_VSWR                                            3
#define RSFPH_VAL_PMET_UNIT_DUVM                                            4
#define RSFPH_VAL_PMET_UNIT_DBUV                                            5
#define RSFPH_VAL_PMET_UNIT_W_M2                                            6
#define RSFPH_VAL_PMET_UNIT_V_M                                             7

// rsfph_rngFreqInputMode
#define RSFPH_VAL_FREQ_INPUT_MODE_CHAN                                      0
#define RSFPH_VAL_FREQ_INPUT_MODE_FREQ                                      1

// rsfph_rngPmetMeasTime
#define RSFPH_VAL_PMET_MEASTIME_NORM                                        0
#define RSFPH_VAL_PMET_MEASTIME_SHORT                                       1
#define RSFPH_VAL_PMET_MEASTIME_LONG                                        2

// rsfph_rngMarkerDemodType
#define RSFPH_VAL_MARKER_DEMOD_AM                                           0
#define RSFPH_VAL_MARKER_DEMOD_FM                                           1

// rsfph_rngAmplAttenMode
#define RSFPH_VAL_ATT_MODE_LNO                                              0
#define RSFPH_VAL_ATT_MODE_LDIS                                             1

// rsfph_rngTraceResultType
#define RSFPH_VAL_TRACE_RESULT_TRACE1                                       0
#define RSFPH_VAL_TRACE_RESULT_TRACE2                                       1
#define RSFPH_VAL_TRACE_RESULT_LIST                                         2

// rsfph_rngPolarity
#define RSFPH_VAL_NEG                                                       0
#define RSFPH_VAL_POS                                                       1

// rsfph_rngTriggerSource
#define RSFPH_VAL_TRG_IMM                                                   0
#define RSFPH_VAL_TRG_EXT                                                   1
#define RSFPH_VAL_TRG_VID                                                   2
#define RSFPH_VAL_TRG_INT                                                   3
#define RSFPH_VAL_TRG_IQP                                                   4
#define RSFPH_VAL_TRG_GAT                                                   5

// rsfph_rngDetectorType
#define RSFPH_VAL_DETECTOR_TYPE_AUTO_PEAK                                   0
#define RSFPH_VAL_DETECTOR_TYPE_AVERAGE                                     1
#define RSFPH_VAL_DETECTOR_TYPE_MAX_PEAK                                    2
#define RSFPH_VAL_DETECTOR_TYPE_MIN_PEAK                                    3
#define RSFPH_VAL_DETECTOR_TYPE_SAMPLE                                      4
#define RSFPH_VAL_DETECTOR_TYPE_RMS                                         5

// rsfph_rngTraceMode
#define RSFPH_VAL_TRACE_MODE_WRITE                                          0
#define RSFPH_VAL_TRACE_MODE_VIEW                                           1
#define RSFPH_VAL_TRACE_MODE_AVER                                           2
#define RSFPH_VAL_TRACE_MODE_MAXH                                           3
#define RSFPH_VAL_TRACE_MODE_MINH                                           4
#define RSFPH_VAL_TRACE_MODE_FRE                                            5
#define RSFPH_VAL_TRACE_MODE_INF                                            6
#define RSFPH_VAL_TRACE_MODE_BLANK                                          7

// rsfph_rngHcopyDeviceLang
#define RSFPH_VAL_HCOPY_DEVICE_LANG_JPG                                     0
#define RSFPH_VAL_HCOPY_DEVICE_LANG_PNG                                     1

// rsfph_rngStatusRegister
#define RSFPH_VAL_STAT_REG_MAIN                                             0
#define RSFPH_VAL_STAT_REG_POWER                                            1
#define RSFPH_VAL_STAT_REG_LIMIT                                            2
#define RSFPH_VAL_STAT_REG_FREQUENCY                                        3
#define RSFPH_VAL_STAT_REG_SYNC                                             4

// rsfph_rngStatusRegisterOperation
#define RSFPH_VAL_STAT_REG_QUESTIONABLE                                     1
#define RSFPH_VAL_STAT_REG_OPERATION                                        2

// rsfph_rngStatusRegisterQuery
#define RSFPH_VAL_STAT_REG_QUERY_COND                                       0
#define RSFPH_VAL_STAT_REG_QUERY_EVENT                                      1
#define RSFPH_VAL_STAT_REG_QUERY_ENABLE                                     2
#define RSFPH_VAL_STAT_REG_QUERY_PTRANSITION                                3
#define RSFPH_VAL_STAT_REG_QUERY_NTRANSITION                                4

// rsfph_rngSystPresetMode
#define RSFPH_VAL_SYST_PRESET_MODE_DEFAULT                                  0
#define RSFPH_VAL_SYST_PRESET_MODE_USER                                     1

// rsfph_rngSystSOEventLimitMode
#define RSFPH_VAL_SYST_SOEVENT_LIMIT_MODE_START                             0
#define RSFPH_VAL_SYST_SOEVENT_LIMIT_MODE_STOP                              1
#define RSFPH_VAL_SYST_SOEVENT_LIMIT_MODE_FAIL                              2

// rsfph_rngSystSOEventStorageDevice
#define RSFPH_VAL_SYST_SOEVENT_STOR_SDCARD                                  0
#define RSFPH_VAL_SYST_SOEVENT_STOR_USB                                     1

// rsfph_rngSystSOEventSource
#define RSFPH_VAL_SYST_SOEVENT_SOURCE_TIME                                  0
#define RSFPH_VAL_SYST_SOEVENT_SOURCE_LIM                                   1
#define RSFPH_VAL_SYST_SOEVENT_SOURCE_DIST                                  2
#define RSFPH_VAL_SYST_SOEVENT_SOURCE_ALLSWEEPS                             3

// rsfph_rngAmplitudeUnits
#define RSFPH_VAL_AMPLITUDE_UNITS_DBM                                       0
#define RSFPH_VAL_AMPLITUDE_UNITS_DBMV                                      1
#define RSFPH_VAL_AMPLITUDE_UNITS_DBUV                                      2
#define RSFPH_VAL_AMPLITUDE_UNITS_VOLT                                      3
#define RSFPH_VAL_AMPLITUDE_UNITS_WATT                                      4
#define RSFPH_VAL_AMPLITUDE_UNITS_DUVM                                      5
#define RSFPH_VAL_AMPLITUDE_UNITS_DUAM                                      6
#define RSFPH_VAL_AMPLITUDE_UNITS_V_M                                       7
#define RSFPH_VAL_AMPLITUDE_UNITS_W_M2                                      8
#define RSFPH_VAL_AMPLITUDE_UNITS_RHO                                       9
#define RSFPH_VAL_AMPLITUDE_UNITS_MRHO                                      10
#define RSFPH_VAL_AMPLITUDE_UNITS_DUVE                                      11
#define RSFPH_VAL_AMPLITUDE_UNITS_DMVE                                      12
#define RSFPH_VAL_AMPLITUDE_UNITS_VEMF                                      13
#define RSFPH_VAL_AMPLITUDE_UNITS_DBUA                                      14
#define RSFPH_VAL_AMPLITUDE_UNITS_DB                                        15

// rsfph_rngROSCSource
#define RSFPH_VAL_ROSC_SOURCE_INT                                           0
#define RSFPH_VAL_ROSC_SOURCE_EXT                                           1

// rsfph_rngLimitXUnit
#define RSFPH_VAL_LIMIT_X_UNIT_HZ                                           0
#define RSFPH_VAL_LIMIT_X_UNIT_S                                            1
#define RSFPH_VAL_LIMIT_X_UNIT_M                                            2

// rsfph_rngAbsRel
#define RSFPH_VAL_ABS                                                       0
#define RSFPH_VAL_REL                                                       1

// rsfph_rngLimitYUnit
#define RSFPH_VAL_LIMIT_Y_UNIT_DB                                           0
#define RSFPH_VAL_LIMIT_Y_UNIT_DBM                                          1
#define RSFPH_VAL_LIMIT_Y_UNIT_DBMV                                         2
#define RSFPH_VAL_LIMIT_Y_UNIT_DBUV                                         3
#define RSFPH_VAL_LIMIT_Y_UNIT_V                                            4
#define RSFPH_VAL_LIMIT_Y_UNIT_W                                            5
#define RSFPH_VAL_LIMIT_Y_UNIT_DBUVM                                        6
#define RSFPH_VAL_LIMIT_Y_UNIT_DBUAM                                        7
#define RSFPH_VAL_LIMIT_Y_UNIT_V_M                                          8
#define RSFPH_VAL_LIMIT_Y_UNIT_W_M2                                         9
#define RSFPH_VAL_LIMIT_Y_UNIT_VSWR                                         10

// rsfph_rngSystemAccessory
#define RSFPH_VAL_SYST_ACCESSORY_NONE                                       0
#define RSFPH_VAL_SYST_ACCESSORY_UNKNOWN                                    1
#define RSFPH_VAL_SYST_ACCESSORY_TS                                         2
#define RSFPH_VAL_SYST_ACCESSORY_Z1                                         3
#define RSFPH_VAL_SYST_ACCESSORY_Z2                                         4
#define RSFPH_VAL_SYST_ACCESSORY_Z3                                         5
#define RSFPH_VAL_SYST_ACCESSORY_Z18                                        6
#define RSFPH_VAL_SYST_ACCESSORY_Z44                                        7
#define RSFPH_VAL_SYST_ACCESSORY_ZN_Z103                                    8

// rsfph_rngBNCMode
#define RSFPH_VAL_BNC_MODE_REFERENCE                                        0
#define RSFPH_VAL_BNC_MODE_TRIGGER                                          1
#define RSFPH_VAL_BNC_MODE_BIAS                                             2

// rsfph_rngCaptureMode
#define RSFPH_VAL_CAPTURE_MODE_NONE                                         0
#define RSFPH_VAL_CAPTURE_MODE_SCREEN                                       1
#define RSFPH_VAL_CAPTURE_MODE_DATASET                                      2
#define RSFPH_VAL_CAPTURE_MODE_BOTH                                         3

// rsfph_rngInstrumentMode
#define RSFPH_VAL_INSTRUMENT_SAN                                            0
#define RSFPH_VAL_INSTRUMENT_PM                                             1
#define RSFPH_VAL_INSTRUMENT_ADEM                                           2
#define RSFPH_VAL_INSTRUMENT_REC                                            3
#define RSFPH_VAL_INSTRUMENT_ACT                                            4
#define RSFPH_VAL_INSTRUMENT_MAPS                                           5
#define RSFPH_VAL_INSTRUMENT_DDEM                                           6
#define RSFPH_VAL_INSTRUMENT_NAN                                            7

// rsfph_rngMarkerFreqDispMode
#define RSFPH_VAL_MARKER_FREQ_DISP_MODE_FREQ                                0
#define RSFPH_VAL_MARKER_FREQ_DISP_MODE_CHAN                                1

// rsfph_rngPmetStandardSelect
#define RSFPH_VAL_PMET_STANDARD_GSM                                         0
#define RSFPH_VAL_PMET_STANDARD_EDGE                                        1
#define RSFPH_VAL_PMET_STANDARD_WCDMA                                       2
#define RSFPH_VAL_PMET_STANDARD_CDMAO                                       3
#define RSFPH_VAL_PMET_STANDARD_CDMA2000                                    4
#define RSFPH_VAL_PMET_STANDARD_DVBT                                        5
#define RSFPH_VAL_PMET_STANDARD_DAB                                         6
#define RSFPH_VAL_PMET_STANDARD_TETRA                                       7
#define RSFPH_VAL_PMET_STANDARD_USER                                        8

// rsfph_rngSystemPadType
#define RSFPH_VAL_PAD_TYPE_RAM                                              0
#define RSFPH_VAL_PAD_TYPE_RAZ                                              1
#define RSFPH_VAL_PAD_TYPE_HZTE                                             2

// rsfph_rngTraceMathExpression
#define RSFPH_VAL_TRACE_MATH_EXPR_MEMCURR                                   0
#define RSFPH_VAL_TRACE_MATH_EXPR_CURRMEM                                   1

// rsfph_rngSystemPowerSource
#define RSFPH_VAL_POWER_SOURCE_BATTERY                                      0
#define RSFPH_VAL_POWER_SOURCE_MAINS                                        1

// rsfph_rngPWMForwardPowerDisplay
#define RSFPH_VAL_PMET_DETECTOR_AVERAGE                                     0
#define RSFPH_VAL_PMET_DETECTOR_PEAK_ENVELOPE                               1

// rsfph_rngMeasPowerSelect
#define RSFPH_VAL_MEAS_POW_CPOW                                             0
#define RSFPH_VAL_MEAS_POW_MCAC                                             1
#define RSFPH_VAL_MEAS_POW_OBW                                              2
#define RSFPH_VAL_MEAS_POW_TDMA                                             3

// rsfph_rngAnalogModulationResultDisplay
#define RSFPH_VAL_AM_TIME                                                   0
#define RSFPH_VAL_FM_TIME                                                   1
#define RSFPH_VAL_AM_SUMMARY                                                2
#define RSFPH_VAL_FM_SUMMARY                                                3

// rsfph_rngChannelPowerDisplayMode
#define RSFPH_VAL_DISPLAY_MODE_CLR                                          0
#define RSFPH_VAL_DISPLAY_MODE_MAXHOLD                                      1

// rsfph_rngChannelPowerUnits
#define RSFPH_VAL_CHANNEL_POWER_UNITS_DBM                                   0
#define RSFPH_VAL_CHANNEL_POWER_UNITS_DBMV                                  1
#define RSFPH_VAL_CHANNEL_POWER_UNITS_DBUV                                  2
#define RSFPH_VAL_CHANNEL_POWER_UNITS_VOLT                                  3
#define RSFPH_VAL_CHANNEL_POWER_UNITS_WATT                                  4
#define RSFPH_VAL_CHANNEL_POWER_UNITS_DUVM                                  5
#define RSFPH_VAL_CHANNEL_POWER_UNITS_DUAM                                  6
#define RSFPH_VAL_CHANNEL_POWER_UNITS_V_M                                   7
#define RSFPH_VAL_CHANNEL_POWER_UNITS_W_M2                                  8

// rsfph_rngReceiverTraceStyle
#define RSFPH_VAL_STYLE_LINES                                               0
#define RSFPH_VAL_STYLE_POLYGON                                             1

// rsfph_rngIsotropicAntennaDirection
#define RSFPH_VAL_DIRECTION_AUTO                                            0
#define RSFPH_VAL_DIRECTION_X                                               1
#define RSFPH_VAL_DIRECTION_Y                                               2
#define RSFPH_VAL_DIRECTION_Z                                               3

// rsfph_rngDigitalDemodulationResultDisplay
#define RSFPH_VAL_ERROR                                                     0
#define RSFPH_VAL_EYE                                                       1
#define RSFPH_VAL_MEAS                                                      2
#define RSFPH_VAL_SYMBOL                                                    3

// rsfph_rngDigitalDemodulationModulation
#define RSFPH_VAL_DDEM_ASK                                                  0
#define RSFPH_VAL_DDEM_FSK                                                  1

// rsfph_rngDigitalDemodulationFilterType
#define RSFPH_VAL_FILTER_GAUS                                               0
#define RSFPH_VAL_FILTER_RC                                                 1
#define RSFPH_VAL_FILTER_RRC                                                2

// rsfph_rngStatusRegisterFormat
#define RSFPH_VAL_STATUS_REG_FORMAT_ASCII                                   0
#define RSFPH_VAL_STATUS_REG_FORMAT_BINARY                                  1
#define RSFPH_VAL_STATUS_REG_FORMAT_HEX                                     2
#define RSFPH_VAL_STATUS_REG_FORMAT_OCTAL                                   3

// rsfph_rngAnalogModulationAudioLowpassFilter
#define RSFPH_VAL_LOWPASS_FILTER_DBW_1                                      0
#define RSFPH_VAL_LOWPASS_FILTER_DBW_10                                     1
#define RSFPH_VAL_LOWPASS_FILTER_DBW_30                                     2
#define RSFPH_VAL_LOWPASS_FILTER_DBW_100                                    3

// rsfph_rngDisplayUnitLength
#define RSFPH_VAL_UNIT_LENGTH_METER                                         0
#define RSFPH_VAL_UNIT_LENGTH_FEET                                          1

// rsfph_rngACLRUnits
#define RSFPH_VAL_ACLR_UNITS_DBM                                            0
#define RSFPH_VAL_ACLR_UNITS_DBMV                                           1
#define RSFPH_VAL_ACLR_UNITS_DBUV                                           2
#define RSFPH_VAL_ACLR_UNITS_VOLT                                           3
#define RSFPH_VAL_ACLR_UNITS_WATT                                           4
#define RSFPH_VAL_ACLR_UNITS_DVUA                                           5
#define RSFPH_VAL_ACLR_UNITS_DUVM                                           6
#define RSFPH_VAL_ACLR_UNITS_DUAM                                           7
#define RSFPH_VAL_ACLR_UNITS_VOLT_PER_M                                     8
#define RSFPH_VAL_ACLR_UNITS_WATT_PER_SQM                                   9

// rsfph_rngACLRReferenceChannelAutomaticSelection
#define RSFPH_VAL_ADJ_RCHAN_AUTO_MIN                                        0
#define RSFPH_VAL_ADJ_RCHAN_AUTO_MAX                                        1
#define RSFPH_VAL_ADJ_RCHAN_AUTO_LHIG                                       2
#define RSFPH_VAL_ADJ_RCHAN_AUTO_MAN                                        3

// rsfph_rngHarmonicDistortionResult
#define RSFPH_VAL_HARMONIC_TOTAL                                            0

// rsfph_rngGPSReceiverQuality
#define RSFPH_VAL_GPS_RECEIVER_QUALITY_INSUFFICIENT                         0
#define RSFPH_VAL_GPS_RECEIVER_QUALITY_LOW                                  1
#define RSFPH_VAL_GPS_RECEIVER_QUALITY_MEDIUM                               2
#define RSFPH_VAL_GPS_RECEIVER_QUALITY_HIGH                                 3
#define RSFPH_VAL_GPS_RECEIVER_QUALITY_EXCELLENT                            4

// rsfph_rngChannelLinkDirection
#define RSFPH_VAL_UP                                                        0
#define RSFPH_VAL_DOWN                                                      1

// rsfph_rngSEMSweepMode
#define RSFPH_VAL_SEM_SWEEP_MODE_AUTO                                       0
#define RSFPH_VAL_SEM_SWEEP_MODE_ESPECTRUM                                  1
#define RSFPH_VAL_SEM_SWEEP_MODE_LIST                                       2

// rsfph_rngBinaryDataOrder
#define RSFPH_VAL_BINARY_ORDER_NORMAL                                       0
#define RSFPH_VAL_BINARY_ORDER_SWAPPED                                      1

// rsfph_rngFreqScale
#define RSFPH_VAL_FREQ_SCALE_LINEAR                                         0
#define RSFPH_VAL_FREQ_SCALE_LOGARITHMIC                                    1

// rsfph_rngMagnitudeScale
#define RSFPH_VAL_MAGNITUDE_SCALE_LINEAR                                    0
#define RSFPH_VAL_MAGNITUDE_SCALE_LOGARITHMIC                               1

// rsfph_rngVNAMeasurementFormat
#define RSFPH_VAL_VNA_MEAS_FORMAT_LOSS                                      0
#define RSFPH_VAL_VNA_MEAS_FORMAT_MAGNITUDE                                 1
#define RSFPH_VAL_VNA_MEAS_FORMAT_PHASE                                     2
#define RSFPH_VAL_VNA_MEAS_FORMAT_SMITH                                     3
#define RSFPH_VAL_VNA_MEAS_FORMAT_VSWR                                      4

// rsfph_rngVNAMeasurementMode
#define RSFPH_VAL_VNA_MEAS_MODE_DTFAULT                                     0
#define RSFPH_VAL_VNA_MEAS_MODE_LOSS                                        1
#define RSFPH_VAL_VNA_MEAS_MODE_REFLECTION                                  2
#define RSFPH_VAL_VNA_MEAS_MODE_TRANSMISSION                                3

// rsfph_rngMarkerMode
#define RSFPH_VAL_MARKER_MODE_NORMAL                                        0
#define RSFPH_VAL_MARKER_MODE_REFLECTION_DB                                 1
#define RSFPH_VAL_MARKER_MODE_REFLECTION_LINEAR                             2
#define RSFPH_VAL_MARKER_MODE_REFLECTION_SCALAR                             3
#define RSFPH_VAL_MARKER_MODE_IMPEDANCE                                     4
#define RSFPH_VAL_MARKER_MODE_ADMITTANCE                                    5
#define RSFPH_VAL_MARKER_MODE_IMPEDANCE_STD                                 6
#define RSFPH_VAL_MARKER_MODE_ADMITTANCE_STD                                7

// rsfph_rngCalibrationInstructions
#define RSFPH_VAL_CALIBRATION_DONE                                          0
#define RSFPH_VAL_CALIBRATION_CONNECT_OPEN                                  1
#define RSFPH_VAL_CALIBRATION_CONNECT_SHORT                                 2
#define RSFPH_VAL_CALIBRATION_CONNECT_LOAD                                  3
#define RSFPH_VAL_CALIBRATION_CONNECT_THROUGH                               4
#define RSFPH_VAL_CALIBRATION_DISCONNECT_DUT                                5

// rsfph_rngCalibrationMode
#define RSFPH_VAL_CALIBRATION_MODE_DEFAULT                                  0
#define RSFPH_VAL_CALIBRATION_MODE_USER                                     1

// rsfph_rngCalibrationStatus
#define RSFPH_VAL_CALIBRATION_STATUS_NORM                                   0
#define RSFPH_VAL_CALIBRATION_STATUS_APPROX                                 1

// rsfph_rngLimitCheckState
#define RSFPH_VAL_LIMIT_CHECK_STATE_PASS                                    0
#define RSFPH_VAL_LIMIT_CHECK_STATE_FAIL                                    1

// rsfph_rngTrace
#define RSFPH_VAL_TRACE1                                                    1
#define RSFPH_VAL_TRACE2                                                    2
#define RSFPH_VAL_TRACE3                                                    3
#define RSFPH_VAL_TRACE4                                                    4

// rsfph_rngDigitalDemodulationStandard
#define RSFPH_VAL_DIGITAL_DEMODULATION_STANDARD_BLE                         0
#define RSFPH_VAL_DIGITAL_DEMODULATION_STANDARD_OFF                         1
#define RSFPH_VAL_DIGITAL_DEMODULATION_STANDARD_TIRE                        2

//repcap Marker
#define RSFPH_REPCAP_MARKER_M1                                              1
#define RSFPH_REPCAP_MARKER_M2                                              2
#define RSFPH_REPCAP_MARKER_M3                                              3
#define RSFPH_REPCAP_MARKER_M4                                              4
#define RSFPH_REPCAP_MARKER_M5                                              5
#define RSFPH_REPCAP_MARKER_M6                                              6

//repcap Limit
#define RSFPH_REPCAP_LIMIT_L1                                               1
#define RSFPH_REPCAP_LIMIT_L2                                               2

//repcap Transducer
#define RSFPH_REPCAP_TRANSDUCER_T1                                          1
#define RSFPH_REPCAP_TRANSDUCER_T2                                          2

//repcap Trace
#define RSFPH_REPCAP_TRACE_TR1                                              1
#define RSFPH_REPCAP_TRACE_TR2                                              2

//repcap PowerMeter
#define RSFPH_REPCAP_POWERMETER_PM1                                         1
#define RSFPH_REPCAP_POWERMETER_PM2                                         2

//repcap DeltaMarker
#define RSFPH_REPCAP_DELTAMARKER_DM2                                        0
#define RSFPH_REPCAP_DELTAMARKER_DM3                                        1
#define RSFPH_REPCAP_DELTAMARKER_DM4                                        2
#define RSFPH_REPCAP_DELTAMARKER_DM5                                        3
#define RSFPH_REPCAP_DELTAMARKER_DM6                                        4

//repcap AlternateChannel
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH1                                1
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH2                                2
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH3                                3
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH4                                4
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH5                                5
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH6                                6
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH7                                7
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH8                                8
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH9                                9
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH10                               10
#define RSFPH_REPCAP_ALTERNATECHANNEL_ALTCH11                               11

//repcap TXChannel
#define RSFPH_REPCAP_TXCHANNEL_TXCH1                                        1
#define RSFPH_REPCAP_TXCHANNEL_TXCH2                                        2
#define RSFPH_REPCAP_TXCHANNEL_TXCH3                                        3
#define RSFPH_REPCAP_TXCHANNEL_TXCH4                                        4
#define RSFPH_REPCAP_TXCHANNEL_TXCH5                                        5
#define RSFPH_REPCAP_TXCHANNEL_TXCH6                                        6
#define RSFPH_REPCAP_TXCHANNEL_TXCH7                                        7
#define RSFPH_REPCAP_TXCHANNEL_TXCH8                                        8
#define RSFPH_REPCAP_TXCHANNEL_TXCH9                                        9
#define RSFPH_REPCAP_TXCHANNEL_TXCH10                                       10
#define RSFPH_REPCAP_TXCHANNEL_TXCH11                                       11
#define RSFPH_REPCAP_TXCHANNEL_TXCH12                                       12

//repcap bits
#define RSFPH_REPCAP_BITS_BITS8                                             0
#define RSFPH_REPCAP_BITS_BITS9                                             1
#define RSFPH_REPCAP_BITS_BITS10                                            2
#define RSFPH_REPCAP_BITS_BITS11                                            3
#define RSFPH_REPCAP_BITS_BITS12                                            4
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSFPH_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSFPH_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSFPH_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSFPH_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ FP Value Defines --------------------------------*
 ****************************************************************************/
#define RSFPH_VAL_ATT_MODE_MANUAL 2

/* --- Sweep Coupling ------------------------------------------ */
#define RSFPH_VAL_COUPLING_RBW        0
#define RSFPH_VAL_COUPLING_VBW        1
#define RSFPH_VAL_COUPLING_SWEEP_TIME 2

/* --- Marker Search ------------------------------------------ */
#define RSFPH_VAL_MARKER_SEARCH_HIGHEST            1
#define RSFPH_VAL_MARKER_SEARCH_MINIMUM            2
#define RSFPH_VAL_MARKER_SEARCH_NEXT_PEAK          3

/* --- Instrument Setting ------------------------------------------ */
#define RSFPH_VAL_INSTRUMENT_SETTING_FREQUENCY_CENTER 0
#define RSFPH_VAL_INSTRUMENT_SETTING_REFERENCE_LEVEL  1

/* --- Operation ------------------------------------------ */
#define RSFPH_VAL_FILE_NEW_FOLDER 0
#define RSFPH_VAL_FILE_COPY       1
#define RSFPH_VAL_FILE_RENAME     2
#define RSFPH_VAL_FILE_DELETE     3
#define RSFPH_VAL_FILE_RDIR       4
#define RSFPH_VAL_FILE_CDIR       5

#define RSFPH_VAL_MEM_SAVE        0
#define RSFPH_VAL_MEM_RECALL      1
#define RSFPH_VAL_MEM_SAVE_PC     2
#define RSFPH_VAL_MEM_SAVE_SCR_PC 3
#define RSFPH_VAL_MEM_LOAD_PC     4
#define RSFPH_VAL_MEM_SAVE_TO_CSV 5

/* --- Register Operation ------------------------------------------ */
#define RSFPH_VAL_STAT_REG_PRESET       0
#define RSFPH_VAL_STAT_REG_QUESTIONABLE 1
#define RSFPH_VAL_STAT_REG_OPERATION    2

#define RSFPH_VAL_FAST_SWEEP_NORMAL 0
#define RSFPH_VAL_FAST_SWEEP_FAST   1

#define RSFPH_VAL_MEAS_POW_CPOW 0

#define RSFPH_VAL_ACP_TX  0
#define RSFPH_VAL_ACP_ADJ 1
#define RSFPH_VAL_ACP_ALT 2

#define RSFPH_VAL_HARMONIC_TOTAL 0

#define RSFPH_VAL_CHAN_BANDWIDTH 0
#define RSFPH_VAL_POWER_IN_PCT   1

#define RSFPH_VAL_RAM     0
#define RSFPH_VAL_STORAGE 1

#define RSFPH_VAL_ANALOG_RESULT_FM_OFFSET           0
#define RSFPH_VAL_ANALOG_RESULT_CARRIER_POWER       1
#define RSFPH_VAL_ANALOG_RESULT_SINAD               2
#define RSFPH_VAL_ANALOG_RESULT_THD                 3
#define RSFPH_VAL_ANALOG_RESULT_AUDIO_FREQUENCY     4
#define RSFPH_VAL_ANALOG_RESULT_FREQUENCY_ERROR     5
#define RSFPH_VAL_ANALOG_RESULT_AM_MODULATION_INDEX 6
#define RSFPH_VAL_ANALOG_RESULT_AM_MAX              7
#define RSFPH_VAL_ANALOG_RESULT_AM_MIN              8
#define RSFPH_VAL_ANALOG_RESULT_AM_AVERAGE          9
#define RSFPH_VAL_ANALOG_RESULT_AM_RMS              10
#define RSFPH_VAL_ANALOG_RESULT_FM_MAX              11
#define RSFPH_VAL_ANALOG_RESULT_FM_MIN              12
#define RSFPH_VAL_ANALOG_RESULT_FM_AVERAGE          13
#define RSFPH_VAL_ANALOG_RESULT_FM_RMS              14
#define RSFPH_VAL_ANALOG_RESULT_AM_MODULATION_DEPTH 15
#define RSFPH_VAL_ANALOG_RESULT_FM_MODULATION_RATE  16

#define RSFPH_VAL_DIGITAL_RESULT_FSK_OFFSET           0
#define RSFPH_VAL_DIGITAL_RESULT_CARRIER_POWER        1
#define RSFPH_VAL_DIGITAL_RESULT_CARRIER_FREQ_DRIFT   2
#define RSFPH_VAL_DIGITAL_RESULT_CARRIER_FREQ_ERROR   3
#define RSFPH_VAL_DIGITAL_RESULT_CARRIER_SIGNAL_POWER 4
#define RSFPH_VAL_DIGITAL_RESULT_MODULATION_DEPTH     5
#define RSFPH_VAL_DIGITAL_RESULT_MODULATION_INDEX     6
#define RSFPH_VAL_DIGITAL_RESULT_MODULATION_ERROR     7
#define RSFPH_VAL_DIGITAL_RESULT_FREQUENCY_DEVIATION  8
#define RSFPH_VAL_DIGITAL_RESULT_MAGNITUDE_ERROR      9

#define RSFPH_VAL_VALUE 3

#define RSFPH_VAL_CALIBRATION_ABORT                    0
#define RSFPH_VAL_CALIBRATION_CONTINUE                1
#define RSFPH_VAL_CALIBRATION_S11C                    2
#define RSFPH_VAL_CALIBRATION_S11                    3
#define RSFPH_VAL_CALIBRATION_S21N                    4

#define RSFPH_VAL_VNA_DTF_MAGN                        0
#define RSFPH_VAL_VNA_DTF_VSWR                        1
#define RSFPH_VAL_VNA_LOSS_LOSS                        2
#define RSFPH_VAL_VNA_REFL_MAGN                        3
#define RSFPH_VAL_VNA_REFL_PHAS                        4
#define RSFPH_VAL_VNA_REFL_SMIT                        5
#define RSFPH_VAL_VNA_REFL_VSWR                        6
#define RSFPH_VAL_VNA_TRAN_MAGN                        7

// Attribute name corrected, defined here for backwards compatibility
//#define RSFPH_ATTR_DIGITAL_DEMODULATION_MODULAITON_DEPTH_RESULT RSFPH_ATTR_DIGITAL_DEMODULATION_MODULATION_DEPTH_RESULT

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSFPH_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSFPH_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSFPH_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSFPH_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSFPH_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSFPH_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSFPH_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSFPH_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSFPH_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSFPH_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSFPH_ERROR_CODES_AND_MSGS \
    {RSFPH_WARN_MEASURE_UNCALIBRATED,  RSFPH_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSFPH_WARN_OVER_RANGE,            RSFPH_WARNMSG_OVER_RANGE},\
    {RSFPH_ERROR_MARKER_NOT_ENABLED,   RSFPH_ERRMSG_MARKER_NOT_ENABLED},\
    {RSFPH_ERROR_NOT_DELTA_MARKER,     RSFPH_ERRMSG_NOT_DELTA_MARKER},\
    {RSFPH_ERROR_MAX_TIME_EXCEEDED,    RSFPH_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rsfph_init(ViRsrc     resourceName,
                             ViBoolean  IDQuery,
                             ViBoolean  resetDevice,
                             ViSession* instrSession);

ViStatus _VI_FUNC rsfph_InitWithOptions(ViRsrc     resourceName,
                                        ViBoolean  IDQuery,
                                        ViBoolean  resetDevice,
                                        ViString   optionString,
                                        ViSession* instrSession);

ViStatus _VI_FUNC rsfph_SetSpectrumMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureAcquisition(ViSession instrSession,
                                             ViBoolean sweepModeContinuous,
                                             ViInt32   numberOfSweeps);

ViStatus _VI_FUNC rsfph_ConfigureSweepMode(ViSession instrSession,
                                           ViBoolean sweepModeContinuous);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyMeasurementDomain(ViSession instrSession,
                                                            ViInt32   measurementDomain);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyInputMode(ViSession instrSession,
                                                    ViInt32   inputMode);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyStartStop(ViSession instrSession,
                                                    ViReal64  startFrequency,
                                                    ViReal64  stopFrequency);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyCenterSpan(ViSession instrSession,
                                                     ViReal64  centerFrequency,
                                                     ViReal64  span);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyCenter(ViSession instrSession,
                                                 ViReal64  centerFrequency);

ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanFull(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanZero(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanAuto(ViSession instrSession,
                                                   ViBoolean autoSpan);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyCoupling(ViSession instrSession,
                                                   ViInt32   coupling);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyStepSize(ViSession instrSession,
                                                   ViReal64  stepSize);

ViStatus _VI_FUNC rsfph_ConfigureFrequencyOffset(ViSession instrSession,
                                                 ViReal64  frequencyOffset);

ViStatus _VI_FUNC rsfph_ConfigureChannelTable(ViSession instrSession,
                                              ViInt32   channelLinkDirection,
                                              ViInt32   channelNumber,
                                              ViString  channelTable);

ViStatus _VI_FUNC rsfph_ConfigureDisplayAutoscaleOnce(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureReferenceLevel(ViSession instrSession,
                                                ViReal64  referenceLevel);

ViStatus _VI_FUNC rsfph_ConfigureReferenceLevelOffset(ViSession instrSession,
                                                      ViReal64  referenceLevelOffset);

ViStatus _VI_FUNC rsfph_ConfigureReferenceLevelUnits(ViSession instrSession,
                                                     ViInt32   amplitudeUnits);

ViStatus _VI_FUNC rsfph_ConfigureVerticalRange(ViSession instrSession,
                                               ViReal64  range,
                                               ViReal64  referencePosition);

ViStatus _VI_FUNC rsfph_ConfigureVerticalScaling(ViSession instrSession,
                                                 ViInt32   verticalScale);

ViStatus _VI_FUNC rsfph_ConfigureDeviationPerDivision(ViSession instrSession,
                                                      ViReal64  deviationPerDivision);

ViStatus _VI_FUNC rsfph_ConfigureAttenuation(ViSession instrSession,
                                             ViInt32   mode,
                                             ViReal64  attenuation);

ViStatus _VI_FUNC rsfph_ConfigurePreamplifier(ViSession instrSession,
                                              ViBoolean state);

ViStatus _VI_FUNC rsfph_ConfigureInputImpedance(ViSession instrSession,
                                                ViReal64  impedance);

ViStatus _VI_FUNC rsfph_ConfigureSweepCoupling(ViSession instrSession,
                                               ViInt32   sweepCoupling,
                                               ViReal64  couplingValue);

ViStatus _VI_FUNC rsfph_ConfigureSweepCouplingAuto(ViSession instrSession,
                                                   ViInt32   sweepCoupling);

ViStatus _VI_FUNC rsfph_ConfigureSweep(ViSession instrSession,
                                       ViBoolean sweepTimeAuto,
                                       ViReal64  time);

ViStatus _VI_FUNC rsfph_ConfigureNumberOfSweeps(ViSession instrSession,
                                                ViInt32   numberOfSweeps);

ViStatus _VI_FUNC rsfph_ConfigureSweepPoints(ViSession instrSession,
                                             ViInt32   points);

ViStatus _VI_FUNC rsfph_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   triggerSource);

ViStatus _VI_FUNC rsfph_ConfigureTrigger(ViSession instrSession,
                                         ViReal64  offset,
                                         ViInt32   slope);

ViStatus _VI_FUNC rsfph_ConfigureVideoTrigger(ViSession instrSession,
                                              ViReal64  triggerLevel);

ViStatus _VI_FUNC rsfph_ConfigureInternalTriggerClock(ViSession instrSession,
                                                      ViReal64  clock);

ViStatus _VI_FUNC rsfph_ConfigureExternalGate(ViSession instrSession,
                                              ViBoolean gatedTrigger,
                                              ViReal64  delay,
                                              ViReal64  length,
                                              ViReal64  time);

ViStatus _VI_FUNC rsfph_ConfigureIQTriggerLevel(ViSession instrSession,
                                                ViReal64  level);

ViStatus _VI_FUNC rsfph_SelectTransducerFactor(ViSession instrSession,
                                               ViInt32   transducerNumber,
                                               ViBoolean transducerState,
                                               ViString  transducerName);

ViStatus _VI_FUNC rsfph_QueryTransducerFactorUnits(ViSession instrSession,
                                                   ViInt32   transducerNumber,
                                                   ViInt32*  unit);

ViStatus _VI_FUNC rsfph_ConfigureTransducerFactorIsotropicAntenna(
                            ViSession instrSession,
                            ViInt32   transducerNumber,
                            ViBoolean isotropicAntenna);

ViStatus _VI_FUNC rsfph_ConfigureTrace(ViSession instrSession,
                                       ViInt32   trace,
                                       ViBoolean traceState,
                                       ViInt32   traceType);

ViStatus _VI_FUNC rsfph_ConfigureTraceDetector(ViSession instrSession,
                                               ViInt32   trace,
                                               ViBoolean detectorTypeAuto,
                                               ViInt32   detectorType);

ViStatus _VI_FUNC rsfph_ConfigureSubtractTraces(ViSession instrSession,
                                                ViInt32   trace,
                                                ViBoolean traceMathState,
                                                ViInt32   mode);

ViStatus _VI_FUNC rsfph_StoreTraceToMemory(ViSession instrSession,
                                           ViInt32   trace);

ViStatus _VI_FUNC rsfph_ConfigureTraceMemoryState(ViSession instrSession,
                                                  ViInt32   trace,
                                                  ViBoolean memoryState);

ViStatus _VI_FUNC rsfph_ConfigureMarker(ViSession instrSession,
                                        ViInt32   trace,
                                        ViInt32   marker,
                                        ViBoolean markerState);

ViStatus _VI_FUNC rsfph_ConfigureMarkerFrequencyDisplayMode(ViSession instrSession,
                                                            ViInt32   trace,
                                                            ViInt32   marker,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rsfph_DisableAllMarkers(ViSession instrSession,
                                          ViInt32   trace);

ViStatus _VI_FUNC rsfph_MarkerSearch(ViSession instrSession,
                                     ViInt32   trace,
                                     ViInt32   marker,
                                     ViInt32   markerSearch);

ViStatus _VI_FUNC rsfph_MoveMarker(ViSession instrSession,
                                   ViInt32   trace,
                                   ViInt32   marker,
                                   ViReal64  markerPosition);

ViStatus _VI_FUNC rsfph_SetInstrumentFromMarker(ViSession instrSession,
                                                ViInt32   trace,
                                                ViInt32   marker,
                                                ViInt32   instrumentSetting);

ViStatus _VI_FUNC rsfph_QueryMarker(ViSession instrSession,
                                    ViInt32   trace,
                                    ViInt32   marker,
                                    ViReal64* markerPosition,
                                    ViReal64* markerAmplitude);

ViStatus _VI_FUNC rsfph_ConfigMarkerSearchLimits(ViSession instrSession,
                                                 ViInt32   trace,
                                                 ViInt32   marker,
                                                 ViBoolean searchLimits,
                                                 ViReal64  searchLimitLeft,
                                                 ViReal64  searchLimitRight);

ViStatus _VI_FUNC rsfph_ConfigureMarkerMode(ViSession instrSession,
                                            ViInt32   mode);

ViStatus _VI_FUNC rsfph_ConfigureMarkerFrequencyCounter(ViSession instrSession,
                                                        ViInt32   trace,
                                                        ViInt32   marker,
                                                        ViBoolean markerFrequencyCounter);

ViStatus _VI_FUNC rsfph_QueryMarkerFrequencyCounterResult(ViSession instrSession,
                                                          ViInt32   trace,
                                                          ViInt32   marker,
                                                          ViReal64* counterFrequency);

ViStatus _VI_FUNC rsfph_ConfigureMarkerNoiseMeasurement(ViSession instrSession,
                                                        ViInt32   trace,
                                                        ViInt32   marker,
                                                        ViBoolean state);

ViStatus _VI_FUNC rsfph_QueryMarkerNoiseMeasurementResult(ViSession instrSession,
                                                          ViInt32   trace,
                                                          ViInt32   marker,
                                                          ViReal64* result);

ViStatus _VI_FUNC rsfph_ConfigureNdBPoints(ViSession instrSession,
                                           ViInt32   trace,
                                           ViInt32   marker,
                                           ViBoolean nDBState,
                                           ViReal64  nDBLevel);

ViStatus _VI_FUNC rsfph_QueryNdBResult(ViSession instrSession,
                                       ViInt32   trace,
                                       ViInt32   marker,
                                       ViReal64* nDBResult);

ViStatus _VI_FUNC rsfph_QueryNdBFrequencies(ViSession instrSession,
                                            ViInt32   trace,
                                            ViInt32   marker,
                                            ViReal64* nDBFrequencyLower,
                                            ViReal64* nDBFrequencyHigher);

ViStatus _VI_FUNC rsfph_ConfigureMarkerDemodulation(ViSession instrSession,
                                                    ViInt32   trace,
                                                    ViInt32   marker,
                                                    ViBoolean state,
                                                    ViInt32   demodulationType,
                                                    ViReal64  markerStopTime);

ViStatus _VI_FUNC rsfph_SelectPowerMeasurement(ViSession instrSession,
                                               ViInt32   trace,
                                               ViInt32   marker,
                                               ViBoolean state,
                                               ViInt32   powerMeasurement);

ViStatus _VI_FUNC rsfph_ConfigurePowerStandard(ViSession instrSession,
                                               ViInt32   trace,
                                               ViInt32   marker,
                                               ViString  standard);

ViStatus _VI_FUNC rsfph_QueryPowerStandardCheck(ViSession instrSession,
                                                ViInt32   trace,
                                                ViInt32   marker,
                                                ViInt32*  standardCheck);

ViStatus _VI_FUNC rsfph_QueryPowerMeasurementsResults(ViSession instrSession,
                                                      ViInt32   trace,
                                                      ViInt32   marker,
                                                      ViInt32   powerMeasurement,
                                                      ViInt32   arraySize,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rsfph_AdjustPowerReferenceLevel(ViSession instrSession,
                                                  ViInt32   trace,
                                                  ViInt32   marker,
                                                  ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_ConfigureACLRPower(ViSession instrSession,
                                           ViInt32   channelMode,
                                           ViInt32   noOfAdjChannels,
                                           ViInt32   noOfTXChannels,
                                           ViInt32   unit);

ViStatus _VI_FUNC rsfph_ConfigureACLRReferenceChannel(ViSession instrSession,
                                                      ViInt32   reference,
                                                      ViInt32   channel);

ViStatus _VI_FUNC rsfph_ConfigureACLRSpacing(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   channelNumber,
                                             ViReal64  spacing);

ViStatus _VI_FUNC rsfph_ConfigureACLRBandwidth(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   channelNumber,
                                               ViReal64  bandwidth);

ViStatus _VI_FUNC rsfph_AdjustACLRReferenceLevel(ViSession instrSession,
                                                 ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_QueryACLRTotalTXChannelPower(ViSession instrSession,
                                                     ViReal64* totalTXChannelPower);

ViStatus _VI_FUNC rsfph_ConfigureACLRLimitCheckState(ViSession instrSession,
                                                     ViBoolean limitCheckState);

ViStatus _VI_FUNC rsfph_ConfigureACLRAdjacentChannelLimitCheck(
                            ViSession instrSession,
                            ViBoolean relativeState,
                            ViReal64  relativeValue,
                            ViBoolean absoluteState,
                            ViReal64  absoluteValue);

ViStatus _VI_FUNC rsfph_ConfigureACLRAlternateChannelLimitCheck(
                            ViSession instrSession,
                            ViInt32   alternateChannelNumber,
                            ViBoolean relativeState,
                            ViReal64  relativeValue,
                            ViBoolean absoluteState,
                            ViReal64  absoluteValue);

ViStatus _VI_FUNC rsfph_QueryACLRAdjacentChannelLimitCheckResult(
                            ViSession instrSession,
                            ViInt32*  lowerResult,
                            ViInt32*  upperResult);

ViStatus _VI_FUNC rsfph_QueryACLRAlternateChannelLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   alternateChannelNumber,
                            ViInt32*  lowerResult,
                            ViInt32*  upperResult);

ViStatus _VI_FUNC rsfph_ConfigureChannelPower(ViSession instrSession,
                                              ViInt32   trace,
                                              ViInt32   marker,
                                              ViReal64  bandwidth,
                                              ViInt32   displayMode,
                                              ViInt32   unit,
                                              ViBoolean channelPowerPerHertz);

ViStatus _VI_FUNC rsfph_ConfigureHarmonicDistortionMeasurement(
                            ViSession instrSession,
                            ViBoolean state,
                            ViInt32   numberOfHarmonics);

ViStatus _VI_FUNC rsfph_AdjustHarmonicDistortionSettings(ViSession instrSession,
                                                         ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_QueryHarmonicDistortion(ViSession instrSession,
                                                ViInt32   type,
                                                ViReal64* harmonicDistortionInPercent,
                                                ViReal64* harmonicDistortionInDB);

ViStatus _VI_FUNC rsfph_QueryHarmonicDistortionPositionList(ViSession instrSession,
                                                            ViInt32   arraySize,
                                                            ViReal64  positionList[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsfph_ConfigureAMModulationDepth(ViSession instrSession,
                                                   ViInt32   trace,
                                                   ViInt32   marker,
                                                   ViBoolean AMModulationDepth);

ViStatus _VI_FUNC rsfph_QueryAMModulationDepthResult(ViSession instrSession,
                                                     ViInt32   trace,
                                                     ViInt32   marker,
                                                     ViReal64* result);

ViStatus _VI_FUNC rsfph_ConfigureOccupiedBandwidth(ViSession instrSession,
                                                   ViInt32   type,
                                                   ViReal64  bandwidth);

ViStatus _VI_FUNC rsfph_ConfigureTDMABurstLength(ViSession instrSession,
                                                 ViReal64  burstLength);

ViStatus _VI_FUNC rsfph_ConfigureIsotropicAntenna(ViSession instrSession,
                                                  ViBoolean state,
                                                  ViInt32   direction);

ViStatus _VI_FUNC rsfph_ConfigureTOIMeasurementEnabled(ViSession instrSession,
                                                       ViBoolean enabled);

ViStatus _VI_FUNC rsfph_ConfigureTOISearch(ViSession instrSession);

ViStatus _VI_FUNC rsfph_QueryTOIResult(ViSession instrSession,
                                       ViReal64  *TOIResult);

ViStatus _VI_FUNC rsfph_ConfigureMarkerTrackingEnabled(ViSession instrSession,
                                                       ViBoolean enabled);

ViStatus _VI_FUNC rsfph_ConfigureDeltaMarker(ViSession instrSession,
                                             ViInt32   trace,
                                             ViInt32   deltaMarker,
                                             ViBoolean state);

ViStatus _VI_FUNC rsfph_DisableAllDeltaMarkers(ViSession instrSession,
                                               ViInt32   trace);

ViStatus _VI_FUNC rsfph_DeltaMarkerSearch(ViSession instrSession,
                                          ViInt32   trace,
                                          ViInt32   deltaMarker,
                                          ViInt32   markerSearch);

ViStatus _VI_FUNC rsfph_MoveDeltaMarker(ViSession instrSession,
                                        ViInt32   trace,
                                        ViInt32   deltaMarker,
                                        ViInt32   mode,
                                        ViReal64  position);

ViStatus _VI_FUNC rsfph_QueryDeltaMarker(ViSession instrSession,
                                         ViInt32   trace,
                                         ViInt32   deltaMarker,
                                         ViInt32   mode,
                                         ViReal64* position,
                                         ViReal64* amplitude);

ViStatus _VI_FUNC rsfph_ConfigureDisplayLine(ViSession instrSession,
                                             ViBoolean state,
                                             ViReal64  position);

ViStatus _VI_FUNC rsfph_CreateLimitLine(ViSession instrSession,
                                        ViInt32   limit,
                                        ViString  name,
                                        ViString  description,
                                        ViInt32   xAxisUnits,
                                        ViInt32   xScale,
                                        ViInt32   yAxisUnits,
                                        ViInt32   arraySize,
                                        ViReal64  xData[],
                                        ViReal64  yData[]);

ViStatus _VI_FUNC rsfph_ConfigureLimitLine(ViSession instrSession,
                                           ViInt32   limit,
                                           ViBoolean limitCheckState,
                                           ViBoolean beep);

ViStatus _VI_FUNC rsfph_ConfigureLowerLimitLine(ViSession instrSession,
                                                ViInt32   limit,
                                                ViString  name);

ViStatus _VI_FUNC rsfph_ConfigureLowerLimitThreshold(ViSession instrSession,
                                                     ViInt32   limit,
                                                     ViReal64  threshold);

ViStatus _VI_FUNC rsfph_ConfigureUpperLimitLine(ViSession instrSession,
                                                ViInt32   limit,
                                                ViString  name);

ViStatus _VI_FUNC rsfph_ConfigureUpperLimitThreshold(ViSession instrSession,
                                                     ViInt32   limit,
                                                     ViReal64  threshold);

ViStatus _VI_FUNC rsfph_DeleteLimitLine(ViSession instrSession,
                                        ViInt32   limit);

ViStatus _VI_FUNC rsfph_QueryLimitLineComment(ViSession instrSession,
                                              ViInt32   limit,
                                              ViInt32   bufferSize,
                                              ViChar    comment[]);

ViStatus _VI_FUNC rsfph_QueryLimitLineXUnits(ViSession instrSession,
                                             ViInt32   limit,
                                             ViInt32*  xAxisUnits);

ViStatus _VI_FUNC rsfph_QueryLimitLineYUnits(ViSession instrSession,
                                             ViInt32   limit,
                                             ViInt32*  yAxisUnits);

ViStatus _VI_FUNC rsfph_ConfigureDisplay(ViSession instrSession,
                                         ViInt32   colorScheme,
                                         ViReal64  brightness,
                                         ViInt32   dateFormat);

ViStatus _VI_FUNC rsfph_DisplayColorDefault(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureDisplayLengthUnit(ViSession instrSession,
                                                   ViInt32   unit);

ViStatus _VI_FUNC rsfph_ConfigureDisplayRemoteOperationEnabled(
                            ViSession instrSession,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsfph_ConfigurePadType(ViSession instrSession,
                                         ViInt32   padType);

ViStatus _VI_FUNC rsfph_ConfigureAudioVolume(ViSession instrSession,
                                             ViReal64  keyboardClickVolume,
                                             ViReal64  beeperVolume,
                                             ViReal64  speakerVolume);

ViStatus _VI_FUNC rsfph_ConfigureBeeperOnPowerOverload(ViSession instrSession,
                                                       ViBoolean beepOnPowerOverload);

ViStatus _VI_FUNC rsfph_ConfigureReferenceOscillator(ViSession instrSession,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsfph_ConfigureBNCMode(ViSession instrSession,
                                         ViInt32   BNCMode);

ViStatus _VI_FUNC rsfph_ConfigureSystemDate(ViSession instrSession,
                                            ViInt32   year,
                                            ViInt32   month,
                                            ViInt32   day);

ViStatus _VI_FUNC rsfph_ConfigureSystemTime(ViSession instrSession,
                                            ViInt32   hour,
                                            ViInt32   minute,
                                            ViInt32   second);

ViStatus _VI_FUNC rsfph_ConfigureSystemTimeZone(ViSession instrSession,
                                                ViInt32   hour,
                                                ViInt32   minute);

ViStatus _VI_FUNC rsfph_ConfigureSystemAccessory(ViSession instrSession,
                                                 ViBoolean autoDetection);

ViStatus _VI_FUNC rsfph_QueryDetectedAccessory(ViSession instrSession,
                                               ViInt32*  accessory);

ViStatus _VI_FUNC rsfph_ConfigureSystemCapture(ViSession instrSession,
                                               ViInt32   mode);

ViStatus _VI_FUNC rsfph_ConfigureSystemCaptureCounter(ViSession instrSession,
                                                      ViString  counter);

ViStatus _VI_FUNC rsfph_ConfigureSystemCaptureItems(ViSession instrSession,
                                                    ViBoolean includeDataset,
                                                    ViBoolean includeScreen,
                                                    ViBoolean includeGPXInformation);

ViStatus _VI_FUNC rsfph_ConfigureSavingEvents(ViSession instrSession,
                                              ViBoolean enabled,
                                              ViInt32   storage,
                                              ViInt32   source);

ViStatus _VI_FUNC rsfph_ConfigureSavingEventsInterval(ViSession instrSession,
                                                      ViInt32   interval);

ViStatus _VI_FUNC rsfph_ConfigureSavingEventsDistance(ViSession instrSession,
                                                      ViInt32   distance);

ViStatus _VI_FUNC rsfph_ConfigureSavingEventsLimitMode(ViSession instrSession,
                                                       ViInt32   limitMode);

ViStatus _VI_FUNC rsfph_SystemReboot(ViSession instrSession);

ViStatus _VI_FUNC rsfph_SystemShutdown(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigurePresetMode(ViSession instrSession,
                                            ViInt32   presetMode);

ViStatus _VI_FUNC rsfph_Preset(ViSession instrSession);

ViStatus _VI_FUNC rsfph_FactoryPreset(ViSession instrSession);

ViStatus _VI_FUNC rsfph_UserPreset(ViSession instrSession,
                                   ViString  path);

ViStatus _VI_FUNC rsfph_ConfigureIPAddress(ViSession instrSession,
                                           ViBoolean DHCP,
                                           ViString  IPAddress,
                                           ViString  subnetMask,
                                           ViString  gateway,
                                           ViInt32   port);

ViStatus _VI_FUNC rsfph_QueryMACAddress(ViSession instrSession,
                                        ViInt32   length,
                                        ViChar    MACAddress[]);

ViStatus _VI_FUNC rsfph_QuerySystemPower(ViSession instrSession,
                                         ViInt32*  powerSource,
                                         ViReal64* batteryPower);

ViStatus _VI_FUNC rsfph_ConfigureGPSReceiver(ViSession instrSession,
                                             ViBoolean GPSReceiver);

ViStatus _VI_FUNC rsfph_QueryGPSReceiverData(ViSession  instrSession,
                                             ViBoolean* connected,
                                             ViReal64*  correctionFrequency,
                                             ViInt32*   satellites,
                                             ViInt32*   quality);

ViStatus _VI_FUNC rsfph_QueryGPSReceiverCoordinates(ViSession instrSession,
                                                    ViInt32*  latitudeDegrees,
                                                    ViInt32*  latitudeMinutes,
                                                    ViReal64* latitudeSeconds,
                                                    ViInt32*  longitudeDegrees,
                                                    ViInt32*  longitudeMinutes,
                                                    ViReal64* longitudeSeconds,
                                                    ViReal64* altitude);

ViStatus _VI_FUNC rsfph_QueryGPSReceiverValidPosition(ViSession  instrSession,
                                                      ViBoolean* validPosition);

ViStatus _VI_FUNC rsfph_QueryDeviceNumbers(ViSession instrSession,
                                           ViUInt32  bufferSize,
                                           ViChar    materialNumber[],
                                           ViChar    serialNumber[]);

ViStatus _VI_FUNC rsfph_QueryMemoryInfo(ViSession instrSession,
                                        ViInt32   type,
                                        ViReal64* total,
                                        ViReal64* used,
                                        ViReal64* free);

ViStatus _VI_FUNC rsfph_SetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32   attributeValue);

ViStatus _VI_FUNC rsfph_SetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64  attributeValue);

ViStatus _VI_FUNC rsfph_SetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViString  attributeValue);

ViStatus _VI_FUNC rsfph_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeID,
                                              ViBoolean attributeValue);

ViStatus _VI_FUNC rsfph_SetAttributeViSession(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeID,
                                              ViSession attributeValue);

ViStatus _VI_FUNC rsfph_GetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32*  attributeValue);

ViStatus _VI_FUNC rsfph_GetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64* attributeValue);

ViStatus _VI_FUNC rsfph_GetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[]);

ViStatus _VI_FUNC rsfph_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   channelName,
                                              ViAttr     attributeID,
                                              ViBoolean* attributeValue);

ViStatus _VI_FUNC rsfph_GetAttributeViSession(ViSession  instrSession,
                                              ViString   channelName,
                                              ViAttr     attributeID,
                                              ViSession* attributeValue);

ViStatus _VI_FUNC rsfph_CheckAttributeViInt32(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeID,
                                              ViInt32   attributeValue);

ViStatus _VI_FUNC rsfph_CheckAttributeViReal64(ViSession instrSession,
                                               ViString  channelName,
                                               ViAttr    attributeID,
                                               ViReal64  attributeValue);

ViStatus _VI_FUNC rsfph_CheckAttributeViString(ViSession instrSession,
                                               ViString  channelName,
                                               ViAttr    attributeID,
                                               ViString  attributeValue);

ViStatus _VI_FUNC rsfph_CheckAttributeViBoolean(ViSession instrSession,
                                                ViString  channelName,
                                                ViAttr    attributeID,
                                                ViBoolean attributeValue);

ViStatus _VI_FUNC rsfph_CheckAttributeViSession(ViSession instrSession,
                                                ViString  channelName,
                                                ViAttr    attributeID,
                                                ViSession attributeValue);

ViStatus _VI_FUNC rsfph_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeID,
                                               ViString  repCapNameID,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[]);

ViStatus _VI_FUNC rsfph_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rsfph_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rsfph_ConfigureHardcopyFormat(ViSession instrSession,
                                                ViInt32   format);

ViStatus _VI_FUNC rsfph_HardcopySetFileName(ViSession instrSession,
                                            ViString  name);

ViStatus _VI_FUNC rsfph_HardcopyPrint(ViSession instrSession);

ViStatus _VI_FUNC rsfph_HardcopyPrintScreenToFile(ViSession instrSession,
                                                  ViString  destination);

ViStatus _VI_FUNC rsfph_FileManagerOperations(ViSession instrSession,
                                              ViInt32   operation,
                                              ViString  source,
                                              ViString  destination);

ViStatus _VI_FUNC rsfph_FileDirectory(ViSession instrSession,
                                      ViInt32   bufferSize,
                                      ViChar    output[]);

ViStatus _VI_FUNC rsfph_DirectoriesInCurrentDirectory(ViSession instrSession,
                                                      ViInt32   bufferSize,
                                                      ViChar    output[]);

ViStatus _VI_FUNC rsfph_DataSetFileOperations(ViSession instrSession,
                                              ViInt32   operation,
                                              ViString  path);

ViStatus _VI_FUNC rsfph_ConfigureFileDate(ViSession instrSession,
                                          ViString  path,
                                          ViInt32   year,
                                          ViInt32   month,
                                          ViInt32   day);

ViStatus _VI_FUNC rsfph_ConfigureFileTime(ViSession instrSession,
                                          ViString  path,
                                          ViInt32   hour,
                                          ViInt32   minute,
                                          ViInt32   second);

ViStatus _VI_FUNC rsfph_ConfigureFileLock(ViSession instrSession,
                                          ViString  path,
                                          ViBoolean locked);

ViStatus _VI_FUNC rsfph_ReadYTrace(ViSession instrSession,
                                   ViInt32   trace,
                                   ViUInt32  maximumTime,
                                   ViInt32   arrayLength,
                                   ViInt32*  actualPoints,
                                   ViReal64  amplitude[]);

ViStatus _VI_FUNC rsfph_FetchYTrace(ViSession instrSession,
                                    ViInt32   trace,
                                    ViInt32   arrayLength,
                                    ViInt32*  actualPoints,
                                    ViReal64  amplitude[]);

ViStatus _VI_FUNC rsfph_FetchPeakList(ViSession instrSession,
                                      ViInt32   arrayLength,
                                      ViInt32*  actualPoints,
                                      ViReal64  peakList[]);

ViStatus _VI_FUNC rsfph_GetLimitCheckResult(ViSession instrSession,
                                            ViInt32   limit,
                                            ViInt32*  state);

ViStatus _VI_FUNC rsfph_QueryMemoryTraceData(ViSession instrSession,
                                             ViInt32   trace,
                                             ViInt32   arraySize,
                                             ViReal64  memoryData[],
                                             ViInt32*  actualPoints);

ViStatus _VI_FUNC rsfph_Initiate(ViSession instrSession,
                                 ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_Abort(ViSession instrSession);

ViStatus _VI_FUNC rsfph_SendSoftwareTrigger(ViSession instrSession,
                                            ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_ConfigureZeroSpanEnabled(ViSession instrSession,
                                                 ViBoolean zeroSpanEnabled);

ViStatus _VI_FUNC rsfph_ConfigureTrackingGenerator(ViSession instrSession,
                                                   ViBoolean enabled,
                                                   ViBoolean autoFrequencyEnabled,
                                                   ViReal64  frequency,
                                                   ViReal64  frequencyOffset);

ViStatus _VI_FUNC rsfph_ConfigureTrackingGeneratorPower(ViSession instrSession,
                                                        ViReal64  power);

ViStatus _VI_FUNC rsfph_ConfigureTrackingGeneratorAttenuation(
                            ViSession instrSession,
                            ViReal64  attenuation);

ViStatus _VI_FUNC rsfph_SetPowerMeterMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterFrequency(ViSession instrSession,
                                                     ViReal64  frequency,
                                                     ViReal64  channelBandwidth);

ViStatus _VI_FUNC rsfph_ZeroPowerMeter(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterReferenceLevel(ViSession instrSession,
                                                          ViBoolean measureToReference,
                                                          ViReal64  referenceValue);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterReferenceLevelOffset(
                            ViSession instrSession,
                            ViReal64  referenceValueOffset);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterUnits(ViSession instrSession,
                                                 ViInt32   powerMeterUnits);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterMeasurementTime(ViSession instrSession,
                                                           ViInt32   measurementTime);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterVideoBandwidth(ViSession instrSession,
                                                          ViReal64  videoBandwidth);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterStandard(ViSession instrSession,
                                                    ViBoolean state,
                                                    ViInt32   standard);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterFowardPowerDisplay(
                            ViSession instrSession,
                            ViInt32   forwardPowerDisplay);

ViStatus _VI_FUNC rsfph_ConfigurePowerMeterWavelength(ViSession instrSession,
                                                      ViInt32   wavelength);

ViStatus _VI_FUNC rsfph_FetchPowerMeterResults(ViSession instrSession,
                                               ViInt32   arrayLength,
                                               ViInt32*  actualPoints,
                                               ViReal64  results[]);

ViStatus _VI_FUNC rsfph_FetchPowerMeterReflectedResult(ViSession instrSession,
                                                       ViInt32   arrayLength,
                                                       ViInt32   *actualPoints,
                                                       ViReal64  *reflectedResults);

ViStatus _VI_FUNC rsfph_SetAnalogModulationMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationBandwidth(ViSession instrSession,
                                                           ViReal64  bandwidth);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationDeemphasis(ViSession instrSession,
                                                            ViBoolean state,
                                                            ViReal64  timeConstant);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationLowpassFilter(
                            ViSession instrSession,
                            ViInt32   lowpassFilter);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationReferenceDeviation(
                            ViSession instrSession,
                            ViReal64  referenceDeviation);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationLimitLine(ViSession instrSession,
                                                           ViString  name);

ViStatus _VI_FUNC rsfph_DeleteAnalogModulationLimitLine(ViSession instrSession);

ViStatus _VI_FUNC rsfph_QueryAnalogModulationLimitCheckResult(
                            ViSession instrSession,
                            ViInt32*  limitLineCheckResult);

ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationResultDisplay(
                            ViSession instrSession,
                            ViInt32   resultDisplay);

ViStatus _VI_FUNC rsfph_QueryAnalogModulationResults(ViSession instrSession,
                                                     ViInt32   type,
                                                     ViReal64* result);

ViStatus _VI_FUNC rsfph_QueryAnalogModulationMeasurementTime(ViSession instrSession,
                                                             ViReal64* measurementTime);

ViStatus _VI_FUNC rsfph_SetDigitalDemodulationMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_SelectDigitalDemodulationMeasurement(ViSession instrSession,
                                                             ViInt32   measurement);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulation(ViSession instrSession,
                                                     ViReal64  symbolRate,
                                                     ViInt32   numberOfSymbols);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationFilter(ViSession instrSession,
                                                           ViBoolean state,
                                                           ViInt32   type,
                                                           ViReal64  numberOfSymbols);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationBurstStateEnabled(
                            ViSession instrSession,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationFSKFrequencyDeviation(
                            ViSession instrSession,
                            ViReal64  FSKFrequencyDeviation);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationStandard(ViSession instrSession,
                                                             ViInt32   standard);

ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationResultDisplay(
                            ViSession instrSession,
                            ViInt32   resultDisplay);

ViStatus _VI_FUNC rsfph_QueryDigitalDemodulationResults(ViSession instrSession,
                                                        ViInt32   type,
                                                        ViReal64* result);

ViStatus _VI_FUNC rsfph_SetReceiverMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureReceiverScanRange(ViSession instrSession,
                                                   ViReal64  start,
                                                   ViReal64  stop,
                                                   ViReal64  stepSize);

ViStatus _VI_FUNC rsfph_ReceiverResetMaxholdInformation(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ReceiverSynchronizeBargraphFrequencyToMarker(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ReceiverSynchronizeBargraphFrequencyToSpecifiedMarker(
                            ViSession instrSession,
                            ViInt32   marker);

ViStatus _VI_FUNC rsfph_ConfigureReceiverTraceStyle(ViSession instrSession,
                                                    ViInt32   traceStyle);

ViStatus _VI_FUNC rsfph_ConfigureReceiverCISPRBandwidth(ViSession instrSession,
                                                        ViBoolean autoo,
                                                        ViReal64  bandwidth);

ViStatus _VI_FUNC rsfph_ConfigureReceiverFrequencyScale(ViSession instrSession,
                                                        ViInt32   frequencyScale);

ViStatus _VI_FUNC rsfph_CalibrationStep(ViSession instrSession,
                                        ViInt32   step,
                                        ViInt32   *result,
                                        ViUInt32  timeout);

ViStatus _VI_FUNC rsfph_QueryCalibrationMode(ViSession instrSession,
                                             ViInt32   *mode);

ViStatus _VI_FUNC rsfph_QueryCalibrationStatus(ViSession instrSession,
                                               ViInt32   *status);

ViStatus _VI_FUNC rsfph_ConfigureSystemPresetCalibrationDiscardEnabled(
                            ViSession instrSession,
                            ViBoolean calibrationDiscardEnabled);

ViStatus _VI_FUNC rsfph_SetSpectrumEmissionMaskPreset(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureSpectrumEmissionMaskStandard(
                            ViSession instrSession,
                            ViString  fileName);

ViStatus _VI_FUNC rsfph_ConfigureSpectrumEmissionMaskSweepMode(
                            ViSession instrSession,
                            ViInt32   sweepMode);

ViStatus _VI_FUNC rsfph_SetVectorNetworkAnalyzerMode(ViSession instrSession);

ViStatus _VI_FUNC rsfph_ConfigureVNAMeasurement(ViSession instrSession,
                                                ViInt32   VNAConfiguration);

ViStatus _VI_FUNC rsfph_ConfigureVNAInterferenceSuppresion(ViSession instrSession,
                                                           ViBoolean enable,
                                                           ViBoolean autoSize,
                                                           ViInt32   size);

ViStatus _VI_FUNC rsfph_ConfigureDTFSettingsCouplingEnabled(ViSession instrSession,
                                                            ViBoolean settingsCouplingEnabled);

ViStatus _VI_FUNC rsfph_ConfigureDTFCableModelPreset(ViSession instrSession,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsfph_ConfigureDTFMeasurementDistances(ViSession instrSession,
                                                         ViReal64  startDistance,
                                                         ViReal64  stopDistance);

ViStatus _VI_FUNC rsfph_ConfigureDTFListThreshold(ViSession instrSession,
                                                  ViReal64  threshold);

ViStatus _VI_FUNC rsfph_QueryDTFPeakCount(ViSession instrSession,
                                          ViInt32   *peakCount);

ViStatus _VI_FUNC rsfph_QueryDTFPeakListResults(ViSession instrSession,
                                                ViInt32   arraySizes,
                                                ViReal64  peakDistances[],
                                                ViReal64  returnLosses[],
                                                ViInt32   *peakCount);

ViStatus _VI_FUNC rsfph_ConfigureDTFDisplayEnabled(ViSession instrSession,
                                                   ViBoolean enabled);

ViStatus _VI_FUNC rsfph_ConfigureVNACableLossFormat(ViSession instrSession,
                                                    ViReal64  referenceLevel,
                                                    ViInt32   referencePosition,
                                                    ViReal64  yAxisRange);

ViStatus _VI_FUNC rsfph_ConfigureVNAReturnLossFormat(ViSession instrSession,
                                                     ViReal64  referenceLevel,
                                                     ViInt32   referencePosition,
                                                     ViInt32   yAxisScale,
                                                     ViReal64  logRange);

ViStatus _VI_FUNC rsfph_ConfigureVNAPhaseFormat(ViSession instrSession,
                                                ViReal64  referenceLevel,
                                                ViInt32   referencePosition,
                                                ViBoolean unwrappingEnabled,
                                                ViReal64  yAxisRange);

ViStatus _VI_FUNC rsfph_ConfigureVNASWRYAxisRange(ViSession instrSession,
                                                  ViReal64  yAxisRange);

ViStatus _VI_FUNC rsfph_ConfigureVNASWRYAxisMinMax(ViSession instrSession,
                                                   ViReal64  yAxisMinimum,
                                                   ViReal64  yAxisMaximum);

ViStatus _VI_FUNC rsfph_ConfigureSmithChartReferenceImpedanceMarker(
                            ViSession instrSession,
                            ViReal64  referenceImpedance);

ViStatus _VI_FUNC rsfph_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   enable,
                                          ViInt32   PTransition,
                                          ViInt32   NTransition);

ViStatus _VI_FUNC rsfph_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   registerPart,
                                          ViInt32*  registerValue);

ViStatus _VI_FUNC rsfph_SetStatusRegisterBit(ViSession instrSession,
                                             ViInt32   registerOperation,
                                             ViInt32   bitNumber,
                                             ViInt32   enable,
                                             ViInt32   PTransition,
                                             ViInt32   NTransition);

ViStatus _VI_FUNC rsfph_GetStatusRegisterBit(ViSession instrSession,
                                             ViInt32   registerOperation,
                                             ViInt32   bitNumber,
                                             ViInt32   registerPart,
                                             ViInt32*  registerValue);

ViStatus _VI_FUNC rsfph_reset(ViSession instrSession);

ViStatus _VI_FUNC rsfph_self_test(ViSession instrSession,
                                  ViInt16*  selfTestResult,
                                  ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rsfph_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsfph_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[]);

ViStatus _VI_FUNC rsfph_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rsfph_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking);

ViStatus _VI_FUNC rsfph_ConfigureStatusChecking(ViSession instrSession,
                                                ViBoolean statusChecking);

ViStatus _VI_FUNC rsfph_ConfigureRangeChecking(ViSession instrSession,
                                               ViBoolean rangeChecking);

ViStatus _VI_FUNC rsfph_SetOPCTimeout(ViSession instrSession,
                                      ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rsfph_GetOPCTimeout(ViSession instrSession,
                                      ViUInt32* timeout);

ViStatus _VI_FUNC rsfph_SetVISATimeout(ViSession instrSession,
                                       ViUInt32  VISATimeout);

ViStatus _VI_FUNC rsfph_GetVISATimeout(ViSession instrSession,
                                       ViUInt32* VISATimeout);

ViStatus _VI_FUNC rsfph_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsfph_IDQueryResponse(ViSession instrSession,
                                        ViUInt32  bufferSize,
                                        ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rsfph_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsfph_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC);

ViStatus _VI_FUNC rsfph_SetFastSweepMode(ViSession instrSession,
                                         ViInt32   fastSweepMode);

ViStatus _VI_FUNC rsfph_GetError(ViSession instrSession,
                                 ViStatus* code,
                                 ViInt32   bufferSize,
                                 ViChar    description[]);

ViStatus _VI_FUNC rsfph_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsfph_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination);

ViStatus _VI_FUNC rsfph_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  source,
                                                 ViString  destination);

ViStatus _VI_FUNC rsfph_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer);

ViStatus _VI_FUNC rsfph_ReadInstrData(ViSession instrSession,
                                      ViInt32   numberOfBytesToRead,
                                      ViChar    readBuffer[],
                                      ViUInt32* numBytesRead);

ViStatus _VI_FUNC rsfph_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value);

ViStatus _VI_FUNC rsfph_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value);

ViStatus _VI_FUNC rsfph_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value);

ViStatus _VI_FUNC rsfph_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[]);

ViStatus _VI_FUNC rsfph_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rsfph_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsfph_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsfph_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsfph_close(ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSFPH_HEADER */

