/*****************************************************************************
 *  Rohde&Schwarz FSH instrument driver
 *  VXIpnp Style Instrument Driver
 *  Original Release: July 2016
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/
#include "rsfph.h"
#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI

#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
        #include <windows.h>
#endif
#if defined (_CVI_)
    #include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/
//static ViString listFilterTypeArr[] = {"NORM","CFIL","RRC","FFT","PULS"};
static ViString gsAbsRelArr[] = {"ABS","REL",NULL};
static ViString gsXUnitArr[] = {"HZ","S","M",NULL};
static ViString gsYUnitArr[] = {"DB","DBM","DBMV","DBUV","V","W","DBUVM","DBUAM","V_M","W_M2","VSWR",NULL};
static ViString powerMeasurementArr[] = {"CPOW","MCAC","OBAN","TDMA", NULL};
static ViString resultsArr[] = { "PASSED", "FAILED", NULL };

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 *- Utility Functions Declaration (Non-Exportable Functions) ----------------*
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_RsClose (ViSession instrSession);

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/
/// HIFN  This function performs the following initialization actions:
/// HIFN
/// HIFN     - Creates a new IVI instrument driver session.
/// HIFN
/// HIFN     - Opens a session to the specified device using the interface and
/// HIFN  address you specify for the Resource Name parameter.
/// HIFN
/// HIFN     - If the ID Query parameter is set to VI_TRUE, this function queries
/// HIFN  the instrument ID and checks that it is valid for this instrument
/// HIFN  driver.
/// HIFN
/// HIFN     - If the Reset parameter is set to VI_TRUE, this function resets the
/// HIFN  instrument to a known state.
/// HIFN
/// HIFN     - Sends initialization commands to set the instrument to the state
/// HIFN  necessary for the operation of the instrument driver.
/// HIFN
/// HIFN     - Returns a ViSession handle that you use to identify the instrument
/// HIFN  in all subsequent instrument driver function calls.
/// HIFN
/// HIFN     Note:  This function creates a new session each time you invoke it.
/// HIFN  Although you can open more than one VISA session for the same resource,
/// HIFN  it is best not to do so.  You can use the same session in multiple
/// HIFN  program threads.
/// HIRET Returns the status code of this operation.
/// HIPAR resourceName/Pass the resource name of the device to initialize.
/// HIPAR idQuery/Specify whether you want the instrument driver to perform an ID Query.
/// HIPAR resetDevice/Specify whether you want the to reset the instrument during the
/// HIPAR resetDevice/initialization procedure.
/// HIPAR instrSession/Returns a ViSession handle that you use to identify the instrument in
/// HIPAR instrSession/all subsequent instrument driver function calls.
ViStatus _VI_FUNC rsfph_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice, ViSession *newInstrSession)
{
    ViStatus error = VI_SUCCESS;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                                  VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rsfph_InitWithOptions (resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
    return error;
}

/// HIFN  This function performs the following initialization actions:
/// HIFN
/// HIFN     - Creates a new IVI instrument driver and optionally sets the initial
/// HIFN  state of the following session attributes:
/// HIFN
/// HIFN         RSFPH_ATTR_RANGE_CHECK
/// HIFN         RSFPH_ATTR_QUERY_INSTRUMENT_STATUS
/// HIFN
/// HIFN     - Opens a session to the specified device using the interface and
/// HIFN  address you specify for the Resource Name parameter.
/// HIFN
/// HIFN     - If the ID Query parameter is set to VI_TRUE, this function queries
/// HIFN  the instrument ID and checks that it is valid for this instrument
/// HIFN  driver.
/// HIFN
/// HIFN     - If the Reset parameter is set to VI_TRUE, this function resets the
/// HIFN  instrument to a known state.
/// HIFN
/// HIFN     - Sends initialization commands to set the instrument to the state
/// HIFN  necessary for the operation of the instrument driver.
/// HIFN
/// HIFN     - Returns a ViSession handle that you use to identify the instrument
/// HIFN  in all subsequent instrument driver function calls.
/// HIFN
/// HIFN     Note:  This function creates a new session each time you invoke it.
/// HIFN  Although you can open more than one VISA session for the same resource,
/// HIFN  it is best not to do so.  You can use the same session in multiple
/// HIFN  program threads.
/// HIRET Returns the status code of this operation.
/// HIPAR resourceName/Pass the resource name of the device to initialize.
/// HIPAR idQuery/Specify whether you want the instrument driver to perform an ID Query.
/// HIPAR resetDevice/Specify whether you want the to reset the instrument during the
/// HIPAR resetDevice/initialization procedure.
/// HIPAR optionString/You can use this control to set the initial value of certain
/// HIPAR optionString/attributes for the session.  The following table lists the attributes
/// HIPAR optionString/and the name you use in this parameter to identify the attribute.
/// HIPAR instrSession/Returns a ViSession handle that you use to identify the instrument in
/// HIPAR instrSession/all subsequent instrument driver function calls.
ViStatus _VI_FUNC rsfph_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                            ViBoolean resetDevice,
                                            ViString optionString,
                                            ViPSession newInstrSession)
{
    ViStatus error = VI_SUCCESS;
    RsCoreAttributePtr* attrList = NULL;
    ViSession instrSession = 0;
    RsCoreSessionPtr sessionProperties = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
                                  "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    attrList = (RsCoreAttributePtr *)rsfph_RsCoreAttributeList;

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rsfph", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        rsfph_RsCoreAttributeList, // List of all attributes from the rsxxx_AttrPropertiesList
        rsfph_RsCoreAttributeListLength, // Length of the attributes list
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "FPC1000", VI_FALSE: "FPC" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        100000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSFPH_OPC_TIMEOUT, // OPC timeout
        15000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version is 4.5.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 5, 0));

    checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */

    sessionProperties->autoSystErrQuery = VI_FALSE;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rsfph_RsCoreRepCapTable, rsfph_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // -RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "FPC1000", false : "FPC"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSFPH_SIMULATION_ID_QUERY, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSFPH_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rsfph_reset(instrSession));
    }
    else
    {
        checkErr(rsfph_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSFPH_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    RsCore_AfterErrorInInit(instrSession, sessionProperties, error, newInstrSession);
    return error;
}

/// HIFN This function selects the spectrum analyzer mode.
/// HIRET Document return value here.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetSpectrumMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_SAN),
            2, "Instrument Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the acquisition attributes of the spectrum
/// HIFN  analyzer. Single sweep, continuous sweep and sweep count can be set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepModeContinuous/Turns on/off continuous sweeping.
/// HIPAR numberOfSweeps/The number of sweeps to take.
ViStatus _VI_FUNC rsfph_ConfigureAcquisition(ViSession instrSession,
                                             ViBoolean sweepModeContinuous,
                                             ViInt32   numberOfSweeps)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SWEEP_MODE, sweepModeContinuous),
            2, "Sweep Mode Continuous");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_NUMBER_OF_SWEEPS, numberOfSweeps),
            3, "Number Of Sweeps");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the acquisition sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepModeContinuous/Turns on/off continuous sweeping.
ViStatus _VI_FUNC rsfph_ConfigureSweepMode(ViSession instrSession,
                                           ViBoolean sweepModeContinuous)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SWEEP_MODE, sweepModeContinuous),
            2, "Sweep Mode Continuous");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function switches between frequency domain and time domain in the
/// HIFN  analyzer mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurementDomain/This control sets the measurement domain (frequency or time).
ViStatus _VI_FUNC rsfph_ConfigureFrequencyMeasurementDomain(ViSession instrSession,
                                                            ViInt32   measurementDomain)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_FREQUENCY_DOMAIN, measurementDomain),
            2, "Measurement Domain");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the frequency mode. Select the Channel frequency
/// HIFN  mode only if you want to work with channel tables. In this case, the
/// HIFN  input of the center frequency is not a frequency value, but a channel
/// HIFN  number.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR inputMode/This control selects the frequency mode. Select the Channel frequency
/// HIPAR inputMode/mode only if you want to work with channel tables. In this case, the
/// HIPAR inputMode/input of the center frequency is not a frequency value, but a channel
/// HIPAR inputMode/number.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyInputMode(ViSession instrSession,
                                                    ViInt32   inputMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_FREQUENCY_INPUT_MODE, inputMode),
            2, "Input Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the start/stop frequency of the spectrum
/// HIFN  analyzer
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR startFrequency/The start frequency of the frequency sweep.
/// HIPAR stopFrequency/The stop frequency of the frequency sweep.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyStartStop(ViSession instrSession,
                                                    ViReal64  startFrequency,
                                                    ViReal64  stopFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_START, startFrequency),
            2, "Start Frequency");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_STOP, stopFrequency),
            3, "Stop Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the center/span frequency the spectrum
/// HIFN  analyzer
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR centerFrequency/The center frequency of the frequency sweep.
/// HIPAR span/The frequency span of the frequency sweep.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyCenterSpan(ViSession instrSession,
                                                     ViReal64  centerFrequency,
                                                     ViReal64  span)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_CENTER, centerFrequency),
            2, "Center Frequency");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_SPAN, span),
            3, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the center frequency the spectrum analyzer
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR centerFrequency/The center frequency of the frequency sweep.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyCenter(ViSession instrSession,
                                                 ViReal64  centerFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_CENTER, centerFrequency),
            2, "Center Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the frequency span in the analyzer mode to its
/// HIFN  maximum.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanFull(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FREQUENCY_SPAN_FULL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the span to 0 Hz. The x-axis becomes the time axis
/// HIFN  with the grid lines corresponding to 1/10 of the current sweep time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanZero(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "",
                                             RSFPH_ATTR_FREQUENCY_SPAN,
                                             0.0), 3, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the automatic calculation of the ideal span on and
/// HIFN  off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSpan/This control turns the automatic calculation of the ideal span on and
/// HIPAR autoSpan/off.
ViStatus _VI_FUNC rsfph_ConfigureFrequencySpanAuto(ViSession instrSession,
                                                   ViBoolean autoSpan)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_FREQUENCY_SPAN_AUTO, autoSpan),
            2, "Auto Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function couples the step width of the center frequency to span
/// HIFN  (span >0) or cancels the couplings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR coupling/Couples and decouples the center frequency step size to the span.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyCoupling(ViSession instrSession,
                                                   ViInt32   coupling)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_FREQUENCY_CENTER_LINK, coupling),
            2, "Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the center frequency step size.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR stepSize/Sets the step width of the center frequency.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyStepSize(ViSession instrSession,
                                                   ViReal64  stepSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_FREQUENCY_CENTER_LINK, RSFPH_VAL_CENT_FREQ_LINK_OFF),
            2, "Center Frequency Coupling");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_CENTER_STEP, stepSize),
            2, "Step Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the frequency offset attribute of the
/// HIFN  spectrum analyzer. This function affects the setting of the spectrum
/// HIFN  analyzer's absolute frequencies, such as start, stop, center, and
/// HIFN  marker. It does not affect values, which are the difference of
/// HIFN  frequencies, such as span and delta marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequencyOffset/Frequency offset.
ViStatus _VI_FUNC rsfph_ConfigureFrequencyOffset(ViSession instrSession,
                                                 ViReal64  frequencyOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_FREQUENCY_OFFSET, frequencyOffset),
            2, "Frequency Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the channel table settings.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Set the frequency mode with rsfph_ConfigureFrequencyInputMode to channel after calling this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelLinkDirection/This control selects the link direction for measurements with channel tables.
/// HIPAR channelNumber/Frequency offset.
/// HIPAR channelTableDownlink/This control selects a channel table configured for selected direction signals.
ViStatus _VI_FUNC rsfph_ConfigureChannelTable(ViSession instrSession,
                                              ViInt32   channelLinkDirection,
                                              ViInt32   channelNumber,
                                              ViString  channelTable)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_CHANNEL_LINK_DIRECTION, channelLinkDirection),
            2, "Channel Link Direction");

    if (channelLinkDirection == RSFPH_VAL_DOWN)
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_CHANNEL_TABLE_DOWNLINK, channelTable),
                4, "Channel Table");
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_CHANNEL_TABLE_UPLINK, channelTable),
                4, "Channel Table");
    }

    checkErr(rsfph_ConfigureFrequencyInputMode(instrSession, RSFPH_VAL_FREQ_INPUT_MODE_CHAN));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_CHANNEL_NUMBER, channelNumber),
            3, "Channel Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function automatically scales the vertical axis for optimum
/// HIFN  display results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsfph_ConfigureDisplayAutoscaleOnce(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_DISP_ADJUST, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the reference level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/Defines the reference level.
ViStatus _VI_FUNC rsfph_ConfigureReferenceLevel(ViSession instrSession,
                                                ViReal64  referenceLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_REFERENCE_LEVEL, referenceLevel),
            2, "Reference Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the offset value to the reference level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevelOffset/Specifies the offset value to the reference level.
ViStatus _VI_FUNC rsfph_ConfigureReferenceLevelOffset(ViSession instrSession,
                                                      ViReal64  referenceLevelOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_REFERENCE_LEVEL_OFFSET, referenceLevelOffset),
            2, "Reference Level Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the amplitude units for input, output and display. Pass the
/// HIFN  units you want the spectrum analyzer to use.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR amplitudeUnits/This control selects the unit of the vertical axis.
ViStatus _VI_FUNC rsfph_ConfigureReferenceLevelUnits(ViSession instrSession,
                                                     ViInt32   amplitudeUnits)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_AMPLITUDE_UNITS, amplitudeUnits),
            2, "Amplitude Units");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the display range of the Y axis (level axis) in
/// HIFN  the selected measurement window with logarithmic scaling
/// HIFN  (DISP:TRAC:Y:SPAC LOG) and reference level position.
/// HIFN     For linear scaling, (DISP:TRAC:Y:SPAC LIN | PERC) the display range is
/// HIFN  fixed and cannot be modified.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR range/This control defines the display range of the vertical axis.
/// HIPAR referencePosition/This control defines the position of the reference level on the
/// HIPAR referencePosition/display grid.
ViStatus _VI_FUNC rsfph_ConfigureVerticalRange(ViSession instrSession,
                                               ViReal64  range,
                                               ViReal64  referencePosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DISP_LOG_RANGE, range),
            2, "Range");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DISP_REF_POSITION, referencePosition),
            3, "referencePosition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the vertical scale of analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/This control selects the scaling type of the vertical axis.
ViStatus _VI_FUNC rsfph_ConfigureVerticalScaling(ViSession instrSession,
                                                 ViInt32   verticalScale)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_VERTICAL_SCALE, verticalScale),
            2, "Vertical Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the Y scale (deviation per division) in Hz
/// HIFN  (FM) or percent (AM).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviationPerDivision/This control sets the Y scale (deviation per division) in Hz (FM) or
/// HIPAR deviationPerDivision/percent (AM).
ViStatus _VI_FUNC rsfph_ConfigureDeviationPerDivision(ViSession instrSession,
                                                      ViReal64  deviationPerDivision)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DISPLAY_DEVIATION_PER_DIVISION, deviationPerDivision),
            2, "Deviation Per Division");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the input attenuation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attenuation/This control defines the input attenuation.
/// HIPAR mode/This control selects the attenuation mode.
ViStatus _VI_FUNC rsfph_ConfigureAttenuation(ViSession instrSession,
                                             ViInt32   mode,
                                             ViReal64  attenuation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (mode == RSFPH_VAL_ATT_MODE_MANUAL)
    {
        viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ATTENUATION_AUTO, VI_FALSE),
                2, "Mode");

        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_ATTENUATION, attenuation),
                3, "Attenuation");
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ATTENUATION_AUTO, VI_TRUE),
                2, "Mode");

        viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ATTENUATION_MODE, mode),
                2, "Mode");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute turns the preamplifier on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Turns the preamplifier on and off.
ViStatus _VI_FUNC rsfph_ConfigurePreamplifier(ViSession instrSession,
                                              ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_AMPL_PREAMPLIFIER, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This control selects the nominal input impedance. The set impedance is
/// HIFN  taken into account in all level indications of results.
/// HIFN
/// HIFN     The setting 75  should be selected, if the 50  input impedance is
/// HIFN  transformed to a higher impedance using a 75  adapter of the RAZ type
/// HIFN  (= 25  in series to the input impedance of the instrument). The
/// HIFN  correction value in this case is 1.76 dB = 10 log (75 / 50 ).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR impedance/This control selects the nominal input impedance. The set impedance is
/// HIPAR impedance/taken into account in all level indications of results.
ViStatus _VI_FUNC rsfph_ConfigureInputImpedance(ViSession instrSession,
                                                ViReal64  impedance)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_INPUT_IMPEDANCE, impedance),
            2, "Impedance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the coupling values of the spectrum analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepCoupling/This control selects coupling type.
/// HIPAR couplingValue/Resolution bandwidth:
ViStatus _VI_FUNC rsfph_ConfigureSweepCoupling(ViSession instrSession,
                                               ViInt32   sweepCoupling,
                                               ViReal64  couplingValue)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (sweepCoupling)
    {
        case RSFPH_VAL_COUPLING_RBW:
            viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_RESOLUTION_BANDWIDTH, couplingValue),
                    3, "Coupling Value");
            break;
        case RSFPH_VAL_COUPLING_VBW:
            viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_VIDEO_BANDWIDTH, couplingValue),
                    3, "Coupling Value");
            break;
        case RSFPH_VAL_COUPLING_SWEEP_TIME:
            viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_SWEEP_TIME, couplingValue),
                    3, "Coupling Value");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, sweepCoupling), 2,"Sweep Coupling");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates auto coupling of selected coupling method.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepCoupling/This control selects coupling type.
ViStatus _VI_FUNC rsfph_ConfigureSweepCouplingAuto(ViSession instrSession,
                                                   ViInt32   sweepCoupling)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (sweepCoupling)
    {
        case RSFPH_VAL_COUPLING_RBW:
            viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_RESOLUTION_BANDWIDTH_AUTO, VI_TRUE),
                    2, "Sweep Coupling");
            break;
        case RSFPH_VAL_COUPLING_VBW:
            viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_VIDEO_BANDWIDTH_AUTO, VI_TRUE),
                    2, "Sweep Coupling");
            break;
        case RSFPH_VAL_COUPLING_SWEEP_TIME:
            viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SWEEP_TIME_AUTO, VI_TRUE),
                    2, "Sweep Coupling");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, sweepCoupling), 2,"Sweep Coupling");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the sweep parameters of the spectrum
/// HIFN  analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepTimeAuto/This control sets automatic sweep time.
/// HIPAR time/The length of time to complete one sweep.
/// HIPAR points/Sets defines the number of measurement points for one sweep run.
ViStatus _VI_FUNC rsfph_ConfigureSweep(ViSession instrSession,
                                       ViBoolean sweepTimeAuto,
                                       ViReal64  time)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SWEEP_TIME_AUTO, sweepTimeAuto),
            2, "Sweep Time Auto");
    if (sweepTimeAuto == VI_FALSE)
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_SWEEP_TIME, time),
                3, "Time");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute defines the number of sweeps included in a single
/// HIFN  sweep. It also defines the number of sweeps the R&S Spectrum Rider uses
/// HIFN  to average traces or calculate maximum values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR numberofSweeps/This control defines the number of sweeps included in a single sweep.
/// HIPAR numberofSweeps/It also defines the number of sweeps the R&S Spectrum Rider uses to
/// HIPAR numberofSweeps/average traces or calculate maximum values.
ViStatus _VI_FUNC rsfph_ConfigureNumberOfSweeps(ViSession instrSession,
                                                ViInt32   numberOfSweeps)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_NUMBER_OF_SWEEPS, numberOfSweeps),
            2, "Number Of Sweeps");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the number of measurement points in a single
/// HIFN  sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR points/This control queries the number of measurement points in a single
/// HIPAR points/sweep.
ViStatus _VI_FUNC rsfph_ConfigureSweepPoints(ViSession instrSession,
                                             ViInt32   points)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_SWEEP_POINTS, points),
            2, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the trigger source that causes the spectrum
/// HIFN  analyzer to leave the Wait-for-Trigger state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerSource/This control selects the trigger source.
ViStatus _VI_FUNC rsfph_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the trigger parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR offset/This control defines the length of the trigger delay.
/// HIPAR slope/This control selects the slope of the trigger signal.
ViStatus _VI_FUNC rsfph_ConfigureTrigger(ViSession instrSession,
                                         ViReal64  offset,
                                         ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_TRIGGER_SLOPE, slope),
            3, "Slope");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_TRIGGER_DELAY, offset),
            2, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This control defines the level of the video trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerLevel/This control defines the level of the video trigger.
ViStatus _VI_FUNC rsfph_ConfigureVideoTrigger(ViSession instrSession,
                                              ViReal64  triggerLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_VIDEO_TRIGGER_LEVEL, triggerLevel),
            2, "Trigger Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the clock rate of the internal trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR clock/This control defines the clock rate of the internal trigger.
ViStatus _VI_FUNC rsfph_ConfigureInternalTriggerClock(ViSession instrSession,
                                                      ViReal64  clock)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_TRIGGER_CLOCK, clock),
            2, "Clock");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the external gate parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gatedTrigger/This control turns a gated trigger on and off.
/// HIPAR delay/This control defines the length of the gate delay.
/// HIPAR length/This control defines the gate length.
/// HIPAR time/This control defines the sweep time for the gated trigger.
ViStatus _VI_FUNC rsfph_ConfigureExternalGate(ViSession instrSession,
                                              ViBoolean gatedTrigger,
                                              ViReal64  delay,
                                              ViReal64  length,
                                              ViReal64  time)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_EXTERNAL_GATE, gatedTrigger),
            2, "Gated Trigger");
    if (gatedTrigger)
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_EXTERNAL_GATE_HOLD, delay),
                3, "Delay");

        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_EXTERNAL_GATE_LENGTH, length),
                4, "Length");

        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_EXTERNAL_GATE_TIME, time),
                5, "Time");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute defines the trigger level of the I/Q power trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR level/This control defines the trigger level of the I/Q power trigger.
ViStatus _VI_FUNC rsfph_ConfigureIQTriggerLevel(ViSession instrSession,
                                                ViReal64  level)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_IQ_TRIGGER_LEVEL, level),
            2, "Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function generates a transducer factor <name> using normalized
/// HIFN  trace data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR transducerNumber/Selects the transducer.
/// HIPAR transducerState/This command switches the selected transducer factor on or off.
/// HIPAR transducerName/This control selects a transducer factor. If name does not exist yet,
/// HIPAR transducerName/a new transducer factor is created.
ViStatus _VI_FUNC rsfph_SelectTransducerFactor(ViSession instrSession,
                                               ViInt32   transducerNumber,
                                               ViBoolean transducerState,
                                               ViString  transducerName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, transducerNumber, 1, 2),
            2, "Transducer Number");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "T%ld", transducerNumber);

    if (transducerState)
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_TFAC_SEL_NAME, transducerName),
                4, "Transducer Name");
    }

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_TFAC_STATE, transducerState),
            3, "Transducer State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries transducer units.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR transducerNumber/Selects the transducer.
/// HIPAR unit/This control queries the unit of the current transducer factor.
ViStatus _VI_FUNC rsfph_QueryTransducerFactorUnits(ViSession instrSession,
                                                   ViInt32   transducerNumber,
                                                   ViInt32*  unit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, transducerNumber, 1, 2),
            2, "Transducer Number");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "T%ld", transducerNumber);

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_TFAC_UNIT, unit),
            3, "Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the use of an isotropic antenna on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR transducerNumber/Selects the transducer.
/// HIPAR isotropicAntenna/This control turns the use of an isotropic antenna on and off.
ViStatus _VI_FUNC rsfph_ConfigureTransducerFactorIsotropicAntenna(
                            ViSession instrSession,
                            ViInt32   transducerNumber,
                            ViBoolean isotropicAntenna)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, transducerNumber, 1, 2),
            2, "Transducer Number");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "T%ld", transducerNumber);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_TRANSDUCER_FACTOR_ISOTROPIC_ANTENNA, isotropicAntenna),
            3, "Isotropic Antenna");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the trace to acquire.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR traceState/This attibute turns a trace on and off.
/// HIPAR traceType/This control selects the trace mode.
ViStatus _VI_FUNC rsfph_ConfigureTrace(ViSession instrSession,
                                       ViInt32   trace,
                                       ViBoolean traceState,
                                       ViInt32   traceType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_TRACE_TYPE, traceType),
            4, "Trace Type");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_TRACE_STATE, traceState),
            3, "Trace State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the trace detector.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR detectorTypeAuto/This control couples and decouples the detector to the trace mode.
/// HIPAR detectorType/This control selects a detector function.
ViStatus _VI_FUNC rsfph_ConfigureTraceDetector(ViSession instrSession,
                                               ViInt32   trace,
                                               ViBoolean detectorTypeAuto,
                                               ViInt32   detectorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_DETECTOR_TYPE_AUTO, detectorTypeAuto),
            3, "Detector Type Auto");
    if (detectorTypeAuto == VI_FALSE)
    {
        viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_DETECTOR_TYPE, detectorType),
                4, "Detector Type");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures subtraction of traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR traceMathState/Switches the mathematical relation of traces on or off.
/// HIPAR mode/Defines the mathematical expression for relating traces to trace 1.
ViStatus _VI_FUNC rsfph_ConfigureSubtractTraces(ViSession instrSession,
                                                ViInt32   trace,
                                                ViBoolean traceMathState,
                                                ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_SUBTRACT_TRACES, mode),
            4, "Mode");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_TRACE_MATH_STATE, traceMathState),
            3, "Trace Math State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This method stores the selected trace into the memory trace of the R&S
/// HIFN  Spectrum Rider.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
ViStatus _VI_FUNC rsfph_StoreTraceToMemory(ViSession instrSession,
                                           ViInt32   trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_TRACE_MATH_STORE, NULL),
            2, "Trace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute turns the memory trace on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memoryState/This control turns the memory trace on and off.
/// HIPAR trace/Selects the trace.
ViStatus _VI_FUNC rsfph_ConfigureTraceMemoryState(ViSession instrSession,
                                                  ViInt32   trace,
                                                  ViBoolean memoryState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_TRACE_MEMORY_STATE, memoryState),
            3, "Memory State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the data of a memory trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace
/// HIPAR arraySize/Buffer size.
/// HIPAR memoryData/Memory trace data
/// HIPAR actualPoints/Memory trace data
ViStatus _VI_FUNC rsfph_QueryMemoryTraceData(ViSession instrSession,
                                             ViInt32   trace,
                                             ViInt32   arraySize,
                                             ViReal64  memoryData[],
                                             ViInt32*  actualPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  p2string;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
                    &rsfph_rngTrace, trace, &p2string),
                2, "Trace");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRACe:DATA:MEMory? %s", p2string);

    checkErr(rsfph_dataReadTrace(instrSession, cmd, arraySize, memoryData, actualPoints));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR markerState/Specifies whether the specified marker is enabled.
ViStatus _VI_FUNC rsfph_ConfigureMarker(ViSession instrSession,
                                        ViInt32   trace,
                                        ViInt32   marker,
                                        ViBoolean markerState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_ENABLED, markerState),
            4, "Marker State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the marker display mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR mode/This control selects the marker frequency display mode.
ViStatus _VI_FUNC rsfph_ConfigureMarkerFrequencyDisplayMode(ViSession instrSession,
                                                            ViInt32   trace,
                                                            ViInt32   marker,
                                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_MARKER_FREQ_DISP_MODE, mode),
            4, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns off all the markers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
ViStatus _VI_FUNC rsfph_DisableAllMarkers(ViSession instrSession,
                                          ViInt32   trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_AOFF, NULL),
            2, "All Markers Off");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the type of marker search and performs the
/// HIFN  search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR markerSearch/Specifies the type of marker search type.
ViStatus _VI_FUNC rsfph_MarkerSearch(ViSession instrSession,
                                     ViInt32   trace,
                                     ViInt32   marker,
                                     ViInt32   markerSearch)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    switch (markerSearch)
    {
        case RSFPH_VAL_MARKER_SEARCH_HIGHEST:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_PEAK, NULL),
                    3, "Marker");
            break;
        case RSFPH_VAL_MARKER_SEARCH_MINIMUM:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_PEAK_MIN, NULL),
                    3, "Marker");
            break;
        case RSFPH_VAL_MARKER_SEARCH_NEXT_PEAK:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_PEAK_NEXT, NULL),
                    3, "Marker");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, markerSearch), 4,"Marker Search");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function moves the active marker to the specified horizontal
/// HIFN  position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR markerPosition/Horizontal position.
ViStatus _VI_FUNC rsfph_MoveMarker(ViSession instrSession,
                                   ViInt32   trace,
                                   ViInt32   marker,
                                   ViReal64  markerPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_POSITION, markerPosition),
            4, "Marker Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function makes the selected marker frequency to be the center
/// HIFN  frequency. It can also make the active marker amplitude to be the
/// HIFN  reference level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR instrumentSetting/Specifies the instrument setting to be set from the marker position.
ViStatus _VI_FUNC rsfph_SetInstrumentFromMarker(ViSession instrSession,
                                                ViInt32   trace,
                                                ViInt32   marker,
                                                ViInt32   instrumentSetting)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    switch (instrumentSetting)
    {
        case RSFPH_VAL_INSTRUMENT_SETTING_FREQUENCY_CENTER:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_TO_CENTER, NULL),
                    4, "Marker To Center");
            break;
        case RSFPH_VAL_INSTRUMENT_SETTING_REFERENCE_LEVEL:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MARKER_TO_REFERENCE, NULL),
                    4, "Marker To Reference");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, instrumentSetting), 4, "Instrument Setting");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the horizontal position and the marker amplitude
/// HIFN  level of the selected marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR markerPosition/The horizontal position of the selected marker.
/// HIPAR markerAmplitude/The amplitude value of the selected marker (Amplitude Units or
/// HIPAR markerAmplitude/relative amplitude units for delta markers).
ViStatus _VI_FUNC rsfph_QueryMarker(ViSession instrSession,
                                    ViInt32   trace,
                                    ViInt32   marker,
                                    ViReal64* markerPosition,
                                    ViReal64* markerAmplitude)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_AMPLITUDE, markerAmplitude),
            5, "Marker Amplitude");

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_POSITION, markerPosition),
            4, "Marker Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the search area and search conditions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR searchLimits/Switches between a limited (ON) and unlimited (OFF) search range. The
/// HIPAR searchLimits/function is independent of the selection of a marker.
/// HIPAR searchLimitLeft/Sets the left limit of the search range for markers and delta markers.
/// HIPAR searchLimitLeft/Depending on the x axis domain the indicated value defines a frequency
/// HIPAR searchLimitLeft/(span > 0) or time (span = 0). The function is independent of the
/// HIPAR searchLimitLeft/selection of a marker.
/// HIPAR searchLimitRight/Sets the right limit of the search range for markers and delta
/// HIPAR searchLimitRight/markers. Depending on the x axis domain the indicated value defines a
/// HIPAR searchLimitRight/frequency (span > 0) or time (span = 0). The function is independent of
/// HIPAR searchLimitRight/the selection of a marker.
ViStatus _VI_FUNC rsfph_ConfigMarkerSearchLimits(ViSession instrSession,
                                                 ViInt32   trace,
                                                 ViInt32   marker,
                                                 ViBoolean searchLimits,
                                                 ViReal64  searchLimitLeft,
                                                 ViReal64  searchLimitRight)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);
    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_LIMITS_STATE, searchLimits),
            4, "Search Limits");
    if (searchLimits)
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_LIMITS_LEFT, searchLimitLeft),
                5, "Search Limit Left");

        viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_SEARCH_LIMITS_RIGHT, searchLimitRight),
                6, "Search Limit Right");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute selects the type of information a marker shows.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/This control selects the type of information a marker shows.
ViStatus _VI_FUNC rsfph_ConfigureMarkerMode(ViSession instrSession,
                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_MARKER_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the marker frequency counter on/off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR markerFrequencyCounter/Specifies whether the frequency counter is enabled.
ViStatus _VI_FUNC rsfph_ConfigureMarkerFrequencyCounter(ViSession instrSession,
                                                        ViInt32   trace,
                                                        ViInt32   marker,
                                                        ViBoolean markerFrequencyCounter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_FREQUENCY_COUNTER_STATE, markerFrequencyCounter),
            4, "Marker Frequency Counter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Performs a frequency measurement at the marker position and returns
/// HIFN  the result.
/// HIFN
/// HIFN     To get a valid result, you have to perform a complete sweep with
/// HIFN  synchronization to the sweep end to make sure that the R&S Spectrum
/// HIFN  Rideractually reaches the frequency you want to measure. This is only
/// HIFN  possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR counterFrequency/Returns the result of the frequency counter for the indicated marker.
ViStatus _VI_FUNC rsfph_QueryMarkerFrequencyCounterResult(ViSession instrSession,
                                                          ViInt32   trace,
                                                          ViInt32   marker,
                                                          ViReal64* counterFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_FREQUENCY_COUNTER_RESULT, counterFrequency),
            4, "Counter Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the noise measurement at the marker position on
/// HIFN  and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR state/This control turns the noise measurement at the marker position on and
/// HIPAR state/off.
ViStatus _VI_FUNC rsfph_ConfigureMarkerNoiseMeasurement(ViSession instrSession,
                                                        ViInt32   trace,
                                                        ViInt32   marker,
                                                        ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);
    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_NOISE_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the result of the noise measurement.
/// HIFN
/// HIFN     To get a valid result, you have to perform a complete sweep with
/// HIFN  synchronization to the sweep end before reading out the result. This is
/// HIFN  only possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/This control selects marker.
/// HIPAR trace/Selects the trace.
/// HIPAR result/This control returns the result of the noise measurement.
ViStatus _VI_FUNC rsfph_QueryMarkerNoiseMeasurementResult(ViSession instrSession,
                                                          ViInt32   trace,
                                                          ViInt32   marker,
                                                          ViReal64* result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_NOISE_RESULT, result),
            4, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the N dB function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR ndBState/Switches the "N dB Down" function on or off. Marker 1 is activated
/// HIPAR ndBState/first, if necessary.
/// HIPAR ndBLevel/This control defines the distance of the n dB down markers to the
/// HIPAR ndBLevel/reference marker.
ViStatus _VI_FUNC rsfph_ConfigureNdBPoints(ViSession instrSession,
                                           ViInt32   trace,
                                           ViInt32   marker,
                                           ViBoolean ndBState,
                                           ViReal64  ndBLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);
    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_NDB_STATE, ndBState),
            4, "N dB State");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_NDB_VAL, ndBLevel),
            5, "N dB Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the frequency spacing or bandwidth of the n dB down markers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/This control selects marker.
/// HIPAR trace/Selects the trace.
/// HIPAR ndBResult/Returns the frequency spacing (bandwidth) of the N-dB-down markers.
ViStatus _VI_FUNC rsfph_QueryNdBResult(ViSession instrSession,
                                       ViInt32   trace,
                                       ViInt32   marker,
                                       ViReal64* ndBResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_NDB_RESULT, ndBResult),
            4, "n dB Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This method queries the horizontal position of the n dB down markers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR ndBFrequencyLower/Returns the lower frequency of N dB down markers.
/// HIPAR ndBFrequencyHigher/Returns the higher frequency of N dB down markers.
ViStatus _VI_FUNC rsfph_QueryNdBFrequencies(ViSession instrSession,
                                            ViInt32   trace,
                                            ViInt32   marker,
                                            ViReal64* ndBFrequencyLower,
                                            ViReal64* ndBFrequencyHigher)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:FUNC:NDBD:FREQ?", trace, marker);
    checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, ndBFrequencyLower, ndBFrequencyHigher, NULL, NULL));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures marker demodulation parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR state/This control switches on or off the audio demodulator when the
/// HIPAR state/indicated marker is reached. In the frequency domain (span > 0) the
/// HIPAR state/hold time can be defined at the corresponding marker position with
/// HIPAR state/Holdoff argument.
/// HIPAR demodulationType/Selects the demodulation type for the audio demodulator.
/// HIPAR markerStopTime/This control defines the hold time at the marker position for the
/// HIPAR markerStopTime/demodulation with span > 0.
ViStatus _VI_FUNC rsfph_ConfigureMarkerDemodulation(ViSession instrSession,
                                                    ViInt32   trace,
                                                    ViInt32   marker,
                                                    ViBoolean state,
                                                    ViInt32   demodulationType,
                                                    ViReal64  markerStopTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,M%ld", trace, marker);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MARKER_DEMOD_STATE, state),
            4, "State");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_MARKER_DEMOD_TYPE, demodulationType),
            5, "Demodulation Type");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MARKER_DEMOD_HOLDOFF, markerStopTime),
            6, "Marker Stop Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the power measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR state/This control sets the state of selected power measurement.
/// HIPAR powerMeasurement/This control selects a power measurement.
ViStatus _VI_FUNC rsfph_SelectPowerMeasurement(ViSession instrSession,
                                               ViInt32   trace,
                                               ViInt32   marker,
                                               ViBoolean state,
                                               ViInt32   powerMeasurement)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_SELECT,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_SELECT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    if (state == VI_FALSE)
    {
        checkErr(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MEAS_POW_OFF, NULL));
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_MEAS_POW_SELECT, powerMeasurement),
                5, "Power Measurement");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects one of the predefined configurations for a
/// HIFN  telecommunications standard. The configuration for a standard is in
/// HIFN  line with the specifications and includes parameters like weighting
/// HIFN  filter, channel bandwidth and spacing, resolution and video bandwidth,
/// HIFN  as well as detector and sweep time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR standard/Selects one of the predefined configurations for a telecommunications
/// HIPAR standard/standard.
ViStatus _VI_FUNC rsfph_ConfigurePowerStandard(ViSession instrSession,
                                               ViInt32   trace,
                                               ViInt32   marker,
                                               ViString  standard)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MEAS_POW_STANDARD, standard),
            4, "Standard");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function checks if the current settings are in line with the
/// HIFN  settings defined by the standard selected with
/// HIFN  RSFPH_ATTR_MEAS_POW_STANDARD. Note that the command only checks those
/// HIFN  parameters that are defined by the standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR standardCheck/This control checks if the current settings are in line with the
/// HIPAR standardCheck/settings defined by the standard selected with
/// HIPAR standardCheck/RSFPH_ATTR_MEAS_POW_STANDARD.
ViStatus _VI_FUNC rsfph_QueryPowerStandardCheck(ViSession instrSession,
                                                ViInt32   trace,
                                                ViInt32   marker,
                                                ViInt32*  standardCheck)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD_CHECK,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD_CHECK,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_MEAS_POW_STANDARD_CHECK, standardCheck),
            4, "Standard Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the power measurement results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR powerMeasurement/This control selects a power measurement.
/// HIPAR arraySize/Defines the memory size allocated for Results.
/// HIPAR results/Returns the measured values:
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsfph_QueryPowerMeasurementsResults(ViSession instrSession,
                                                      ViInt32   trace,
                                                      ViInt32   marker,
                                                      ViInt32   powerMeasurement,
                                                      ViInt32   arraySize,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, powerMeasurement, RSFPH_VAL_MEAS_POW_CPOW, RSFPH_VAL_MEAS_POW_TDMA),
            4, "powerMeasurement");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 0), 5, "Array Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 6, "Results");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:FUNC:POW:RES? %s", trace, marker, powerMeasurementArr[powerMeasurement]);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, arraySize, results, returnedValues));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function adjusts the reference level to the measured signal
/// HIFN  power. This automatic routine makes sure that the signal power level
/// HIFN  does not overload the R&S Spectrum Rider or limits the dynamic range by
/// HIFN  too small an S/N ratio. To determine the best reference level, the R&S
/// HIFN  Spectrum Rider aborts current measurements and performs a series of
/// HIFN  test sweeps. After it has finished the test, it continues with the
/// HIFN  actual measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_AdjustPowerReferenceLevel(ViSession instrSession,
                                                  ViInt32   trace,
                                                  ViInt32   marker,
                                                  ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViUInt32 old_timeout = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD_CHECK,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MEAS_POW_STANDARD_CHECK,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    checkErr(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_MEAS_POW_ADJUST_REFERENCE_LEVEL, NULL));

Error:
    if (old_timeout != 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the ACLR power measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR unit/This control selects the unit of the ACLR results.
/// HIPAR channelMode/This control selects the way the R&S FSH displays the power of
/// HIPAR channelMode/adjacent channels. The number of adjacent and alternate channels has to
/// HIPAR channelMode/be greater than 0 for the command to work.
/// HIPAR noOfAdjChannels/This control defines the number of pairs of adjacent channels.
/// HIPAR noOfTXChannels/This control defines the number of transmission channels. The command
/// HIPAR noOfTXChannels/is available for measurements with span > 0.
ViStatus _VI_FUNC rsfph_ConfigureACLRPower(ViSession instrSession,
                                           ViInt32   channelMode,
                                           ViInt32   noOfAdjChannels,
                                           ViInt32   noOfTXChannels,
                                           ViInt32   unit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_RESULT_UNIT, unit),
            5, "Unit");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_CHANNEL_MODE, channelMode),
            2, "Channel Mode");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_NUMBER_OF_ADJACENT_CHANNELS, noOfAdjChannels),
            3, "No Of Adj Channels");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_COUNT, noOfTXChannels),
            4, "No Of TX Channels");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the ACLR reference channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR reference/This control automatically selects a reference channel for relative
/// HIPAR reference/ACLR measurements. The number of transmission channels and adjacent /
/// HIPAR reference/alternate channels has to be greater than 0 for the command to work.
/// HIPAR channel/This control defines a reference channel for relative ACLR
/// HIPAR channel/measurements. The number of transmission channels and adjacent /
/// HIPAR channel/alternate channels has to be greater than 0 for the command to work.
ViStatus _VI_FUNC rsfph_ConfigureACLRReferenceChannel(ViSession instrSession,
                                                      ViInt32   reference,
                                                      ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (reference == RSFPH_VAL_ADJ_RCHAN_AUTO_MAN)
    {
        viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_AS_REFERENCE_CHANNEL, channel),
                3, "Channel");
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ACLR_REFERENCE_CHANNEL_AUTOMATIC_SELECTION, reference),
                2, "Reference");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the ACLR spacing settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects the channel type.
/// HIPAR channelNumber/Sets the channel number.
/// HIPAR spacing/Sets the selected channel spacing.
ViStatus _VI_FUNC rsfph_ConfigureACLRSpacing(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   channelNumber,
                                             ViReal64  spacing)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   attr[] = {RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_SPACING,
             RSFPH_ATTR_ACLR_ADJACENT_CHANNEL_SPACING,
             RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_SPACING};
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    switch (channel)
    {
        case RSFPH_VAL_ACP_TX:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelNumber, 1, 12),
                    3, "Channel Number");
            viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_ACLR_TRANSMISSION_CHANNEL_SPACING,
                    "TXChannel", channelNumber - 1, RS_REPCAP_BUF_SIZE, repCap),
                    3, "Channel Number");
        break;
        case RSFPH_VAL_ACP_ALT:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelNumber, 1, 11),
                    3, "Channel Number");
            viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_SPACING,
                    "AlternateChannel", channelNumber - 1, RS_REPCAP_BUF_SIZE, repCap),
                    3, "Channel Number");
        break;
        case RSFPH_VAL_ACP_ADJ:

        break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, channel), 2, "Channel");
    }

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, attr[channel], spacing),
            4, "Spacing");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the ACLR bandwidth settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects the channel type.
/// HIPAR channelNumber/Sets the channel number.
/// HIPAR bandwidth/Sets the selected channel bandwidth.
ViStatus _VI_FUNC rsfph_ConfigureACLRBandwidth(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   channelNumber,
                                               ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   attr[] = {RSFPH_ATTR_ACLR_CHANNEL_BANDWIDTH,
             RSFPH_ATTR_ACLR_ADJACENT_CHANNEL_BANDWIDTH,
             RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_BANDWIDTH};
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    switch (channel)
    {
        case RSFPH_VAL_ACP_ALT:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelNumber, 1, 11),
                    3, "Channel Number");
            viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_ACLR_ALTERNATE_CHANNEL_BANDWIDTH,
                    "AlternateChannel", channelNumber - 1, RS_REPCAP_BUF_SIZE, repCap),
                    3, "Channel Number");
        break;
        case RSFPH_VAL_ACP_ADJ:
        case RSFPH_VAL_ACP_TX:

        break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, channel), 2, "Channel");
    }

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, attr[channel], bandwidth),
            4, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function adjusts the reference level to the measured signal
/// HIFN  power. This automatic routine makes sure that the that the signal power
/// HIFN  level does not overload the R&S FPH or limit the dynamic range by too
/// HIFN  small a S/N ratio. To determine the best reference level, the R&S FPH
/// HIFN  aborts current measurements and performs a series of test sweeps. After
/// HIFN  it has finished the test, it continues with the actual measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_AdjustACLRReferenceLevel(ViSession instrSession,
                                                 ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 old_timeout = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_ACLR_ADJUST_REFERENCE_LEVEL, NULL));

Error:
    if (old_timeout != 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the total TX channel power.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR totalTXChannelPower/This control queries the total TX channel power.
ViStatus _VI_FUNC rsfph_QueryACLRTotalTXChannelPower(ViSession instrSession,
                                                     ViReal64* totalTXChannelPower)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_ACLR_TOTAL_TX_CHANNEL_POWER, totalTXChannelPower),
            2, "Total TX Channel Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the limit check for ACLR measurements on and off.
/// HIFN  You have to use RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK_STATE or
/// HIFN  RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK_STATE in combination
/// HIFN  with this command to select the channels the limit check should be
/// HIFN  performed on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limitCheckState/This control turns the limit check for ACLR measurements on and off.
/// HIPAR limitCheckState/You have to use CALCulate:LIMit<k>:ACPower:ACHannel[:RELative]:STATe
/// HIPAR limitCheckState/<State> or CALCulate:LIMit<k>:ACPower:ALTernate<y>[:RELative]:STATe
/// HIPAR limitCheckState/<State> in combination with this command to select the channels the
/// HIPAR limitCheckState/limit check should be performed on.
ViStatus _VI_FUNC rsfph_ConfigureACLRLimitCheckState(ViSession instrSession,
                                                     ViBoolean limitCheckState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE, limitCheckState),
            2, "Limit Check State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the limit value of the adjacent channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR relativeState/This control turns the relative limit check for the adjacent channels
/// HIPAR relativeState/on and off. You have to activate the general ACLR limit check before
/// HIPAR relativeState/using this control with RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE first.
/// HIPAR relativeValue/This control defines the relative limit of the adjacent channels. The
/// HIPAR relativeValue/reference value for the relative limit value is the measured channel
/// HIPAR relativeValue/power. Note that the relative limit has no effect on the limit check if
/// HIPAR relativeValue/it is below the absolute limit value (see
/// HIPAR relativeValue/RSFPH_ATTR_ACLR_ABSOLUTE_LIMIT_CHECK). This mechanism allows automatic
/// HIPAR relativeValue/checking of the absolute basic values of adjacent-channel power as
/// HIPAR relativeValue/defined in mobile radio standards.
/// HIPAR absoluteState/This control turns the absolute limit check for the adjacent channels
/// HIPAR absoluteState/on and off. You have to activate the general ACLR limit check before
/// HIPAR absoluteState/using this control with RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE first.
/// HIPAR absoluteValue/This control defines the absolute limit of the adjacent channels. The
/// HIPAR absoluteValue/reference value for the relative limit value is the measured channel
/// HIPAR absoluteValue/power. Note that the relative limit has no effect on the limit check if
/// HIPAR absoluteValue/it is below the absolute limit value (see
/// HIPAR absoluteValue/RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK). This mechanism allows automatic
/// HIPAR absoluteValue/checking of the absolute basic values of adjacent-channel power as
/// HIPAR absoluteValue/defined in mobile radio standards.
ViStatus _VI_FUNC rsfph_ConfigureACLRAdjacentChannelLimitCheck(
                            ViSession instrSession,
                            ViBoolean relativeState,
                            ViReal64  relativeValue,
                            ViBoolean absoluteState,
                            ViReal64  absoluteValue)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK, relativeValue),
            3, "Relative Value");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ACLR_RELATIVE_LIMIT_CHECK_STATE, relativeState),
            2, "Relative State");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_ACLR_ABSOLUTE_LIMIT_CHECK, absoluteValue),
            5, "Absolute Value");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ACLR_ABSOLUTE_LIMIT_CHECK_STATE, absoluteState),
            4, "Absolute State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the limit value of the alternate adjacent
/// HIFN  channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR alternateChannelNumber/Sets the channel number.
/// HIPAR relativeState/This control turns the relative limit check for an alternate channels
/// HIPAR relativeState/on and off. You have to activate the general ACLR limit check before
/// HIPAR relativeState/using this control with RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE first.
/// HIPAR relativeValue/This control defines the relative limit of the alternate channels. The
/// HIPAR relativeValue/reference value for the relative limit value is the measured channel
/// HIPAR relativeValue/power. Note that the relative limit has no effect on the limit check if
/// HIPAR relativeValue/it is below the absolute limit value (see
/// HIPAR relativeValue/RSFPH_ATTR_ACLR_ALTERNATE_ABSOLUTE_LIMIT_CHECK). This mechanism allows
/// HIPAR relativeValue/automatic checking of the absolute basic values of adjacent-channel
/// HIPAR relativeValue/power as defined in mobile radio standards.
/// HIPAR absoluteState/This control turns the absolute limit check for the alternate channels
/// HIPAR absoluteState/on and off. You have to activate the general ACLR limit check before
/// HIPAR absoluteState/using this control with RSFPH_ATTR_ACLR_LIMIT_CHECK_STATE first.
/// HIPAR absoluteValue/This control defines the absolute limit of the alternate channels. The
/// HIPAR absoluteValue/reference value for the relative limit value is the measured channel
/// HIPAR absoluteValue/power. Note that the relative limit has no effect on the limit check if
/// HIPAR absoluteValue/it is below the absolute limit value (see
/// HIPAR absoluteValue/RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK). This mechanism allows
/// HIPAR absoluteValue/automatic checking of the absolute basic values of adjacent-channel
/// HIPAR absoluteValue/power as defined in mobile radio standards.
ViStatus _VI_FUNC rsfph_ConfigureACLRAlternateChannelLimitCheck(
                            ViSession instrSession,
                            ViInt32   alternateChannelNumber,
                            ViBoolean relativeState,
                            ViReal64  relativeValue,
                            ViBoolean absoluteState,
                            ViReal64  absoluteValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, alternateChannelNumber, 1, 11),
            2, "Alternate Channel Number");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK_STATE,
            "AlternateChannel", alternateChannelNumber - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Alternate Channel Number");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK, relativeValue),
            3, "Relative Value");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_ACLR_ALTERNATE_RELATIVE_LIMIT_CHECK_STATE, relativeState),
            2, "Relative State");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_ACLR_ALTERNATE_ABSOLUTE_LIMIT_CHECK, absoluteValue),
            5, "Absolute Value");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_ACLR_ALTERNATE_ABSOLUTE_LIMIT_CHECK_STATE, absoluteState),
            4, "Absolute State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute queries the result of the limit check of the adjacent
/// HIFN  channels. To get a valid result, you have to perform a complete sweep
/// HIFN  with synchronization to the sweep end before reading out the result.
/// HIFN  This is only possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lowerResult/Returns the lower limit result.
/// HIPAR upperResult/Returns the upper limit result.
ViStatus _VI_FUNC rsfph_QueryACLRAdjacentChannelLimitCheckResult(
                            ViSession instrSession,
                            ViInt32*  lowerResult,
                            ViInt32*  upperResult)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  resultIdxs[2];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, lowerResult),
        2, "Lower Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, upperResult),
        3, "Upper Result");

    RsCore_QueryStringIndexesArrayToUserBuffer(instrSession, "CALC:LIM:ACP:ACH:RES?", resultsArr, 2, resultIdxs, NULL);
    *lowerResult = resultIdxs[0];
    *upperResult = resultIdxs[1];

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the result of the limit check of the alternate
/// HIFN  channels. To get a valid result, you have to perform a complete sweep
/// HIFN  with synchronization to the sweep end before reading out the result.
/// HIFN  This is only possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR alternateChannelNumber/Sets the channel number.
/// HIPAR lowerResult/Returns the lower limit result.
/// HIPAR upperResult/Returns the upper limit result.
ViStatus _VI_FUNC rsfph_QueryACLRAlternateChannelLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   alternateChannelNumber,
                            ViInt32*  lowerResult,
                            ViInt32*  upperResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  resultIdxs[2];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, alternateChannelNumber, 1, 11),
            2, "Alternate Channel Number");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, lowerResult),
        3, "Lower Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, upperResult),
        4, "Upper Result");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM:ACP:ALT%ld:RES?", alternateChannelNumber);
    RsCore_QueryStringIndexesArrayToUserBuffer(instrSession, cmd, resultsArr, 2, resultIdxs, NULL);
    *lowerResult = resultIdxs[0];
    *upperResult = resultIdxs[1];

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the channel power measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR bandwidth/This control defines the channel bandwidth for channel power
/// HIPAR bandwidth/measurements.
/// HIPAR displayMode/This control selects the display mode for channel power measurements.
/// HIPAR unit/This control selects the unit of the vertical axis for channel power
/// HIPAR unit/measurements.
/// HIPAR channelPowerPerHertz/This control turns the display of the channel power per Hertz on and
/// HIPAR channelPowerPerHertz/off.
ViStatus _VI_FUNC rsfph_ConfigureChannelPower(ViSession instrSession,
                                              ViInt32   trace,
                                              ViInt32   marker,
                                              ViReal64  bandwidth,
                                              ViInt32   displayMode,
                                              ViInt32   unit,
                                              ViBoolean channelPowerPerHertz)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_CHANNEL_POWER_BANDWIDTH,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_CHANNEL_POWER_BANDWIDTH,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_CHANNEL_POWER_BANDWIDTH, bandwidth),
            4, "Bandwidth");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_CHANNEL_POWER_DISPLAY_MODE, displayMode),
            5, "Display Mode");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_CHANNEL_POWER_UNIT, unit),
            6, "Unit");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_CHANNEL_POWER_PER_HERTZ, channelPowerPerHertz),
            7, "Channel Power Per Hertz");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the harmonic distortion measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/This control turns the harmonic distortion measurement on and off.
/// HIPAR numberOfHarmonics/This control sets the number of harmonics.
ViStatus _VI_FUNC rsfph_ConfigureHarmonicDistortionMeasurement(
                            ViSession instrSession,
                            ViBoolean state,
                            ViInt32   numberOfHarmonics)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_HARMONIC_DISTORTION_STATE, state),
            2, "State");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_HARMONIC_DISTORTION_NO_OF_HARMONICS, numberOfHarmonics),
            3, "Number Of Harmonics");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function optimizes the settings for the harmonic distortion
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_AdjustHarmonicDistortionSettings(ViSession instrSession,
                                                         ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 old_timeout = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_HARMONIC_DISTORTION_ADJUST_SETTINGS, NULL));

Error:
    if (old_timeout != 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the total harmonic distortion of the signal. To
/// HIFN  get a valid result, you have to perform a complete sweep with
/// HIFN  synchronization  to the sweep end before reading out the result. This
/// HIFN  is only possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the type of harmonic distortion.
/// HIPAR harmonicDistortioninpercent/Returns the results of the harmonic distortion in %.
/// HIPAR harmonicDistortionindB/Returns the results of the harmonic distortion in dB.
ViStatus _VI_FUNC rsfph_QueryHarmonicDistortion(ViSession instrSession,
                                                ViInt32   type,
                                                ViReal64* harmonicDistortioninpercent,
                                                ViReal64* harmonicDistortionindB)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViString harmonicDistortionType[] = {"TOT", NULL};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSFPH_VAL_HARMONIC_TOTAL, RSFPH_VAL_HARMONIC_TOTAL),
            2, "Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:MARK:FUNC:HARM:DIST? %s", harmonicDistortionType[type]);
    checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, harmonicDistortioninpercent, harmonicDistortionindB, NULL, NULL));
    checkErr(rsfph_CheckStatus(instrSession));

Error:  
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads out the list of harmonics. The first value is the
/// HIFN  absolute power of the first harmonic in the unit set via UNIT:POWer.
/// HIFN  The other values are relative to the carrier signal and are output in
/// HIFN  dB.
/// HIFN
/// HIFN     A complete sweep with synchronization to sweep end must be performed
/// HIFN  between switching on the function and querying the measured value to
/// HIFN  obtain a valid query result. This is only possible in single sweep
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Number of array points requested.
/// HIPAR positionList/Returns the list of harmonics. The first value is the absolute power
/// HIPAR positionList/of the first harmonic in the unit set via UNIT. The other values are
/// HIPAR positionList/relative to the carrier signal and are output in dB.
/// HIPAR returnedValues/Number of points actually returned in the Position List array.
ViStatus _VI_FUNC rsfph_QueryHarmonicDistortionPositionList(ViSession instrSession,
                                                            ViInt32   arraySize,
                                                            ViReal64  positionList[],
                                                            ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 0), 5, "Array Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, positionList), 6, "Position List");

    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, "CALC:MARK:FUNC:HARM:LIST?", arraySize, positionList, returnedValues));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the AM Modulation Depth measurement on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR amModulationDepth/This control turns the AM Modulation Depth measurement on and off.
ViStatus _VI_FUNC rsfph_ConfigureAMModulationDepth(ViSession instrSession,
                                                   ViInt32   trace,
                                                   ViInt32   marker,
                                                   ViBoolean amModulationDepth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MODULATION_DEPTH_STATE,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MODULATION_DEPTH_STATE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_MODULATION_DEPTH_STATE, amModulationDepth),
            4, "AM Modulation Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the results (in %) of the AM modulation depth
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR marker/This control selects marker.
/// HIPAR result/This control queries the results (in %) of the AM modulation depth
/// HIPAR result/measurement.
ViStatus _VI_FUNC rsfph_QueryAMModulationDepthResult(ViSession instrSession,
                                                     ViInt32   trace,
                                                     ViInt32   marker,
                                                     ViReal64* result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_2[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            3, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MODULATION_DEPTH_RESULT,
            "Trace", trace - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trace");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSFPH_ATTR_MODULATION_DEPTH_RESULT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_2),
            3, "Marker");

    strcat (repCap, ",");
    strcat (repCap, repCap_2);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_MODULATION_DEPTH_RESULT, result),
            4, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the occupied bandwidth measurement.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function is only available for R&S FPC1000.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/This control selects the type of the setting.
/// HIPAR bandwidth/This control defines the value in Hertz or in % based on the Type
/// HIPAR bandwidth/control.
ViStatus _VI_FUNC rsfph_ConfigureOccupiedBandwidth(ViSession instrSession,
                                                   ViInt32   type,
                                                   ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViAttr   attr[] = {RSFPH_ATTR_OCCUPIED_BANDWIDTH_CHANNEL_BANDWIDTH,
             RSFPH_ATTR_OCCUPIED_BANDWIDTH_POWER_PERCENTAGE};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSFPH_VAL_CHAN_BANDWIDTH, RSFPH_VAL_POWER_IN_PCT),
            2, "Type");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", attr[type], bandwidth),
            3, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the burst length of the TDMA signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR burstLength/This control defines the burst length of the TDMA signal.
ViStatus _VI_FUNC rsfph_ConfigureTDMABurstLength(ViSession instrSession,
                                                 ViReal64  burstLength)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_TDMA_BURST_LENGTH, burstLength),
            2, "Burst Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the settings of the isotropic antenna.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/This control turns the use of an isotropic antenna on and off.
/// HIPAR direction/This control selects the direction that the isotropic antenna
/// HIPAR direction/measures.
ViStatus _VI_FUNC rsfph_ConfigureIsotropicAntenna(ViSession instrSession,
                                                  ViBoolean state,
                                                  ViInt32   direction)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ISOTROPIC_ANTENNA_STATE, state),
            2, "State");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ISOTROPIC_ANTENNA_DIRECTION, direction),
            3, "Direction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the third order intermodulation measurement on and
/// HIFN  off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns the third order intermodulation measurement on and
/// HIPAR enabled/off.
ViStatus _VI_FUNC rsfph_ConfigureTOIMeasurementEnabled(ViSession instrSession,
                                                       ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_TOI_MEASUREMENT_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function begins the search for signals to determine the TOI.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ConfigureTOISearch(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, NULL, RSFPH_ATTR_TOI_SEARCH, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the result of the third order intermodulation
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR toiResult/This control queries the result of the third order intermodulation
/// HIPAR toiResult/measurement.
ViStatus _VI_FUNC rsfph_QueryTOIResult(ViSession instrSession,
                                       ViReal64  *TOIResult)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_QUERY_TOI_RESULT, TOIResult));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns marker tracking on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns marker tracking on and off.
ViStatus _VI_FUNC rsfph_ConfigureMarkerTrackingEnabled(ViSession instrSession,
                                                       ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_MARKER_TRACKING_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables the active deltamarker on the specified trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR deltaMarker/This control selects delta marker.
/// HIPAR state/Specifies whether the specified marker is enabled.
ViStatus _VI_FUNC rsfph_ConfigureDeltaMarker(ViSession instrSession,
                                             ViInt32   trace,
                                             ViInt32   deltaMarker,
                                             ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, deltaMarker, 2, 6),
            3, "Delta Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,DM%ld", trace, deltaMarker);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_STATE, state),
            4, "Delta Marker State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns off all the delta markers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
ViStatus _VI_FUNC rsfph_DisableAllDeltaMarkers(ViSession instrSession,
                                               ViInt32   trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld", trace);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_AOFF, NULL),
            2, "Delta Marker All Off");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the type of delta marker search and performs
/// HIFN  the search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deltaMarker/This control selects delta marker.
/// HIPAR trace/Selects the trace.
/// HIPAR markerSearch/Specifies the type of marker search type.
ViStatus _VI_FUNC rsfph_DeltaMarkerSearch(ViSession instrSession,
                                          ViInt32   trace,
                                          ViInt32   deltaMarker,
                                          ViInt32   markerSearch)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, deltaMarker, 2, 6),
            3, "Delta Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,DM%ld", trace, deltaMarker);

    switch (markerSearch)
    {
        case RSFPH_VAL_MARKER_SEARCH_HIGHEST:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_PEAK, NULL),
                    3, "Marker");
            break;
        case RSFPH_VAL_MARKER_SEARCH_MINIMUM:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_MINIMUM, NULL),
                    3, "Marker");
            break;
        case RSFPH_VAL_MARKER_SEARCH_NEXT_PEAK:
            viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_PEAK_NEXT, NULL),
                    3, "Marker");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, markerSearch), 4,"Marker Search");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the delta marker position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR deltaMarker/This control selects delta marker.
/// HIPAR mode/Switches between relative and absolute frequency input of the delta
/// HIPAR mode/marker
/// HIPAR position/Sets the position of selected delta marker.
ViStatus _VI_FUNC rsfph_MoveDeltaMarker(ViSession instrSession,
                                        ViInt32   trace,
                                        ViInt32   deltaMarker,
                                        ViInt32   mode,
                                        ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, deltaMarker, 2, 6),
            3, "Delta Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,DM%ld", trace, deltaMarker);

    switch (mode)
    {
        case RSFPH_VAL_ABS:
            viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_POSITION, position),
                    5, "Position");
            break;
        case RSFPH_VAL_REL:
            viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_REL_POSITION, position),
                    3, "Position");
    break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, mode), 4, "Mode");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the horizontal position and the marker amplitude
/// HIFN  level of the selected delta marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace.
/// HIPAR deltaMarker/This control selects delta marker.
/// HIPAR mode/Switches between absolute and relative position value.
/// HIPAR position/Returns the absolute or relative position of selected delta marker.
/// HIPAR amplitude/Returns the measured value of the selected delta marker. The
/// HIPAR amplitude/corresponding delta marker will be activated, if necessary. The output
/// HIPAR amplitude/is always a relative value referred to marker 1 or to the reference
/// HIPAR amplitude/position (reference fixed active).
ViStatus _VI_FUNC rsfph_QueryDeltaMarker(ViSession instrSession,
                                         ViInt32   trace,
                                         ViInt32   deltaMarker,
                                         ViInt32   mode,
                                         ViReal64* position,
                                         ViReal64* amplitude)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, deltaMarker, 2, 6),
            3, "Delta Marker");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "TR%ld,DM%ld", trace, deltaMarker);

    switch (mode)
    {
        case RSFPH_VAL_ABS:
            viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_POSITION, position),
                    5, "Position");
            break;
        case RSFPH_VAL_REL:
            viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_REL_POSITION, position),
                    3, "Position");
    break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, mode), 4, "Mode");
    }
    viCheckParm(rsfph_GetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_REFERENCE_MARKER_AMPLITUDE, amplitude),
            5, "Amplitude");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the specified display line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Specifies whether selected line is enabled.
/// HIPAR position/Defines position of selected line.
ViStatus _VI_FUNC rsfph_ConfigureDisplayLine(ViSession instrSession,
                                             ViBoolean state,
                                             ViReal64  position)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_DLINE_STATE, state),
            2, "State");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DLINE_POSITION, position),
            3, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function creates new limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit line.
/// HIPAR name/Limit line name.
/// HIPAR xAxisUnits/This control selects the horizontal unit of a limit line.
/// HIPAR description/This control sets the limit line comment.
/// HIPAR xScale/Switches between absolute and relative position value.
/// HIPAR yAxisUnits/Unit of the y-axis.
/// HIPAR arraySize/Defines the size of X Data and Y Data arrays.
/// HIPAR xData/Data points on the x-axis.
/// HIPAR yData/Data points on the y-axis.
ViStatus _VI_FUNC rsfph_CreateLimitLine(ViSession instrSession,
                                        ViInt32   limit,
                                        ViString  name,
                                        ViString  description,
                                        ViInt32   xAxisUnits,
                                        ViInt32   xScale,
                                        ViInt32   yAxisUnits,
                                        ViInt32   arraySize,
                                        ViReal64  xData[],
                                        ViReal64  yData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, xAxisUnits, RSFPH_VAL_LIMIT_X_UNIT_HZ, RSFPH_VAL_LIMIT_X_UNIT_M),
            5, "X Axis Units");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, xScale, RSFPH_VAL_ABS, RSFPH_VAL_REL),
            6, "X Scale");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, yAxisUnits, RSFPH_VAL_LIMIT_Y_UNIT_DBM, RSFPH_VAL_LIMIT_Y_UNIT_VSWR),
            7, "Y Axis Units");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, arraySize, 1, 100),
            8, "Array Size");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM%ld:DEF '%s','%s',%s,%s,%s,",
            limit, name, description, gsXUnitArr[xAxisUnits], gsAbsRelArr[xScale], gsYUnitArr[yAxisUnits]);
    checkErr(RsCore_WriteAsciiViReal64ArraysInterleaved(instrSession, cmd, arraySize, xData, yData, NULL, NULL, NULL, NULL));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures specified limit line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR limitCheckState/This control turns a limit check on and off.
/// HIPAR beep/This control turns the beeper that beeps if a limit line is violated
/// HIPAR beep/on and off.
ViStatus _VI_FUNC rsfph_ConfigureLimitLine(ViSession instrSession,
                                           ViInt32   limit,
                                           ViBoolean limitCheckState,
                                           ViBoolean beep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_LIMIT_STATE, limitCheckState),
            3, "Limit Check State");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, repCap, RSFPH_ATTR_LIMIT_BEEP, beep),
            4, "Beep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures specified limit line for lower check.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR name/This control selects the lower limit line.
ViStatus _VI_FUNC rsfph_ConfigureLowerLimitLine(ViSession instrSession,
                                                ViInt32   limit,
                                                ViString  name)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_LIMIT_LOWER_SELECT, name),
            3, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures specified limit threshold.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR threshold/This control defines the level of a lower threshold limit line.
ViStatus _VI_FUNC rsfph_ConfigureLowerLimitThreshold(ViSession instrSession,
                                                     ViInt32   limit,
                                                     ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_LIMIT_LOWER_THRESHOLD, threshold),
            3, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures specified limit line for upper check.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR name/This control selects the upper limit line.
ViStatus _VI_FUNC rsfph_ConfigureUpperLimitLine(ViSession instrSession,
                                                ViInt32   limit,
                                                ViString  name)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_LIMIT_UPPER_SELECT, name),
            3, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures specified limit threshold
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR threshold/This control defines the level of an upper threshold limit line.
ViStatus _VI_FUNC rsfph_ConfigureUpperLimitThreshold(ViSession instrSession,
                                                     ViInt32   limit,
                                                     ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, repCap, RSFPH_ATTR_LIMIT_UPPER_THRESHOLD, threshold),
            3, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function removes specified limit line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
ViStatus _VI_FUNC rsfph_DeleteLimitLine(ViSession instrSession,
                                        ViInt32   limit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_LIMIT_DELETE, NULL),
            2, "Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This control queries the description of a limit line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR comment/This control returns the description of a limit line.
/// HIPAR bufferSize/Defines size of array in 'Comment'.
/// HIPAR limit/This control selects limit.
ViStatus _VI_FUNC rsfph_QueryLimitLineComment(ViSession instrSession,
                                              ViInt32   limit,
                                              ViInt32   bufferSize,
                                              ViChar    comment[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_GetAttributeViString(instrSession, repCap, RSFPH_ATTR_LIMIT_COMMENT,
            bufferSize, comment),
            3, "Comment");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the horizontal unit of a limit line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR xAxisUnits/This control returns the horizontal unit of a limit line.
ViStatus _VI_FUNC rsfph_QueryLimitLineXUnits(ViSession instrSession,
                                             ViInt32   limit,
                                             ViInt32*  xAxisUnits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_LIMIT_HORIZONTAL_UNIT, xAxisUnits),
            3, "X Axis Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the vertical unit of a limit line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR yAxisUnits/Unit of the y-axis.
ViStatus _VI_FUNC rsfph_QueryLimitLineYUnits(ViSession instrSession,
                                             ViInt32   limit,
                                             ViInt32*  yAxisUnits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_LIMIT_VERTICAL_UNIT, yAxisUnits),
            3, "Y Axis Units");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR colorScheme/This control sets the color scheme of the display.
/// HIPAR brightness/This control sets the brightness of the display backlight.
/// HIPAR dateFormat/This control sets the display date format.
ViStatus _VI_FUNC rsfph_ConfigureDisplay(ViSession instrSession,
                                         ViInt32   colorScheme,
                                         ViReal64  brightness,
                                         ViInt32   dateFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DISP_COLOR, colorScheme),
            2, "Color Scheme");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DISP_BRIGHTNESS, brightness),
            3, "Brightness");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DISP_DATE_FORMAT, dateFormat),
            4, "Date Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute sets the display to the default state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsfph_DisplayColorDefault(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_DISP_COL_PRESET, NULL),
            2, "Display Color Preset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute selects the length unit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR unit/This control selects the length unit.
ViStatus _VI_FUNC rsfph_ConfigureDisplayLengthUnit(ViSession instrSession,
                                                   ViInt32   unit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DISPLAY_UNIT_LENGTH, unit),
            2, "Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Turns the display during remote operation of the R&S FPC on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns the display during remote operation of the R&S FPC
/// HIPAR enabled/on and off.
ViStatus _VI_FUNC rsfph_ConfigureDisplayRemoteOperationEnabled(
                            ViSession instrSession,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_DISPLAY_REMOTE_OPERATION_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This control selects the matching pad connected to the R&S Spectrum
/// HIFN  Rider.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR padtype/This control selects the matching pad connected to the R&S Spectrum
/// HIPAR padtype/Rider.
ViStatus _VI_FUNC rsfph_ConfigurePadType(ViSession instrSession,
                                         ViInt32   padtype)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_PAD_TYPE, padtype),
            2, "Pad Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the volume of the built-in loudspeaker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR keyboardClickVolume/This control sets the volume of the keyboard click noise.
/// HIPAR beeperVolume/This control sets the volume of the system beeper.
/// HIPAR speakerVolume/This control sets the volume of the internal speaker.
ViStatus _VI_FUNC rsfph_ConfigureAudioVolume(ViSession instrSession,
                                             ViReal64  keyboardClickVolume,
                                             ViReal64  beeperVolume,
                                             ViReal64  speakerVolume)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYST_KEYBOARD_CLICK, keyboardClickVolume),
            2, "Keyboard Click Volume");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYST_BEEPER, beeperVolume),
            3, "Beeper Volume");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYST_SPEAKER, speakerVolume),
            4, "Speaker Volume");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns an alert on a power overload on and off. You can
/// HIFN  define the volume of this sound with rsfph_ConfigureAudioVolume (Beeper
/// HIFN  Volume).
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function is only available on R&S FPC1000.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR beepOnPowerOverload/This control turns an alert on a power overload on and off.
ViStatus _VI_FUNC rsfph_ConfigureBeeperOnPowerOverload(ViSession instrSession,
                                                       ViBoolean beepOnPowerOverload)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_BEEPER_ON_POWER_OVERLOAD, beepOnPowerOverload),
            2, "Beep On Power Overload");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the reference oscillator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/This control selects the source of the frequency reference oscillator.
ViStatus _VI_FUNC rsfph_ConfigureReferenceOscillator(ViSession instrSession,
                                                     ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ROSC_SOURCE, source),
            2, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the BNC sockets.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bncMode/This control configures the BNC sockets.
ViStatus _VI_FUNC rsfph_ConfigureBNCMode(ViSession instrSession,
                                         ViInt32   bncMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_BNC_MODE, bncMode),
            2, "BNC Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the system date.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR year/Specifies the year.
/// HIPAR month/Specifies the month.
/// HIPAR day/Specifies the day.
ViStatus _VI_FUNC rsfph_ConfigureSystemDate(ViSession instrSession,
                                            ViInt32   year,
                                            ViInt32   month,
                                            ViInt32   day)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, year, 1980, 2099),
            2, "Year");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, month, 1, 12),
            3, "Month");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, day, 1, 31),
            4, "Day");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:DATE %ld,%ld,%ld", year, month, day);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the system time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR hour/Specifies the hour.
/// HIPAR minute/Specifies the minute.
/// HIPAR second/Specifies the day.
ViStatus _VI_FUNC rsfph_ConfigureSystemTime(ViSession instrSession,
                                            ViInt32   hour,
                                            ViInt32   minute,
                                            ViInt32   second)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hour, 0, 23),
            2, "Hour");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minute, 0, 59),
            3, "Minute");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, second, 0, 59),
            4, "Second");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:TIME %ld,%ld,%ld", hour, minute, second);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a shift of the system time to select another time zone.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR hour/Specifies the hour.
/// HIPAR minute/Specifies the minute.
ViStatus _VI_FUNC rsfph_ConfigureSystemTimeZone(ViSession instrSession,
                                                ViInt32   hour,
                                                ViInt32   minute)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hour, 0, 23),
            2, "Hour");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minute, 0, 59),
            3, "Minute");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:TZON %ld,%ld", hour, minute);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Turns automatic detection of connected measurement accessories on and
/// HIFN  off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR autoDetection/This control turns automatic detection of connected measurement
/// HIPAR autoDetection/accessories on and off.
ViStatus _VI_FUNC rsfph_ConfigureSystemAccessory(ViSession instrSession,
                                                 ViBoolean autoDetection)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SYST_ACCESSORY_AUTO, autoDetection),
            2, "Auto Detection");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the type of measurement accessory, if one is connected to the
/// HIFN  R&S Spectrum Rider (for example a power sensor).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR accessory/This control queries the type of measurement accessory, if one is
/// HIPAR accessory/connected to the R&S Spectrum Rider (for example a power sensor).
ViStatus _VI_FUNC rsfph_QueryDetectedAccessory(ViSession instrSession,
                                               ViInt32*  accessory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_ACCESSORY, accessory),
            2, "Accessory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the data capture.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR mode/This control selects the data types that the R&S Spectrum Rider saves
/// HIPAR mode/when you capture the current measurement data.
ViStatus _VI_FUNC rsfph_ConfigureSystemCapture(ViSession instrSession,
                                               ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_CAPTURE_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the data capture counter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR counter/This control defines the start of the file name counter.
ViStatus _VI_FUNC rsfph_ConfigureSystemCaptureCounter(ViSession instrSession,
                                                      ViString  counter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_CAPTURE_COUNTER, counter),
            2, "Counter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the includes or excludes items from the data capture.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR includeDataset/This control includes or excludes datasets from the data capture.
/// HIPAR includeScreen/This control includes or excludes screenshots from the data capture.
/// HIPAR includeGPXInformation/This control includes or excludes GPX information from the data
/// HIPAR includeGPXInformation/capture.
ViStatus _VI_FUNC rsfph_ConfigureSystemCaptureItems(ViSession instrSession,
                                                    ViBoolean includeDataset,
                                                    ViBoolean includeScreen,
                                                    ViBoolean includeGPXInformation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SYST_CAPTURE_DATASET_STATE, includeDataset),
            2, "Include Dataset");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SYST_CAPTURE_SCREEN_STATE, includeScreen),
            3, "Include Screen");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SYST_CAPTURE_GPX_INFORMATION_STATE, includeGPXInformation),
            4, "Include GPX Information");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the circumstances under which the R&S Spectrum
/// HIFN     Rider saves events.
/// HIFN     Using the commands requires an GPS receiver and a storage device (SD
/// HIFN  card or memory stick).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR storage/This control selects the storage device to save the coordinates to.
/// HIPAR enabled/This control turns saving of your current coordinates in case of
/// HIPAR enabled/certain events on and off.
/// HIPAR source/
ViStatus _VI_FUNC rsfph_ConfigureSavingEvents(ViSession instrSession,
                                              ViBoolean enabled,
                                              ViInt32   storage,
                                              ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_STATE, enabled),
            2, "State");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_STOR_DEV, storage),
            3, "Storage");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_SOURCE, source),
            4, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a time interval that must pass before the R&S Spectrum Rider
/// HIFN  saves another coordinate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR interval/This control defines a distance that you must cover before the R&S
/// HIPAR interval/Spectrum Rider saves another coordinate.
ViStatus _VI_FUNC rsfph_ConfigureSavingEventsInterval(ViSession instrSession,
                                                      ViInt32   interval)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_TIME_INTERVAL, interval),
            2, "Interval");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a distance that you must cover before the R&S Spectrum Rider
/// HIFN  saves another coordinate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR distance/This control defines a distance that you must cover before the R&S
/// HIPAR distance/Spectrum Rider saves another coordinate.
ViStatus _VI_FUNC rsfph_ConfigureSavingEventsDistance(ViSession instrSession,
                                                      ViInt32   distance)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_DISTANCE, distance),
            2, "Distance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the limit check condition that must occur in order to save a
/// HIFN  coordinate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR limitMode/This control selects the limit check condition that must occur in
/// HIPAR limitMode/order to save a coordinate.
ViStatus _VI_FUNC rsfph_ConfigureSavingEventsLimitMode(ViSession instrSession,
                                                       ViInt32   limitMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_SOEVENT_LIMIT_MODE, limitMode),
            2, "Limit Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates a reboot of the R&S Spectrum Rider.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsfph_SystemReboot(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_REBOOT, NULL),
            2, "System Reboot");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function shuts down the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsfph_SystemShutdown(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_SHUTDOWN, NULL),
            2, "System Shutdown");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the preset mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR presetMode/This control selects the preset mode.
ViStatus _VI_FUNC rsfph_ConfigurePresetMode(ViSession instrSession,
                                            ViInt32   presetMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYSTEM_PRESET_MODE, presetMode),
            2, "Preset Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates an instrument reset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_Preset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_PRESET, NULL),
            2, "System Preset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates an instrument reset back to factory settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_FactoryPreset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_FACTORY_PRESET, NULL),
            2, "Factory Preset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a file containing a user defined preset state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/This control specifies the path to the file.
ViStatus _VI_FUNC rsfph_UserPreset(ViSession instrSession,
                                   ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_PRESET_USER, path),
            2, "System Preset User");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the IP address settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dhcp/This control turns the Dynamic Host Configuration Protocol (DHCP) on
/// HIPAR dhcp/and off.
/// HIPAR ipAddress/This control sets the IP address of the R&S Spectrum Rider.
/// HIPAR subnetMask/This control sets the subnet mask of the R&S Spectrum Rider.
/// HIPAR gateway/This control sets the gateway in the LAN.
/// HIPAR port/This control sets the port number for the connection.
ViStatus _VI_FUNC rsfph_ConfigureIPAddress(ViSession instrSession,
                                           ViBoolean dhcp,
                                           ViString  ipAddress,
                                           ViString  subnetMask,
                                           ViString  gateway,
                                           ViInt32   port)
{
    ViStatus error = VI_SUCCESS;
    ViChar   bigCmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViBooleanRange(instrSession, dhcp), 2, "DHCP");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, port, 0, 65535),
            6, "Port");
    if (dhcp)
    {
        viCheckParm(RsCore_InvalidStringLength(instrSession, ipAddress, 7, 15), 3, "IP Address");
        viCheckParm(RsCore_InvalidStringLength(instrSession, subnetMask, 7, 15), 4, "Subnet Mask");
        viCheckParm(RsCore_InvalidStringLength(instrSession, gateway, 0, 15), 5, "Gateway");
    }

    if (dhcp)
    {
        snprintf(bigCmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:SOCK:PORT %ld;DHCP %s", port, (dhcp ? "ON" : "OFF"));
    }
    else
    {
        snprintf(bigCmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:SOCK:ADDR '%s';PORT %ld;:SYST:COMM:LAN:SUBM '%s';GAT '%s';:SYST:COMM:SOCK:DHCP %s", ipAddress, port, subnetMask, gateway, (dhcp ? "ON" : "OFF"));
    }

    checkErr(rsfph_WriteInstrData(instrSession, bigCmd));
    //checkErr(RsCore_CheckStatus(instrSession, error));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the system network IP address info.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR length/Sets the allocated memory length of 'MAC Address' string.
/// HIPAR macAddress/This control queries the MAC address of the R&S Spectrum Rider.
ViStatus _VI_FUNC rsfph_QueryMACAddress(ViSession instrSession,
                                        ViInt32   length,
                                        ViChar    macAddress[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViString(instrSession, "", RSFPH_ATTR_SYST_NETWORK_MAC,
            length, macAddress),
            2, "MAC Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries battery power and power source from instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerSource/This control queries the current R&S Spectrum Rider power source.
/// HIPAR batteryPower/This control queries the remaining power of the battery.
ViStatus _VI_FUNC rsfph_QuerySystemPower(ViSession instrSession,
                                         ViInt32*  powerSource,
                                         ViReal64* batteryPower)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_SYST_POWER_SOURCE, powerSource),
            2, "Power Source");

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYST_BATT_POWER, batteryPower),
            3, "Battery Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the GPS receiver on and off. Note that the GPS
/// HIFN  receiver only works if a connection between the R&S Spectrum Rider and
/// HIFN  a GPS signal transmitter is established.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gpsReceiver/This control turns the GPS receiver on and off. Note that the GPS
/// HIPAR gpsReceiver/receiver only works if a connection between the R&S Spectrum Rider and
/// HIPAR gpsReceiver/a GPS signal transmitter is established.
ViStatus _VI_FUNC rsfph_ConfigureGPSReceiver(ViSession instrSession,
                                             ViBoolean gpsReceiver)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_STATE, gpsReceiver),
            2, "GPS Receiver");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the GPS receiver parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connected/This control queries if the R&S Spectrum Rider is currently connected
/// HIPAR connected/to the GPS receiver.
/// HIPAR correctionFrequency/This control queries the frequency correction factor. The R&S Spectrum
/// HIPAR correctionFrequency/Rider calculates this factor from a reference signal provided by the
/// HIPAR correctionFrequency/GPS receiver. The reference signal is used to determine the deviation
/// HIPAR correctionFrequency/of the internal clock of the instrument. The deviation can be turned
/// HIPAR correctionFrequency/into a correction factor for the measured frequency.
/// HIPAR satellites/This control queries the number of tracked satellites.
/// HIPAR quality/This control queries the quality of the GPS signal.
ViStatus _VI_FUNC rsfph_QueryGPSReceiverData(ViSession  instrSession,
                                             ViBoolean* connected,
                                             ViReal64*  correctionFrequency,
                                             ViInt32*   satellites,
                                             ViInt32*   quality)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViBoolean(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_CONNECTED, connected),
            2, "Connected");

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_CORRECTION_FREQUENCY, correctionFrequency),
            3, "Correction Frequency");

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_SATELLITES, satellites),
            4, "Satellites");

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_QUALITY, quality),
            5, "Quality");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the GPS receiver location coordinates.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR latitudeDegrees/This control queries the latitude degrees of the current position of
/// HIPAR latitudeDegrees/the R&S Spectrum Rider.
/// HIPAR latitudeMinutes/This control queries the latitude minutes of the current position of
/// HIPAR latitudeMinutes/the R&S Spectrum Rider.
/// HIPAR latitudeSeconds/This control queries the latitude seconds of the current position of
/// HIPAR latitudeSeconds/the R&S Spectrum Rider.
/// HIPAR longitudeDegrees/This control queries the longitude degrees of the current position of
/// HIPAR longitudeDegrees/the R&S Spectrum Rider.
/// HIPAR longitudeMinutes/This control queries the longitude minutes of the current position of
/// HIPAR longitudeMinutes/the R&S Spectrum Rider.
/// HIPAR longitudeSeconds/This control queries the longitude seconds of the current position of
/// HIPAR longitudeSeconds/the R&S Spectrum Rider.
/// HIPAR altitude/This control queries the altitude of the current position of the R&S
/// HIPAR altitude/Spectrum Rider.
ViStatus _VI_FUNC rsfph_QueryGPSReceiverCoordinates(ViSession instrSession,
                                                    ViInt32*  latitudeDegrees,
                                                    ViInt32*  latitudeMinutes,
                                                    ViReal64* latitudeSeconds,
                                                    ViInt32*  longitudeDegrees,
                                                    ViInt32*  longitudeMinutes,
                                                    ViReal64* longitudeSeconds,
                                                    ViReal64* altitude)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViString(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_LATITUDE,
            RS_MAX_MESSAGE_BUF_SIZE, response),
            2, "Latitude Error");

    p2buf = strtok(response, ",");
    *latitudeDegrees = atoi(p2buf);

    p2buf = strtok(NULL, ",");
    *latitudeMinutes = atoi(p2buf);

    p2buf = strtok(NULL, ",\n");
    *latitudeSeconds = atof(p2buf);

    viCheckParm(rsfph_GetAttributeViString(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_LONGITUDE,
            RS_MAX_MESSAGE_BUF_SIZE, response),
            2, "Longitude Error");

    p2buf = strtok(response, ",");
    *longitudeDegrees = atoi(p2buf);

    p2buf = strtok(NULL, ",");
    *longitudeMinutes = atoi(p2buf);

    p2buf = strtok(NULL, ",\n");
    *longitudeSeconds = atof(p2buf);

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_ALTITUDE, altitude),
            8, "Altitude");

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries if the current position is valid.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR validPosition/This control queries if the current position is valid.
ViStatus _VI_FUNC rsfph_QueryGPSReceiverValidPosition(ViSession  instrSession,
                                                      ViBoolean* validPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViBoolean(instrSession, "", RSFPH_ATTR_GPS_RECEIVER_VALID_POSITION, validPosition),
            2, "");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the device numbers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Defines the size of buffer in argument 'ID Query Response'.
/// HIPAR materialNumber/This control queries the material number of the device.
/// HIPAR serialNumber/This control queries the serial number of the device.
ViStatus _VI_FUNC rsfph_QueryDeviceNumbers(ViSession instrSession,
                                           ViUInt32  bufferSize,
                                           ViChar    materialNumber[],
                                           ViChar    serialNumber[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViString(instrSession, "", RSFPH_ATTR_SYSTEM_DEVICE_MATERIAL_NUMBER,
            bufferSize, materialNumber),
            2, "Material Number");

    viCheckParm(rsfph_GetAttributeViString(instrSession, "", RSFPH_ATTR_SYSTEM_DEVICE_SERIAL_NUMBER,
            bufferSize, serialNumber),
            3, "Serial Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the device memory information.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/
/// HIPAR total/Queries the size of the memory.
/// HIPAR used/Queries how much memory is currently used.
/// HIPAR free/Queries how much memory is available.
ViStatus _VI_FUNC rsfph_QueryMemoryInfo(ViSession instrSession,
                                        ViInt32   type,
                                        ViReal64* total,
                                        ViReal64* used,
                                        ViReal64* free)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (type)
    {
        case RSFPH_VAL_RAM:
            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_TOTAL_RAM, total),
                    3, "Total");

            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_USED_RAM, used),
                    4, "Used");

            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_FREE_RAM, free),
                    5, "Free");
            break;
        case RSFPH_VAL_STORAGE:
            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_TOTAL_STORAGE, total),
                    3, "Total");

            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_USED_STORAGE, used),
                    4, "Used");

            viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_SYSTEM_FREE_STORAGE, free),
                    5, "Free");
            break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, type), 2, "Type");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*===========================================================================*
 *= rsfph Set/Get/Check Attribute Group Functions ========================*
 *===========================================================================*/

/*****************************************************************************
 * Function: rsfph_SetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to set
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/
/* ViInt32 */
ViStatus _VI_FUNC rsfph_SetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeId,
                                            ViInt32   value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt32(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViInt64 */
ViStatus _VI_FUNC rsfph_SetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeId,
                                            ViInt64   value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rsfph_SetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeId,
                                             ViReal64  value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViReal64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViString */
ViStatus _VI_FUNC rsfph_SetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeId,
                                             ViString  value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViStringOrRawString(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rsfph_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeId,
                                              ViBoolean value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViBoolean(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: rsfph_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rsfph_GetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeId,
                                            ViInt32   *value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt32(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViInt64 */
ViStatus _VI_FUNC rsfph_GetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeId,
                                            ViInt64   *value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rsfph_GetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeId,
                                             ViReal64  *value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViReal64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViString */
ViStatus _VI_FUNC rsfph_GetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeId,
                                             ViInt32   bufSize,
                                             ViChar    attributeValue[])
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringOrRawString(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, bufSize,
        attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rsfph_GetAttributeViBoolean(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeId,
                                              ViBoolean *value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViBoolean(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rsfph_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeId,
                                               ViString  repCapNameId,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeID, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeID,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}

/*****************************************************************************
 * Function: rsfph_CheckAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to check
 *           attribute values directly.  These functions check the value you
 *           specify even if you set the rsfph_ATTR_RANGE_CHECK
 *           attribute to VI_FALSE.  There are typesafe versions for ViInt32,
 *           ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/

/// HIFN  This function selects the data format of the printout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR format/This control selects the file format for screenshots.
ViStatus _VI_FUNC rsfph_ConfigureHardcopyFormat(ViSession instrSession,
                                                ViInt32   format)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_HCOPY_DEVICE_LANG_OUT_FORMAT, format),
            2, "Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines a destination file for the hadcopy output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR name/This control defines the path and file name that the R&S Spectrum
/// HIPAR name/Rider uses for storing screenshots. The path and file name
ViStatus _VI_FUNC rsfph_HardcopySetFileName(ViSession instrSession,
                                            ViString  name)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_HCOPY_FILE_NAME, name),
            2, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Makes a screenshot of the current display contens in png or jpg format
/// HIFN  and stores it on the R&S Spectrum Rider internal memory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_HardcopyPrint(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_HCOPY_PRINT, NULL),
            2, "Hcopy Print Screen");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function takes a screenshot of the current screen content and
/// HIFN  returns it as a jpg in binary format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR destination/This control defines screenshot destination file to which the data
/// HIPAR destination/transfer from instrument to control computer applies.
ViStatus _VI_FUNC rsfph_HardcopyPrintScreenToFile(ViSession instrSession,
                                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, "DISP:FETC?", destination, RS_VAL_TRUNCATE));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  This function provides commands which allow access to the storage
/// HIFN  media of the instrument and for storing and loading various instrument
/// HIFN  settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/This control selects the type of memory operation to be performed.
/// HIPAR source/This control specifies the source of the operation to be performed. If
/// HIPAR source/the operation requires a single parameter, this control specifies that
/// HIPAR source/parameter.
/// HIPAR destination/This control specifies the destination of the operation to be
/// HIPAR destination/performed.
ViStatus _VI_FUNC rsfph_FileManagerOperations(ViSession instrSession,
                                              ViInt32   operation,
                                              ViString  source,
                                              ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch(operation)
    {
        case RSFPH_VAL_FILE_NEW_FOLDER:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_MAKE_DIR, source));
        break;
        case RSFPH_VAL_FILE_COPY:
            viCheckParm(RsCore_InvalidNullPointer(instrSession, destination),
                4, "Destination");

            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:COPY '%s','%s'", source, destination);
            checkErr(RsCore_Write(instrSession, cmd));
            checkErr(rsfph_CheckStatus(instrSession));
        break;

        case RSFPH_VAL_FILE_RENAME:
            viCheckParm(RsCore_InvalidNullPointer(instrSession, destination),
                4, "Destination");

            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:MOVE '%s','%s'", source, destination);
            checkErr(RsCore_Write(instrSession, cmd));
            checkErr(rsfph_CheckStatus(instrSession));
        break;

        case RSFPH_VAL_FILE_DELETE:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_DELETE, source));
        break;

        case RSFPH_VAL_FILE_RDIR:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_DELETE_DIR, source));
        break;

        case RSFPH_VAL_FILE_CDIR:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_EDIT_PATH, source));
        break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, operation), 2, "Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the files of the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Output parameter.
/// HIPAR output/This indicator returns the files of the current directory.
ViStatus _VI_FUNC rsfph_FileDirectory(ViSession instrSession,
                                      ViInt32   bufferSize,
                                      ViChar    output[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, ":MMEM:CAT?", bufferSize, output, NULL));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute queries the directories of the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Output parameter.
/// HIPAR output/This indicator returns the directories of the current directory.
ViStatus _VI_FUNC rsfph_DirectoriesInCurrentDirectory(ViSession instrSession,
                                                      ViInt32   bufferSize,
                                                      ViChar    output[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, ":MMEM:CAT:DIR?", bufferSize, output, NULL));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function allows to provide data set operation for Save/Recall
/// HIFN  items of memory subsystem.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/This control selects the type of memory operation to be performed.
/// HIPAR path/This control specifies the source of the operation to be performed.
ViStatus _VI_FUNC rsfph_DataSetFileOperations(ViSession instrSession,
                                              ViInt32   operation,
                                              ViString  path)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch(operation)
    {
        case RSFPH_VAL_MEM_SAVE:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_SAVE, path));
        break;
        case RSFPH_VAL_MEM_RECALL:
            checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_RECALL, path));
        break;
        case RSFPH_VAL_MEM_SAVE_PC:
            checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, "SYST:SET?", path, RS_VAL_TRUNCATE));
            checkErr(rsfph_CheckStatus(instrSession));
            break;
        case RSFPH_VAL_MEM_SAVE_SCR_PC:
            checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, "SYST:SET:DISP?", path, RS_VAL_TRUNCATE));
            checkErr(rsfph_CheckStatus(instrSession));
            break;
        case RSFPH_VAL_MEM_LOAD_PC:
            checkErr(RsCore_WriteBinaryDataFromFile(instrSession, "SYST:SET", path));
            checkErr(rsfph_CheckStatus(instrSession));
            break;
        case RSFPH_VAL_MEM_SAVE_TO_CSV:
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEMory:STORe:CSV:STATe 1,'%s", path);
            checkErr(RsCore_Write(instrSession, cmd));
            checkErr(rsfph_CheckStatus(instrSession));
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, operation), 2, "Operation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the date of a file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control specifies the path to the file.
/// HIPAR year/Specifies the year.
/// HIPAR month/Specifies the month.
/// HIPAR day/Specifies the day.
ViStatus _VI_FUNC rsfph_ConfigureFileDate(ViSession instrSession,
                                          ViString  path,
                                          ViInt32   year,
                                          ViInt32   month,
                                          ViInt32   day)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, year, 1980, 2099),
            2, "Year");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, month, 1, 12),
            3, "Month");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, day, 1, 31),
            4, "Day");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:FILE:DATE '%s',%ld,%ld,%ld", path, year, month, day);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the time of a file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control specifies the path to the file.
/// HIPAR hour/Specifies the hour.
/// HIPAR minute/Specifies the minute.
/// HIPAR second/Specifies the day.
ViStatus _VI_FUNC rsfph_ConfigureFileTime(ViSession instrSession,
                                          ViString  path,
                                          ViInt32   hour,
                                          ViInt32   minute,
                                          ViInt32   second)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hour, 0, 23),
            2, "Hour");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minute, 0, 59),
            3, "Minute");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, second, 0, 59),
            4, "Second");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:FILE:TIME '%s',%ld,%ld,%ld", path, hour, minute, second);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the read-only attribute of a file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR path/This control specifies the path to the file.
/// HIPAR locked/Enables or disabled write-protection to a dataset.
ViStatus _VI_FUNC rsfph_ConfigureFileLock(ViSession instrSession,
                                          ViString  path,
                                          ViBoolean locked)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (locked)
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_LOCK, path),
                2, "Path");
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_FILE_MANAGER_UNLOCK, path),
                2, "Path");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates a signal acquisition based on the present
/// HIFN  instrument configuration.  It then waits for the acquisition to
/// HIFN  complete, and returns the trace as an array of amplitude values. The
/// HIFN  amplitude array returns data that represent the amplitude of the
/// HIFN  signals of the sweep from the start frequency to the stop frequency (in
/// HIFN  frequency domain, in time domain the amplitude array is ordered from
/// HIFN  beginning of sweep to end). The Amplitude Units attribute determines
/// HIFN  the units of the points in the amplitude array.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) If the spectrum analyzer did not complete the acquisition within
/// HIFN  the time period the user specified with the maxTime parameter, the
/// HIFN  function returns Max Time Exceeded error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace for Detector definition.
/// HIPAR maximumTime/Pass the maximum length of time in which to allow the read waveform
/// HIPAR maximumTime/operation to complete.
/// HIPAR arrayLength/Number of array points requested.
/// HIPAR actualPoints/Number of points actually returned in the Amplitude array and X Array
/// HIPAR actualPoints/array.
/// HIPAR amplitude/A user allocated buffer into which the trace amplitudes is stored.
ViStatus _VI_FUNC rsfph_ReadYTrace(ViSession instrSession,
                                   ViInt32   trace,
                                   ViUInt32  maximumTime,
                                   ViInt32   arrayLength,
                                   ViInt32*  actualPoints,
                                   ViReal64  amplitude[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");

    checkErr(rsfph_Initiate(instrSession, maximumTime));
    checkErr(rsfph_FetchYTrace(instrSession, trace, arrayLength, actualPoints, amplitude));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the trace the spectrum analyzer acquires. The
/// HIFN  trace is from a previously initiated acquisition.  You use the
/// HIFN  rsfph_Initiate function to start an acquisition.
/// HIFN
/// HIFN     You can call the Read Y Trace function instead of the Initiate
/// HIFN  function. This function starts an acquisition, waits for the
/// HIFN  acquisition to complete, and returns the trace in one function call.
/// HIFN
/// HIFN     The array returns data that represents the amplitude of the signals of
/// HIFN  the sweep from the start frequency to the stop frequency (in frequency
/// HIFN  domain, in time domain the amplitude array is ordered from beginning of
/// HIFN  sweep to end).  The Amplitude Units attribute determines the units of
/// HIFN  the points in the amplitude array.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace for Detector definition.
/// HIPAR arrayLength/Number of array points requested.
/// HIPAR actualPoints/Number of points actually returned in the array.
/// HIPAR amplitude/A user allocated buffer into which the trace amplitudes is stored.
ViStatus _VI_FUNC rsfph_FetchYTrace(ViSession instrSession,
                                    ViInt32   trace,
                                    ViInt32   arrayLength,
                                    ViInt32*  actualPoints,
                                    ViReal64  amplitude[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, 1, 2),
            2, "Trace");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRAC? TRACE%ld", trace);
    checkErr(rsfph_dataReadTrace(instrSession, cmd, arrayLength, amplitude, actualPoints));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the peak list of the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace for Detector definition.
/// HIPAR arrayLength/Number of array points requested.
/// HIPAR actualPoints/Number of points actually returned in the array.
/// HIPAR peakList/A user allocated buffer into which the peak list is stored.
ViStatus _VI_FUNC rsfph_FetchPeakList(ViSession instrSession,
                                      ViInt32   arrayLength,
                                      ViInt32*  actualPoints,
                                      ViReal64  peakList[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, "TRAC? LIST", arrayLength, peakList, actualPoints));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the result of a limit check.
/// HIFN
/// HIFN     To get a valid result, you have to perform a complete sweep with
/// HIFN  synchronization to the sweep end before reading out the result. This is
/// HIFN  only possible in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limit/This control selects limit.
/// HIPAR state/This control queries the result of a limit check.
ViStatus _VI_FUNC rsfph_GetLimitCheckResult(ViSession instrSession,
                                            ViInt32   limit,
                                            ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limit, 1, 2),
            2, "Limit");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "L%ld", limit);

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, repCap, RSFPH_ATTR_LIMIT_CHECK_RESULT, state),
            3, "state");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates an acquisition. After calling this function,
/// HIFN  the spectrum analyzer leaves the idle state and waits for a trigger.
/// HIFN
/// HIFN     This function does not check the instrument status. Typically, the
/// HIFN  end-user calls this function only in a sequence of calls to other
/// HIFN  low-level driver functions. The sequence performs one operation. The
/// HIFN  end-user uses the low-level functions to optimize one or more aspects
/// HIFN  of interaction with the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_Initiate(ViSession instrSession,
                                 ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 old_timeout=0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_INIT, NULL));

Error:
    if (old_timeout > 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function aborts a previously initiated measurement and returns
/// HIFN  the spectrum analyzer to the idle state.
/// HIFN
/// HIFN     This function does not check the instrument status. Typically, the
/// HIFN  end-user calls this function only in a sequence of calls to other
/// HIFN  low-level driver functions. The sequence performs one operation. The
/// HIFN  end-user uses the low-level functions to optimize one or more aspects
/// HIFN  of interaction with the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_Abort(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_MEAS_ABORT, NULL),
            2, "Abort");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sends a command to trigger the SpecAn.  Call this
/// HIFN  function if the trigger source is set to software trigger.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) If both the trigger source are not set to software trigger, this
/// HIFN  function returns an error.
/// HIFN
/// HIFN     (2) This function does not check the instrument status.   Typically,
/// HIFN  you call this function only in a sequence of calls to other low-level
/// HIFN  driver functions.  The sequence performs one operation.  You use the
/// HIFN  low-level functions to optimize one or more aspects of interaction with
/// HIFN  the instrument.  If you want to check the instrument status, call the
/// HIFN  rsfph_error_query function at the conclusion of the sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_SendSoftwareTrigger(ViSession instrSession,
                                            ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 old_timeout=0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_INIT_SW_TRIGGER, NULL));

Error:
    if (old_timeout > 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the generation of a CW signal in zero span on and
/// HIFN  off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR zeroSpanEnabled/This control turns the generation of a CW signal in zero span on and
/// HIPAR zeroSpanEnabled/off.
ViStatus _VI_FUNC rsfph_ConfigureZeroSpanEnabled(ViSession instrSession,
                                                 ViBoolean zeroSpanEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_ZERO_SPAN_ENABLED, zeroSpanEnabled),
                2, "Zero Span Enabled")

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the settings for the tracking generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns the tracking generator on and off.
/// HIPAR autoFrequencyEnabled/This control couples the frequency of the CW signal as the center
/// HIPAR autoFrequencyEnabled/frequency of the current measurement.
/// HIPAR frequency/This control defines the frequency of the generated signal.
/// HIPAR frequencyOffset/This control defines a mathematical frequency offset for the tracking
/// HIPAR frequencyOffset/generator.
ViStatus _VI_FUNC rsfph_ConfigureTrackingGenerator(ViSession instrSession,
                                                   ViBoolean enabled,
                                                   ViBoolean autoFrequencyEnabled,
                                                   ViReal64  frequency,
                                                   ViReal64  frequencyOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_ENABLED, enabled),
                2, "Enabled")

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_FREQUENCY, frequency),
                4, "Frequency")

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_FREQUENCY_OFFSET, frequencyOffset),
                5, "Frequency Offset")

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_AUTO_FREQUENCY_ENABLED, autoFrequencyEnabled),
                3, "Auto Frequency Enabled")

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the absolute output level of the tracking
/// HIFN  generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR power/This control defines the absolute output level of the tracking
/// HIPAR power/generator.
ViStatus _VI_FUNC rsfph_ConfigureTrackingGeneratorPower(ViSession instrSession,
                                                        ViReal64  power)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_POWER, power),
                2, "Power")

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the relative output level of the tracking
/// HIFN  generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attenuation/This control defines the relative output level of the tracking
/// HIPAR attenuation/generator.
ViStatus _VI_FUNC rsfph_ConfigureTrackingGeneratorAttenuation(
                            ViSession instrSession,
                            ViReal64  attenuation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL,
                RSFPH_ATTR_TRACKING_GENERATOR_ATTENUATION, attenuation),
                2, "Attenuation")

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the spectrum analyzer mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetPowerMeterMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_PM),
            2, "Instrument Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures power meter frequency settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequency/This control sets the frequency of the power sensor.
/// HIPAR channelBandwidth/This control defines the channel bandwidth.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterFrequency(ViSession instrSession,
                                                     ViReal64  frequency,
                                                     ViReal64  channelBandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_PWM_FREQUENCY, frequency),
            2, "Frequency");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_PWM_CHANNEL_BW, channelBandwidth),
            3, "Channel Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This control starts to zero the power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ZeroPowerMeter(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_PWM_ZERO, NULL),
            2, "PWM Zero");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures power meter reference level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceValue/This control sets the reference value for relative measurements.
/// HIPAR measureToReference/If this control is set to true, current measurement result shall be
/// HIPAR measureToReference/used as the reference level for relative measurements.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterReferenceLevel(ViSession instrSession,
                                                          ViBoolean measureToReference,
                                                          ViReal64  referenceValue)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (measureToReference)
    {
        viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_PWM_MEASURE_TO_REFERENCE, NULL),
                2, "Measure To Reference");
    }
    else
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_PWM_REFERENCE_VALUE, referenceValue),
                3, "Reference Value");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures power meter reference level offset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceValueOffset/This control sets an offset for the reference value.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterReferenceLevelOffset(
                            ViSession instrSession,
                            ViReal64  referenceValueOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_PWM_REFERENCE_VALUE_OFFSET, referenceValueOffset),
            2, "Reference Value Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the unit of the power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerMeterUnits/This control selects the unit of the power sensor.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterUnits(ViSession instrSession,
                                                 ViInt32   powerMeterUnits)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_PWM_UNIT, powerMeterUnits),
            2, "Power Meter Units");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures duration of measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurementTime/This control sets the duration of measurements.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterMeasurementTime(ViSession instrSession,
                                                           ViInt32   measurementTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_PWM_MEASUREMENT_TIME, measurementTime),
            2, "Measurement Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the video bandwidth of the R&S FSH-Z44 power
/// HIFN  sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR videoBandwidth/This control defines the video bandwidth of the R&S FSH-Z44 power
/// HIPAR videoBandwidth/sensor.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterVideoBandwidth(ViSession instrSession,
                                                          ViReal64  videoBandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_PWM_VIDEO_BANDWIDTH, videoBandwidth),
            2, "Video Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures radio communication standards to measurements
/// HIFN  with the power sensor.
/// HIFN     Note that the selection of a standard is available only for the power
/// HIFN  sensors R&S FSH-Z1 and -Z18.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/This control turns the use of a standard on and off.
/// HIPAR standard/This control selects the standard for power sensor measurements.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterStandard(ViSession instrSession,
                                                    ViBoolean state,
                                                    ViInt32   standard)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_PWM_STANDARD_STATE, state),
            2, "State");

    if (state)
    {
        viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_PWM_STANDARD_SELECT, standard),
                3, "Standard");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the forward power display of the power sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR forwardPowerDisplay/This control selects the forward power display of the power sensor.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterFowardPowerDisplay(
                            ViSession instrSession,
                            ViInt32   forwardPowerDisplay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_PWM_FORWARD_POWER_DISPLAY, forwardPowerDisplay),
            2, "Forward Power Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute sets the wavelength when the optical power sensor is
/// HIFN  connected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR wavelength/This control sets the wavelength when the optical power sensor is
/// HIPAR wavelength/connected.
ViStatus _VI_FUNC rsfph_ConfigurePowerMeterWavelength(ViSession instrSession,
                                                      ViInt32   wavelength)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_PWM_WAVELENGTH, wavelength),
            2, "Wavelength");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function  queries the results of measurements with the power
/// HIFN  sensor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arrayLength/Number of array points requested.
/// HIPAR actualPoints/Number of points actually returned in the array.
/// HIPAR results/The return values depend on the power sensor in use.
ViStatus _VI_FUNC rsfph_FetchPowerMeterResults(ViSession instrSession,
                                               ViInt32   arrayLength,
                                               ViInt32*  actualPoints,
                                               ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_dataReadTrace(instrSession, "FETC:PMET?", arrayLength,
                    results, actualPoints));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute queries the results of measurements with the power
/// HIFN  sensor. Returns nothing for R&S FSH-Z1 / R&S FSH-Z18 and the reflected
/// HIFN  power for R&S FSH-Z14 / R&S FSH-Z44.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arrayLength/Number of array points requested.
/// HIPAR actualPoints/Number of points actually returned in the array.
/// HIPAR reflectedResults/Returns the results of measurements with the power sensor. Returns
/// HIPAR reflectedResults/nothing for R&S FSH-Z1 / R&S FSH-Z18 and the reflected power for R&S
/// HIPAR reflectedResults/FSH-Z14 / R&S FSH-Z44.
ViStatus _VI_FUNC rsfph_FetchPowerMeterReflectedResult(ViSession instrSession,
                                                       ViInt32   arrayLength,
                                                       ViInt32   *actualPoints,
                                                       ViReal64  *reflectedResults)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_dataReadTrace(instrSession, "FETC2:PMET?", arrayLength,
                    reflectedResults, actualPoints));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the analog modulation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetAnalogModulationMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_ADEM));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the demodulation bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bandwidth/This control sets the demodulation bandwidth.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationBandwidth(ViSession instrSession,
                                                           ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_BANDWIDTH, bandwidth),
            2, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the FM deemphasis filter,
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/This control switches the FM deemphasis filter on or off.
/// HIPAR timeConstant/This control sets the time constant for the FM deemphasis filter. The
/// HIPAR timeConstant/only supported time constants are 50 us and 75 us.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationDeemphasis(ViSession instrSession,
                                                            ViBoolean state,
                                                            ViReal64  timeConstant)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_DEEMPHASIS_ENABLED, state),
            2, "State");

    if (state == VI_TRUE)
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_DEEMPHASIS_TIME_CONSTANT, timeConstant),
                3, "Time Constant");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the audio lowpass filter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lowpassFilter/This control selects the audio lowpass filter.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationLowpassFilter(
                            ViSession instrSession,
                            ViInt32   lowpassFilter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_AUDIO_LOWPASS_FILTER, lowpassFilter),
            2, "Lowpass Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Only available in FM domain. Sets the reference deviation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceDeviation/Only available in FM domain. This control sets the reference
/// HIPAR referenceDeviation/deviation.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationReferenceDeviation(
                            ViSession instrSession,
                            ViReal64  referenceDeviation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_ANALOG_MODULATION_REFERENCE_DEVIATION, referenceDeviation),
            2, "Reference Deviation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads a limit line for the selected measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR name/This control loads a limit line for the selected measurement mode.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationLimitLine(ViSession instrSession,
                                                           ViString  name)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_SELECT, name),
            2, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function clears the selected limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_DeleteAnalogModulationLimitLine(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_DELETE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the result of a limit check.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limitLineCheckResult/This control queries the result of a limit check.
ViStatus _VI_FUNC rsfph_QueryAnalogModulationLimitCheckResult(
                            ViSession instrSession,
                            ViInt32*  limitLineCheckResult)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_LIMIT_LINE_CHECK_RESULT, limitLineCheckResult),
            2, "Limit Line Check Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the measurement mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR resultDisplay/This control switches the measurement mode.
ViStatus _VI_FUNC rsfph_ConfigureAnalogModulationResultDisplay(
                            ViSession instrSession,
                            ViInt32   resultDisplay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_RESULT_DISPLAY, resultDisplay),
            2, "Result Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the analog modulation results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/This control selects the type.
/// HIPAR result/This control returns the analog modulation results.
ViStatus _VI_FUNC rsfph_QueryAnalogModulationResults(ViSession instrSession,
                                                     ViInt32   type,
                                                     ViReal64* result)
{
    ViStatus                                                 error = VI_SUCCESS;
    ViAttr                                                   attr[] = {RSFPH_ATTR_ANALOG_MODULATION_FM_OFFSET, RSFPH_ATTR_ANALOG_MODULATION_CARRIER_POWER_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_SINAD_RESULT,               RSFPH_ATTR_ANALOG_MODULATION_THD_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_AUDIO_FREQUENCY_RESULT,     RSFPH_ATTR_ANALOG_MODULATION_FREQUENCY_ERROR_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_AM_MODULATION_INDEX_RESULT, RSFPH_ATTR_ANALOG_MODULATION_AM_MAX_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_AM_MIN_RESULT,              RSFPH_ATTR_ANALOG_MODULATION_AM_AVERAGE_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_AM_RMS_RESULT,              RSFPH_ATTR_ANALOG_MODULATION_FM_MAX_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_FM_MIN_RESULT,              RSFPH_ATTR_ANALOG_MODULATION_FM_AVERAGE_RESULT,
    RSFPH_ATTR_ANALOG_MODULATION_FM_RMS_RESULT,              RSFPH_ATTR_ANALOG_MODULATION_AM_MODULATION_DEPTH_RESULT,
                                                             RSFPH_ATTR_ANALOG_MODULATION_FM_MODULATION_RATE_RESULT};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, 0, RSFPH_VAL_ANALOG_RESULT_FM_MODULATION_RATE),
            2, "Type");

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", attr[type], result),
            3, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the measurement time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurementTime/This control queries the measurement time.
ViStatus _VI_FUNC rsfph_QueryAnalogModulationMeasurementTime(ViSession instrSession,
                                                             ViReal64* measurementTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", RSFPH_ATTR_ANALOG_MODULATION_MEASUREMENT_TIME, measurementTime),
            3, "Measurement Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the digital demodulation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetDigitalDemodulationMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_DDEM));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the demodulation scheme of the signal you are
/// HIFN  measuring
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/This control selects the demodulation scheme of the signal you are
/// HIPAR measurement/measuring.
ViStatus _VI_FUNC rsfph_SelectDigitalDemodulationMeasurement(ViSession instrSession,
                                                             ViInt32   measurement)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_SELECT_MEASUREMENT, measurement),
            2, "Measurement");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the digital demodulation parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR symbolRate/This control defines the symbol rate.
/// HIPAR numberofSymbols/This control defines the number of symbols to be evaluated.
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulation(ViSession instrSession,
                                                     ViReal64  symbolRate,
                                                     ViInt32   numberofSymbols)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_SYMBOL_RATE, symbolRate),
            2, "Symbol Rate");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_NUMBER_OF_SYMBOLS, numberofSymbols),
            3, "Number of Symbols");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the digital demodulation filter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/This control turns the measurement filter on and off.
/// HIPAR type/This control selects the measurement filter.
/// HIPAR numberofSymbols/This control defines the roll-off factor of the measurement filter
/// HIPAR numberofSymbols/(alpha or BT value).
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationFilter(ViSession instrSession,
                                                           ViBoolean state,
                                                           ViInt32   type,
                                                           ViReal64  numberofSymbols)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_MEASUREMENT_FILTER, state),
            2, "State");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_FILTER_TYPE, type),
            3, "Type");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_FILTER_ROLL_OFF_FACTOR, numberofSymbols),
            4, "Number of Symbols");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Turns burst processing on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns burst processing on and off.
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationBurstStateEnabled(
                            ViSession instrSession,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_DIGITAL_DEMODULATION_BURST_STATE_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets and queries the frequency deviation in the FSK signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fskFrequencyDeviation/This control sets and queries the frequency deviation in the FSK
/// HIPAR fskFrequencyDeviation/signal.
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationFSKFrequencyDeviation(
                            ViSession instrSession,
                            ViReal64  FSKFrequencyDeviation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_DIGITAL_DEMODULATION_FSK_FREQUENCY_DEVIATION, FSKFrequencyDeviation),
            2, "FSK Frequency Deviation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the result display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR resultDisplay/This control selects the result display.
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationResultDisplay(
                            ViSession instrSession,
                            ViInt32   resultDisplay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_DIGITAL_DEMODULATION_RESULT_DISPLAY, resultDisplay),
            2, "Result Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the digital demodulation results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/This control selects the type.
/// HIPAR result/This control returns the digital demodulation results.
ViStatus _VI_FUNC rsfph_QueryDigitalDemodulationResults(ViSession instrSession,
                                                        ViInt32   type,
                                                        ViReal64* result)
{
    ViStatus                                                        error = VI_SUCCESS;
    ViAttr                                                          attr[] = {RSFPH_ATTR_DIGITAL_DEMODULAITON_FSK_OFFSET, RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_POWER_RESULT,
    RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_FREQUENCY_DRIFT_RESULT, RSFPH_ATTR_DIGITAL_DEMODULATION_CARRIER_FREQUENCY_ERROR_RESULT,
    RSFPH_ATTR_DIGITAL_DEMODULATION_MODULAITON_DEPTH_RESULT,        RSFPH_ATTR_DIGITAL_DEMODULATION_MODULATION_INDEX_RESULT,
    RSFPH_ATTR_DIGITAL_DEMODULATION_MODULATION_ERROR_RESULT,        RSFPH_ATTR_DIGITAL_DEMODULATION_FREQUENCY_DEVIATION_RESULT,
                                                                    RSFPH_ATTR_DIGITAL_DEMODULATION_MAGNITUDE_ERROR_RESULT};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, 0, 8),
            2, "Type");

    viCheckParm(rsfph_GetAttributeViReal64(instrSession, "", attr[type], result),
            3, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the receiver mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetReceiverMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_REC));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the scan range settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR start/This control defines the start frequency of the receiver scan range.
/// HIPAR stop/This control defines the stop frequency of the receiver scan range.
/// HIPAR stepSize/This control defines the step size in the receiver scan range.
ViStatus _VI_FUNC rsfph_ConfigureReceiverScanRange(ViSession instrSession,
                                                   ViReal64  start,
                                                   ViReal64  stop,
                                                   ViReal64  stepSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_RECEIVER_SCAN_RANGE_START, start),
            2, "Start");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_RECEIVER_SCAN_RANGE_STOP, stop),
            3, "Stop");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_RECEIVER_SCAN_RANGE_STEP_SIZE, stepSize),
            4, "Step Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function resets the maxhold information in the fixed frequency
/// HIFN  measurement and the frequency scan.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ReceiverResetMaxholdInformation(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_RECEIVER_RESET_MAXHOLD_INFORMATION, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function synchronizes the bargraph frequency to one of the marker
/// HIFN  frequencies in the frequency scan. At the same, the function switches
/// HIFN  to the fixed frequency measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ReceiverSynchronizeBargraphFrequencyToMarker(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_RECEIVER_SYNCHRONIZE_BARGRAPH_FREQUENCY_TO_MARKER, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This attribute synchronizes the bargraph frequency to one of the
/// HIFN  marker frequencies in the frequency scan. At the same time, the
/// HIFN  attribute switches to the fixed frequency measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/This control selects the marker.
ViStatus _VI_FUNC rsfph_ReceiverSynchronizeBargraphFrequencyToSpecifiedMarker(
                            ViSession instrSession,
                            ViInt32   marker)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 6),
            2, "Marker");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "M%ld", marker);

    checkErr(rsfph_SetAttributeViString(instrSession, repCap, RSFPH_ATTR_RECEIVER_SYNCHRONIZE_BARGRAPH_FREQUENCY_TO_SPECIFIED_MARKER, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the style of the trace display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceStyle/This control selects the style of the trace display.
ViStatus _VI_FUNC rsfph_ConfigureReceiverTraceStyle(ViSession instrSession,
                                                    ViInt32   traceStyle)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_RECEIVER_TRACE_STYLE, traceStyle),
            2, "Trace Style");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the CISPR bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR auto/This control turns automatic selection of the CISPR measurement
/// HIPAR auto/bandwidth on and off.
/// HIPAR bandwidth/This control defines the CISPR (6 dB) bandwidth for CISPR conform
/// HIPAR bandwidth/measurements.
ViStatus _VI_FUNC rsfph_ConfigureReceiverCISPRBandwidth(ViSession instrSession,
                                                        ViBoolean autoo,
                                                        ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_RECEIVER_CISPR_BANDWIDTH_AUTO, autoo),
            2, "Auto");

    if (autoo == VI_FALSE)
    {
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, "", RSFPH_ATTR_RECEIVER_CISPR_BANDWIDTH, bandwidth),
                3, "Bandwidth");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the scale of the x-axis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequencyScale/This control selects the scale of the x-axis.
ViStatus _VI_FUNC rsfph_ConfigureReceiverFrequencyScale(ViSession instrSession,
                                                        ViInt32   frequencyScale)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_RECEIVER_FREQUENCY_SCALE, frequencyScale),
            2, "Frequency Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function performs calibration actions on the R&S FPC1500. The
/// HIFN  return value indicates the next step required to complete the
/// HIFN  calibration process.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR step/This control selects the step.
/// HIPAR result/This control returns the next step in the calibration process.
ViStatus _VI_FUNC rsfph_CalibrationStep(ViSession instrSession,
                                        ViInt32   step,
                                        ViInt32   *result,
                                        ViUInt32  timeout)
{
    ViStatus                         error = VI_SUCCESS;
    ViAttr                           attr[] = { RSFPH_ATTR_ABORT_CALIBRATION,
                                     RSFPH_ATTR_CONTINUE_CALIBRATION,
                                     RSFPH_ATTR_START_FULL_S11_CALIBRATION,
                                     RSFPH_ATTR_START_EASY_S11_CALIBRATION,
    RSFPH_ATTR_START_S21_CALIBRATION };
    ViUInt32                         old_timeout=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, step, RSFPH_VAL_CALIBRATION_ABORT, RSFPH_VAL_CALIBRATION_S21N),
            2, "Step");

    checkErr(rsfph_GetOPCTimeout(instrSession, &old_timeout));
    checkErr(rsfph_SetOPCTimeout(instrSession, timeout));

    if (step == RSFPH_VAL_CALIBRATION_ABORT)
    {
        *result = RSFPH_VAL_CALIBRATION_DONE;
        checkErr(rsfph_SetAttributeViString(instrSession, NULL, attr[step], NULL));
    }
    else
    {
        checkErr(rsfph_GetAttributeViInt32(instrSession, NULL, attr[step], result));
    }

Error:
    if (old_timeout > 0)
        rsfph_SetOPCTimeout(instrSession, old_timeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the current calibration type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Returns the current calibration type.
ViStatus _VI_FUNC rsfph_QueryCalibrationMode(ViSession instrSession,
                                             ViInt32   *mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_QUERY_CALIBRATION_MODE, mode));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries calibration status for the current measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR status/Returns the calibration status for the current measurement.
ViStatus _VI_FUNC rsfph_QueryCalibrationStatus(ViSession instrSession,
                                               ViInt32   *status)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_GetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_QUERY_CALIBRATION_STATUS, status));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This functions turns the mechanism that discards or keeps user
/// HIFN  calibration after a preset (RSFPH_ATTR_SYST_PRESET) on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationDiscardEnabled/This control turns the mechanism that discards or keeps user
/// HIPAR calibrationDiscardEnabled/calibration after a preset (RSFPH_ATTR_SYST_PRESET) on and off.
ViStatus _VI_FUNC rsfph_ConfigureSystemPresetCalibrationDiscardEnabled(
                            ViSession instrSession,
                            ViBoolean calibrationDiscardEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_SYSTEM_PRESET_CALIBRATION_DISCARD_ENABLED, calibrationDiscardEnabled),
            2, "Calibration Discard Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function optimizes the settings for the SEM measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetSpectrumEmissionMaskPreset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViString(instrSession, NULL, RSFPH_ATTR_SPECTRUM_EMISSION_MASK_PRESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads one of the predefined spectrum emission masks for
/// HIFN  a telecommunications standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/The filename on the R&S Spectrum Rider filesystem of one of the
/// HIPAR fileName/predefined spectrum emission masks for a telecommunications standard.
ViStatus _VI_FUNC rsfph_ConfigureSpectrumEmissionMaskStandard(
                            ViSession instrSession,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, NULL, RSFPH_ATTR_SPECTRUM_EMISSION_MASK_STANDARD, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the spectrum emission mask measurement on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sweepMode/This control turns the spectrum emission mask measurement on and off.
ViStatus _VI_FUNC rsfph_ConfigureSpectrumEmissionMaskSweepMode(
                            ViSession instrSession,
                            ViInt32   sweepMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_SPECTRUM_EMISSION_MASK_SWEEP_MODE, sweepMode),
            2, "Sweep Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the Vector Network Analyzer mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_SetVectorNetworkAnalyzerMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_INSTRUMENT_MODE, RSFPH_VAL_INSTRUMENT_NAN));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the measurement mode and format for the Vector
/// HIFN  Network Analysis application of the R&S FPC1500.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR vnaConfiguration/This control selects the measurement mode and format for the Vector
/// HIPAR vnaConfiguration/Network Analysis application of the R&S FPC.
ViStatus _VI_FUNC rsfph_ConfigureVNAMeasurement(ViSession instrSession,
                                                ViInt32   VNAConfiguration)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  mode = 0;
    ViInt32  format = 1;

    checkErr(RsCore_LockSession(instrSession));

    switch(VNAConfiguration) {
        case RSFPH_VAL_VNA_DTF_MAGN:
            mode = RSFPH_VAL_VNA_MEAS_MODE_DTFAULT;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_MAGNITUDE;
            break;
        case RSFPH_VAL_VNA_DTF_VSWR:
            mode = RSFPH_VAL_VNA_MEAS_MODE_DTFAULT;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_VSWR;
            break;
        case RSFPH_VAL_VNA_LOSS_LOSS:
            mode = RSFPH_VAL_VNA_MEAS_MODE_LOSS;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_LOSS;
            break;
        case RSFPH_VAL_VNA_REFL_MAGN:
            mode = RSFPH_VAL_VNA_MEAS_MODE_REFLECTION;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_MAGNITUDE;
            break;
        case RSFPH_VAL_VNA_REFL_PHAS:
            mode = RSFPH_VAL_VNA_MEAS_MODE_REFLECTION;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_PHASE;
            break;
        case RSFPH_VAL_VNA_REFL_SMIT:
            mode = RSFPH_VAL_VNA_MEAS_MODE_REFLECTION;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_SMITH;
            break;
        case RSFPH_VAL_VNA_REFL_VSWR:
            mode = RSFPH_VAL_VNA_MEAS_MODE_REFLECTION;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_VSWR;
            break;
        case RSFPH_VAL_VNA_TRAN_MAGN:
            mode = RSFPH_VAL_VNA_MEAS_MODE_TRANSMISSION;
            format = RSFPH_VAL_VNA_MEAS_FORMAT_MAGNITUDE;
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, VNAConfiguration), 2, "VNA Configuration");
    }

    checkErr(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_MEAS_MODE, mode));
    checkErr(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_MEAS_FORMAT, format));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects one of the available predefined digital standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/Selects one of the available predefined digital standards.
ViStatus _VI_FUNC rsfph_ConfigureDigitalDemodulationStandard(ViSession instrSession,
                                                             ViInt32   standard)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_DIGITAL_DEMODULATION_STANDARD, standard),
            2, "Standard");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Turns interference suppression on and off and selects the aperture size for
/// HINF  interference suppression or uses auto option.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Turns interference suppression on and off.
/// HIPAR autoSize/Turns automatic selection of the aperture size for interference
/// HIPAR autosize/suppression on and off.
/// HIPAR size/Selects the aperture size for interference suppression.
ViStatus _VI_FUNC rsfph_ConfigureVNAInterferenceSuppresion(ViSession instrSession,
                                                           ViBoolean enable,
                                                           ViBoolean autoSize,
                                                           ViInt32   size)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_ENABLED, enable),
            2, "Enable");

    if (enable == VI_TRUE)
    {
        if (autoSize == VI_TRUE)
        {
            viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_AUTO_SIZE_ENABLED, autoSize),
                    3, "Auto Size");
        }
        else
        {
            viCheckParm(rsfph_SetAttributeViBoolean(instrSession, "", RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_AUTO_SIZE_ENABLED, autoSize),
                    3, "Auto Size");

            viCheckParm(rsfph_SetAttributeViInt32(instrSession, "", RSFPH_ATTR_VNA_INTERFERENCE_SUPPRESION_SIZE, size),
                    4, "Size");
        }
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function couples or decouples the frequency settings of the DTF
/// HIFN  measurement to the other VNA measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR settingsCouplingEnabled/This control couples or decouples the frequency settings of the DTF
/// HIPAR settingsCouplingEnabled/measurement to the other VNA measurements.
ViStatus _VI_FUNC rsfph_ConfigureDTFSettingsCouplingEnabled(ViSession instrSession,
                                                            ViBoolean settingsCouplingEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_DTF_SETTINGS_COUPLING_ENABLED, settingsCouplingEnabled),
            2, "Settings Coupling Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a preset cable model.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/The filename on the R&S Spectrum Rider filesystem of a predefined
/// HIPAR fileName/cable models.
ViStatus _VI_FUNC rsfph_ConfigureDTFCableModelPreset(ViSession instrSession,
                                                     ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViString(instrSession, NULL, RSFPH_ATTR_DTF_CABLE_MODEL_PRESET, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the starting and stopping points (distance) of
/// HIFN  the DTF measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR startDistance/This control defines the starting point (distance) of the DTF
/// HIPAR startDistance/measurement.
/// HIPAR stopDistance/This control defines the end point (distance) of the DTF measurement.
ViStatus _VI_FUNC rsfph_ConfigureDTFMeasurementDistances(ViSession instrSession,
                                                         ViReal64  startDistance,
                                                         ViReal64  stopDistance)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_DTF_START_DISTANCE, startDistance),
            2, "Start Distance");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_DTF_STOP_DISTANCE, stopDistance),
            3, "Stop Distance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines a threshold for the DTF list. Only peaks above
/// HIFN  that threshold will appear in the DTF list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR threshold/This control defines a threshold for the DTF list. Only peaks above
/// HIPAR threshold/that threshold will appear in the DTF list.
ViStatus _VI_FUNC rsfph_ConfigureDTFListThreshold(ViSession instrSession,
                                                  ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_DTF_LIST_THRESHOLD, threshold),
            2, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the number of entries in the DTF list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR peakCount/This control queries the number of entries in the DTF list.
ViStatus _VI_FUNC rsfph_QueryDTFPeakCount(ViSession instrSession,
                                          ViInt32*  peakCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_GetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_DTF_PEAK_COUNT, peakCount),
            2, "Peak Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the DTF peak list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySizes/Defines the size of the arrays allocated for the 'Peak Distances' and
/// HIPAR arraySizes/'Return Losses' arrays of doubles.
/// HIPAR peakDistances/This control returns the distance values from the DTF peak list.
/// HIPAR returnLosses/This control returns the return loss values from the DTF peak list.
/// HIPAR peakCount/This control returns the number of entries in the DTF list.
ViStatus _VI_FUNC rsfph_QueryDTFPeakListResults(ViSession instrSession,
                                                ViInt32   arraySizes,
                                                ViReal64  peakDistances[],
                                                ViReal64  returnLosses[],
                                                ViInt32   *peakCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_LEN] = "";
    ViInt32  loopCount = 0;
    ViReal64 result[2] = {0.0, 0.0};
    ViInt32  resultCount;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_QueryDTFPeakCount(instrSession, peakCount));

    loopCount = (*peakCount < arraySizes) ? *peakCount : arraySizes;

    for (ViInt32 i = 0; i < loopCount; i++)
    {
        snprintf(cmd, RS_MAX_MESSAGE_LEN, "CALC:TRAN:DTF:PEAK:DATA%ld?", i + 1);
        checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 2, result, &resultCount));
        if (resultCount != 2) checkErr(RS_ERROR_UNEXPECTED_RESPONSE);
        peakDistances[i] = result[0];
        returnLosses[i] = result[1];
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the display of the DTF list on the R&S FPC1500 on
/// HIFN  and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/This control turns the display of the DTF list on and off.
ViStatus _VI_FUNC rsfph_ConfigureDTFDisplayEnabled(ViSession instrSession,
                                                   ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_DTF_DISPLAY_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines parameters for the cable loss format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/This control defines the reference value for the cable loss
/// HIPAR referenceLevel/measurement format.
/// HIPAR referencePosition/This control defines the position of the reference value for the cable
/// HIPAR referencePosition/loss measurement format. Each step shifts the reference position one
/// HIPAR referencePosition/grid line up or down.
/// HIPAR yAxisRange/This control defines the range of the y-axis for the cable loss
/// HIPAR yAxisRange/measurement format.
ViStatus _VI_FUNC rsfph_ConfigureVNACableLossFormat(ViSession instrSession,
                                                    ViReal64  referenceLevel,
                                                    ViInt32   referencePosition,
                                                    ViReal64  yAxisRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_CABLE_LOSS_REFERENCE_LEVEL, referenceLevel),
            2, "Reference Level");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_CABLE_LOSS_REFERENCE_POSITION, referencePosition),
            3, "Reference Position");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_CABLE_LOSS_Y_AXIS_RANGE, yAxisRange),
            4, "Y Axis Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines parameters for the return loss format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/This control defines the reference value for the return loss
/// HIPAR referenceLevel/measurement format.
/// HIPAR referencePosition/This control defines the position of the reference value for the
/// HIPAR referencePosition/return loss measurement format. Each step shifts the reference position
/// HIPAR referencePosition/one grid line up or down.
/// HIPAR yAxisScale/This control selects scaling of the y-axis for the return loss
/// HIPAR yAxisScale/measurement format.
/// HIPAR logRange/This control defines the range of the y-axis for the return loss
/// HIPAR logRange/measurement format.
ViStatus _VI_FUNC rsfph_ConfigureVNAReturnLossFormat(ViSession instrSession,
                                                     ViReal64  referenceLevel,
                                                     ViInt32   referencePosition,
                                                     ViInt32   yAxisScale,
                                                     ViReal64  logRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_RETURN_LOSS_REFERENCE_LEVEL, referenceLevel),
            2, "Reference Level");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_RETURN_LOSS_REFERENCE_POSITION, referencePosition),
            3, "Reference Position");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_RETURN_LOSS_Y_AXIS_SCALE, yAxisScale),
            4, "Y Axis Scale");

    if (yAxisScale == RSFPH_VAL_MAGNITUDE_SCALE_LOGARITHMIC)
        viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_RETURN_LOSS_LOG_RANGE, logRange),
                5, "Log Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines parameters for the phase format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/This control defines the reference value for the phase measurement
/// HIPAR referenceLevel/format.
/// HIPAR referencePosition/This control defines the position of the reference value for the phase
/// HIPAR referencePosition/measurement format. Each step shifts the reference position one grid
/// HIPAR referencePosition/line up or down.
/// HIPAR unwrappingEnabled/This control removes the restriction limiting the value range to +/-
/// HIPAR unwrappingEnabled/180.
/// HIPAR yAxisRange/This control defines the range of the y-axis for the phase measurement
/// HIPAR yAxisRange/format.
ViStatus _VI_FUNC rsfph_ConfigureVNAPhaseFormat(ViSession instrSession,
                                                ViReal64  referenceLevel,
                                                ViInt32   referencePosition,
                                                ViBoolean unwrappingEnabled,
                                                ViReal64  yAxisRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_PHASE_REFERENCE_LEVEL, referenceLevel),
            2, "Reference Level");

    viCheckParm(rsfph_SetAttributeViInt32(instrSession, NULL, RSFPH_ATTR_VNA_PHASE_REFERENCE_POSITION, referencePosition),
            3, "Reference Position");

    viCheckParm(rsfph_SetAttributeViBoolean(instrSession, NULL, RSFPH_ATTR_VNA_PHASE_UNWRAPPING_ENABLED, unwrappingEnabled),
            4, "Unwrapping Enabled");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_PHASE_Y_AXIS_RANGE, yAxisRange),
            5, "Y Axis Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute defines the range of the y-axis for the SWR measurement
/// HIFN  format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR yAxisRange/This control defines the range of the y-axis for the SWR measurement
/// HIPAR yAxisRange/format.
ViStatus _VI_FUNC rsfph_ConfigureVNASWRYAxisRange(ViSession instrSession,
                                                  ViReal64  yAxisRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_SWR_Y_AXIS_RANGE, yAxisRange),
            2, "Y Axis Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the minimum and maximum values of the vertical
/// HIFN  axis for the SWR measurement format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR yAxisMinimum/This control defines the bottom value of the vertical axis for the SWR
/// HIPAR yAxisMinimum/measurement format.
/// HIPAR yAxisMaximum/This control defines the top value of the vertical axis for the SWR
/// HIPAR yAxisMaximum/measurement format.
ViStatus _VI_FUNC rsfph_ConfigureVNASWRYAxisMinMax(ViSession instrSession,
                                                   ViReal64  yAxisMinimum,
                                                   ViReal64  yAxisMaximum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_SWR_Y_AXIS_MINIMUM, yAxisMinimum),
            2, "Y Axis Minimum");

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_VNA_SWR_Y_AXIS_MAXIMUM, yAxisMaximum),
            3, "Y Axis Maximum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This attribute defines the reference impedance for the Smith chart
/// HIFN  measurement format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceImpedance/This control defines the reference impedance for the Smith chart
/// HIPAR referenceImpedance/measurement format.
ViStatus _VI_FUNC rsfph_ConfigureSmithChartReferenceImpedanceMarker(
                            ViSession instrSession,
                            ViReal64  referenceImpedance)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsfph_SetAttributeViReal64(instrSession, NULL, RSFPH_ATTR_SMITH_CHART_REFERENCE_IMPEDANCE_MARKER, referenceImpedance),
            2, "Reference Impedance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the total harmonic distortion of the signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR distortionPCT/Returns the total harmonic distortion of the signal in %.
/// HIPAR distortiondB/Returns the total harmonic distortion of the signal in dB.
ViStatus _VI_FUNC rsfph_QueryHarmonicDistortionTotalResult(ViSession instrSession,
                                                           ViReal64* distortionPCT,
                                                           ViReal64* distortiondB)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[] = "CALC:MARK:FUNC:HARM:DIST? TOT";
    ViReal64 result[2] = {0.0, 0.0};
    ViInt32  resultCount;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 2, result, &resultCount));
    if (resultCount == 2)
    {
        if (distortionPCT) *distortionPCT = result[0];
        if (distortiondB) *distortiondB = result[1];
    }
    else
    {
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the position of the harmonics.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the size of the arrays allocated for the 'Peak Distances' and
/// HIPAR arraySize/'Return Losses' arrays of doubles.
/// HIPAR harmonicPositionList/
/// HIPAR returnedValues/
ViStatus _VI_FUNC rsfph_QueryHarmonicDistortionHarmonicPositionList(
                            ViSession instrSession,
                            ViInt32   arraySize,
                            ViReal64  harmonicPositionList[],
                            ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, "CALC:MARK:FUNC:HARM:LIST?", arraySize, harmonicPositionList, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This Function sets the Enable, NTransition, and PTransition bits
/// HIFN of the Main, Power, Limit, Left Margin, and Sync status
/// HIFN questionable registers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR enable/Document parameter here.
/// HIPAR PTransition/Document parameter here.
/// HIPAR NTransition/Document parameter here.
ViStatus _VI_FUNC rsfph_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   enable,
                                          ViInt32   PTransition,
                                          ViInt32   NTransition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *p2statReg;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    switch (registerOperation) {
        case RSFPH_VAL_STAT_REG_PRESET:
             checkErr(rsfph_SetAttributeViString(instrSession, "", RSFPH_ATTR_STATUS_PRESET, NULL));
        break;
        case RSFPH_VAL_STAT_REG_QUESTIONABLE:
            switch (questionableRegister){
                case RSFPH_VAL_STAT_REG_MAIN:
                    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:ENAB %ld;PTR %ld;NTR %ld",
                             enable,
                             PTransition,
                             NTransition
                             );
                    checkErr(RsCore_Write(instrSession, cmd));
                break;
                default:
                    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegister, questionableRegister, &p2statReg),
                            3, "Questionable Register");

                    switch (questionableRegister)
                    {
                        case RSFPH_VAL_STAT_REG_MAIN:
                            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:ENAB %ld;PTR %ld;NTR %ld",
                             enable,
                             PTransition,
                             NTransition
                             );
                            checkErr(RsCore_Write(instrSession, cmd));

                        break;
                        default:
                            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:%s:ENAB %ld;PTR %ld;NTR %ld",
                             p2statReg,
                             enable,
                             PTransition,
                             NTransition
                             );
                            checkErr(RsCore_Write(instrSession, cmd));
                    }
            }
        break;
        case RSFPH_VAL_STAT_REG_OPERATION:
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
                    4, "Enable");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, PTransition, 0, 65535),
                    5, "PTransition");
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, NTransition, 0, 65535),
                    6, "NTransition");

            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:ENAB %ld;PTR %ld;NTR %ld",
                     enable,
                     PTransition,
                     NTransition
                     );
            checkErr(RsCore_Write(instrSession, cmd));
        break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function contains the commands for the querying status     */
/// HIFN reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR registerPart/Sets the register part.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rsfph_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   registerPart,
                                          ViInt32   *registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *p2statReg;
    ViChar   *p2statRegQuery;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerPart, 0, 1),
            4, "Register Part");

    switch (registerOperation) {
        case RSFPH_VAL_STAT_REG_QUESTIONABLE:
            switch (questionableRegister){
                case RSFPH_VAL_STAT_REG_MAIN:
                    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegisterQuery, registerPart, &p2statRegQuery),
                            4, "Questionable Register Query");
                    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:%s?", p2statRegQuery);
                    checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
                break;

                default:
                    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegister, questionableRegister, &p2statReg),
                            3, "Questionable Register");
                    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegisterQuery, registerPart, &p2statRegQuery),
                            4, "Questionable Register Query");
                    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:%s:%s?", p2statReg, p2statRegQuery);
                    checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
            }

        break;

        case RSFPH_VAL_STAT_REG_OPERATION:
            viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegisterQuery, registerPart, &p2statRegQuery),
                            4, "Questionable Register Query");
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:%s?", p2statRegQuery);
            checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function contains the commands for the seting status bit
/// HIFN  reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR bitNumber/This control sets the number of the bit.
/// HIPAR enable/This control sets the enable bits of the status register.
/// HIPAR ptransition/This control sets the PTransition bits (edge detectors) of the status
/// HIPAR ptransition/register.
/// HIPAR ntransition/This control sets the NTransition bits (edge detectors) of the status
/// HIPAR ntransition/register.
ViStatus _VI_FUNC rsfph_SetStatusRegisterBit(ViSession instrSession,
                                             ViInt32   registerOperation,
                                             ViInt32   bitNumber,
                                             ViInt32   enable,
                                             ViInt32   ptransition,
                                             ViInt32   ntransition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerOperation, 1, 2),
            2, "Register Operation");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bitNumber, 8, 12),
            3, "Bit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, 0, 65535),
            4, "Enable");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ptransition, 0, 65535),
            5, "PTransition");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ntransition, 0, 65535),
            6, "NTransition");

    switch (registerOperation)
    {
        case RSFPH_VAL_STAT_REG_QUESTIONABLE:
            checkErr(snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:BIT%ld:ENAB %ld;PTR %ld;NTR %ld", bitNumber, enable, ptransition, ntransition));
            checkErr(RsCore_Write(instrSession, cmd));
        break;
        case RSFPH_VAL_STAT_REG_OPERATION:
            checkErr(snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:BIT%ld:ENAB %ld;PTR %ld;NTR %ld", bitNumber, enable, ptransition, ntransition));
            checkErr(RsCore_Write(instrSession, cmd));
        break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function contains the commands for the querying status bit
/// HIFN  reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR bitNumber/This control sets the number of the queried bit.
/// HIPAR registerPart/Sets the register part.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rsfph_GetStatusRegisterBit(ViSession instrSession,
                                             ViInt32   registerOperation,
                                             ViInt32   bitNumber,
                                             ViInt32   registerPart,
                                             ViInt32*  registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *p2statRegQuery;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerOperation, 1, 2),
            2, "Register Operation");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bitNumber, 8, 12),
            3, "Bit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, registerPart, 0, 4),
            4, "Register Part");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsfph_rngStatusRegisterQuery, registerPart, &p2statRegQuery),
                            4, "Questionable Register Query");

    switch (registerOperation) {
        case RSFPH_VAL_STAT_REG_QUESTIONABLE:
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES:BIT%ld:%s?", bitNumber, p2statRegQuery);
            checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;

        case RSFPH_VAL_STAT_REG_OPERATION:
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:BIT%ld:%s?", bitNumber, p2statRegQuery);
            checkErr(RsCore_QueryViInt32(instrSession, cmd, registerValue));
        break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, registerOperation), 2, "Register Operation");
    }

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN This function resets the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  OPC = -1;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession) == VI_FALSE)
    {
        checkErr(rsfph_ClearStatus(instrSession));
        checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
        checkErr(rsfph_QueryOPC(instrSession, &OPC));
    }

    checkErr(rsfph_DefaultInstrSetup(instrSession));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}


/// HIFN  This function runs the instrument's self test routine and returns the
/// HIFN  test result(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selfTestResult/This control contains the value returned from the instrument self
/// HIPAR selfTestResult/test.  Zero means success.  For any other code, see the device's
/// HIPAR selfTestResult/operator's manual.
/// HIPAR selfTestMessage/Returns the self-test response string from the instrument. See the
/// HIPAR selfTestMessage/device's operation manual for an explanation of the string's contents.
ViStatus _VI_FUNC rsfph_self_test(ViSession instrSession,
                                  ViInt16   *testResult,
                                  ViChar    testMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, testResult), 2, "Null address for Test Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, testMessage), 3, "Null address for Test Message");

    checkErr(RsCore_SelfTest(instrSession, testResult, 48, testMessage));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the driver and instrument revisions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR driverRev/Returns the instrument driver software revision numbers in the
/// HIPAR driverRev/form of a string.
/// HIPAR instrRev/Returns the instrument firmware revision numbers in the form of
/// HIPAR instrRev/a string.
ViStatus _VI_FUNC rsfph_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Instrument Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, firmwareRevision));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the instrument error queue and returns
/// HIFN the result.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.
/// HIPAR errCode/Returns the error code read from the instrument's error queue.
/// HIPAR errMessage/Returns the error message string read from the instrument's
/// HIPAR errMessage/error message queue.
ViStatus _VI_FUNC rsfph_error_query(ViSession instrSession,
                                    ViInt32   *errorCode,
                                    ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function translates the error codes returned by this
/// HIFN instrument driver into user-readable strings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the
/// HIPAR errorCode/instrument driver functions..
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the
/// HIPAR errorMessage/status code you specify.
ViStatus _VI_FUNC rsfph_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[])
{
    return rsfph_utility_error_message(instrSession, errorCode, errorMessage);
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rsfph_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN This function switches ON/OFF status checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rsfph_ConfigureStatusChecking(ViSession instrSession,
                                                ViBoolean statusChecking)
{  
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));

Error:
    return error;
}

/// HIFN This function switches ON/OFF range checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR rangeChecking/This control enables or disables range checking.
ViStatus _VI_FUNC rsfph_ConfigureRangeChecking(ViSession instrSession,
                                               ViBoolean rangeChecking)
{  
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rsfph_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rsfph_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}
/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rsfph_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->multiThreadLocking = multiThreadLocking;

Error:
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for writes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for writes.
ViStatus _VI_FUNC rsfph_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrWrites = enable;

Error:
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for queries.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for queries.
ViStatus _VI_FUNC rsfph_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrQueries = enable;

Error:
    return error;
}

/// HIFN  This function sets the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opcTimeout/This control sets the timeout value.
ViStatus _VI_FUNC rsfph_SetOPCTimeout(ViSession instrSession,
                                      ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32) timeout));

Error:
    return error;
}

/// HIFN  This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control returns the timeout value.
ViStatus _VI_FUNC rsfph_GetOPCTimeout(ViSession instrSession,
                                      ViUInt32* timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32*) timeout));

Error:
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIFN Note that the actual timeout used may be higher than the one
/// HIFN requested.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR VISATimeout/Specifies the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
/// HIPAR VISATimeout/Note that the actual timeout used may be higher than the one
/// HIPAR VISATimeout/requested.
ViStatus _VI_FUNC rsfph_SetVISATimeout(ViSession instrSession,
                                       ViUInt32  VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR VISATimeout/Queries the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
ViStatus _VI_FUNC rsfph_GetVISATimeout(ViSession instrSession,
                                       ViUInt32  *VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of IDQueryResponse buffer
/// HIPAR idQueryResponse/Returns the ID Query response string. The array should consist of at
/// HIPAR idQueryResponse/least 256 elements.
ViStatus _VI_FUNC rsfph_IDQueryResponse(ViSession instrSession,
                                        ViUInt32  bufferSize,
                                        ViChar    IDQueryResponse[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, "*IDN?", bufferSize, IDQueryResponse, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before *WAI
/// HIFN  have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsfph_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_WriteInstrData(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opc/Queries the OPC.
ViStatus _VI_FUNC rsfph_QueryOPC(ViSession instrSession,
                                 ViInt32*  opc)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsfph_QueryViInt32(instrSession, "*OPC?", opc));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets fast sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsvna_init or
/// HIPAR instrSession/rsvna_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fastSweepMode/Fast sweep mode
ViStatus _VI_FUNC rsfph_SetFastSweepMode(ViSession instrSession,
                                         ViInt32   fastSweepMode)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, fastSweepMode, RSFPH_VAL_FAST_SWEEP_NORMAL, RSFPH_VAL_FAST_SWEEP_FAST),
            2, "Fast Sweep Mode");

    rsSession->fastSweepInstrument = fastSweepMode;

Error:
    return error;
}

/// HIFN These functions enable the instrument driver user to
/// HIFN get or clear the error information the driver associates with the
/// HIFN RS session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Description parameter.
/// HIPAR description/Returns the error description for the session or execution
/// HIPAR description/thread. If there is no description, the function returns an
/// HIPAR description/empty string.
ViStatus _VI_FUNC rsfph_GetError(ViSession instrSession,
                                 ViStatus  *errorCode,
                                 ViInt32   bufferSize,
                                 ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rsfph_utility_error_message, errorCode, bufferSize, description));

Error:
    (void)RsCore_UnlockSession(instrSession); // IGNORE: ERROR!!! Missing Lock
    return error;
}

/// HIFN This function clears the error code and error description for
/// HIFN the session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsfph_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function is used to read data from the instrument and write
/// HIFN it to a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument
/// HIPAR source/to control computer.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from instrument to control computer applies.
ViStatus _VI_FUNC rsfph_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  source,
                                                 ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function is used to read data from the host computer and
/// HIFN write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
 ViStatus _VI_FUNC rsfph_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN These functions enable the instrument driver user to
/// HIFN write commands directly to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
///  Note:  These functions bypass the RS attribute state caching.
///  Note:        WriteInstrData invalidates the cached values for all
///  Note:        attributes.
ViStatus _VI_FUNC rsfph_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    error = RsCore_Write(instrSession, writeBuffer);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN These functions enable the instrument driver user to
/// HIFN read commands directly from the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR numBytes/Pass the maximum number of bytes to read from the instruments.
/// HIPAR rdBuf/After this function executes, this parameter contains the data
/// HIPAR rdBuf/that was read from the instrument.
/// HIPAR bytesRead/Returns the number of bytes actually read from the instrument
/// HIPAR bytesRead/and stored in the Read Buffer.
ViStatus _VI_FUNC rsfph_ReadInstrData(ViSession instrSession,
                                      ViInt32   numberOfBytesToRead,
                                      ViChar    readBuffer[],
                                      ViUInt32  *numBytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  responseString = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ReadViStringUnknownLength(instrSession, &responseString));
    checkErr(RsCore_CopyToUserBufferAsciiData(readBuffer, numberOfBytesToRead, responseString));
    *numBytesRead = (ViUInt32)strlen(responseString);

Error:
    if (responseString)
        free(responseString);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViBoolean value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViBoolean value.
ViStatus _VI_FUNC rsfph_QueryViBoolean(ViSession instrSession,
                                       ViString  command,
                                       ViBoolean *value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViBoolean(instrSession, command, value));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32   *value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViInt32(instrSession, command, value));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64  *value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViReal64(instrSession, command, value));

    checkErr(rsfph_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rsfph_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  extBuf = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &extBuf));

    checkErr(rsfph_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferAsciiData(value, bufferSize, extBuf));

Error:
    if (extBuf)
        free(extBuf);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function closes the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsfph_init or
/// HIPAR instrSession/rsfph_InitWithOptions function.
ViStatus _VI_FUNC rsfph_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 *------------------- End Instrument Driver Source Code ---------------------*
 *****************************************************************************/

